/* document-manager.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/document-manager.h>
#include <glib/gi18n-lib.h>
#include "src/uimanager.h"
#include "src/recent-manager-ui.h"




enum  {
	VALIDE_DOCUMENT_MANAGER_DUMMY_PROPERTY,
	VALIDE_DOCUMENT_MANAGER_CURRENT
};
static ValideDocumentManager* valide_document_manager_instance = NULL;
static void valide_document_manager_title_change (ValideDocumentManager* self);
static void valide_document_manager_setup_ui (ValideDocumentManager* self);
static ValideDocumentManager* valide_document_manager_new (void);
static void _valide_document_manager_title_change_valide_document_title_change (ValideDocument* sender, gpointer self);
static void _valide_document_manager_buffer_changed_gtk_text_buffer_changed (GtkTextBuffer* sender, gpointer self);
static void _valide_document_manager_setup_ui_gtk_object_destroy (GtkObject* sender, gpointer self);
static GObject * valide_document_manager_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer valide_document_manager_parent_class = NULL;
static void valide_document_manager_dispose (GObject * obj);



#line 42 "document-manager.vala"
static void valide_document_manager_title_change (ValideDocumentManager* self) {
	GtkHBox* title;
	char* text;
	GtkLabel* label;
#line 42 "document-manager.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT_MANAGER (self));
	title = g_object_ref_sink (gtk_hbox_new (FALSE, 4));
	/*
	    Too big icon !
	
	    Gtk.Button button = new Gtk.Button ();
	    button.set_relief (Gtk.ReliefStyle.NONE);
	    button.set_focus_on_click (false);
	    button.add (new Gtk.Image.from_stock (Gtk.STOCK_CLOSE, Gtk.IconSize.MENU));
	    button.set_tooltip_text (_("Close document"));
	    title.pack_start (button, false, false, 0);
	
	
	    Can't return alloc string
	
	    string text = this.current.title;
	*/
	text = g_strdup ("");
#line 62 "document-manager.vala"
	if (valide_document_get_path (valide_document_manager_get_current (self)) == NULL) {
		char* _tmp1;
		const char* _tmp0;
		_tmp1 = NULL;
#line 64 "document-manager.vala"
		_tmp0 = NULL;
#line 64 "document-manager.vala"
		text = (_tmp1 = (_tmp0 = _ ("New file"), (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (text = (g_free (text), NULL)), _tmp1);
	} else {
		char* _tmp2;
		_tmp2 = NULL;
#line 68 "document-manager.vala"
		text = (_tmp2 = g_path_get_basename (valide_document_get_path (valide_document_manager_get_current (self))), (text = (g_free (text), NULL)), _tmp2);
	}
#line 70 "document-manager.vala"
	if (!valide_document_get_is_save (valide_document_manager_get_current (self))) {
		char* _tmp3;
		_tmp3 = NULL;
#line 72 "document-manager.vala"
		text = (_tmp3 = g_strconcat (text, (" *"), NULL), (text = (g_free (text), NULL)), _tmp3);
	}
	label = g_object_ref_sink (gtk_label_new (text));
#line 76 "document-manager.vala"
	gtk_box_pack_start (GTK_BOX (title), GTK_WIDGET (label), FALSE, FALSE, ((guint) 0));
#line 77 "document-manager.vala"
	gtk_widget_show_all (GTK_WIDGET (title));
#line 78 "document-manager.vala"
	gtk_notebook_set_tab_label (GTK_NOTEBOOK (self), GTK_WIDGET (valide_document_manager_get_current (self)), GTK_WIDGET (title));
	(title == NULL ? NULL : (title = (g_object_unref (title), NULL)));
	text = (g_free (text), NULL);
	(label == NULL ? NULL : (label = (g_object_unref (label), NULL)));
}


#line 82 "document-manager.vala"
static void valide_document_manager_setup_ui (ValideDocumentManager* self) {
	gboolean active;
	ValideUIManager* ui;
	GtkAction* _tmp0;
	GtkAction* _tmp1;
	GtkAction* _tmp2;
	GtkAction* _tmp3;
	GtkAction* _tmp4;
	GtkAction* _tmp5;
	GtkAction* _tmp6;
	GtkAction* _tmp7;
	GtkAction* _tmp8;
#line 82 "document-manager.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT_MANAGER (self));
	active = FALSE;
	ui = valide_ui_manager_get_instance ();
#line 87 "document-manager.vala"
	if (valide_document_manager_get_current (self) != NULL) {
#line 89 "document-manager.vala"
		active = TRUE;
	}
#line 91 "document-manager.vala"
	_tmp0 = NULL;
#line 91 "document-manager.vala"
	gtk_action_set_sensitive ((_tmp0 = valide_ui_manager_get_action (ui, "file-save")), active);
	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
#line 92 "document-manager.vala"
	_tmp1 = NULL;
#line 92 "document-manager.vala"
	gtk_action_set_sensitive ((_tmp1 = valide_ui_manager_get_action (ui, "file-save-as")), active);
	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
#line 93 "document-manager.vala"
	_tmp2 = NULL;
#line 93 "document-manager.vala"
	gtk_action_set_sensitive ((_tmp2 = valide_ui_manager_get_action (ui, "file-close")), active);
	(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
#line 94 "document-manager.vala"
	_tmp3 = NULL;
#line 94 "document-manager.vala"
	gtk_action_set_sensitive ((_tmp3 = valide_ui_manager_get_action (ui, "file-close-all")), active);
	(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
#line 95 "document-manager.vala"
	_tmp4 = NULL;
#line 95 "document-manager.vala"
	gtk_action_set_sensitive ((_tmp4 = valide_ui_manager_get_action (ui, "edit-undo")), active);
	(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
#line 96 "document-manager.vala"
	_tmp5 = NULL;
#line 96 "document-manager.vala"
	gtk_action_set_sensitive ((_tmp5 = valide_ui_manager_get_action (ui, "edit-redo")), active);
	(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
#line 97 "document-manager.vala"
	_tmp6 = NULL;
#line 97 "document-manager.vala"
	gtk_action_set_sensitive ((_tmp6 = valide_ui_manager_get_action (ui, "edit-copy")), active);
	(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
#line 98 "document-manager.vala"
	_tmp7 = NULL;
#line 98 "document-manager.vala"
	gtk_action_set_sensitive ((_tmp7 = valide_ui_manager_get_action (ui, "edit-cut")), active);
	(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
#line 99 "document-manager.vala"
	_tmp8 = NULL;
#line 99 "document-manager.vala"
	gtk_action_set_sensitive ((_tmp8 = valide_ui_manager_get_action (ui, "edit-paste")), active);
	(_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL)));
	(ui == NULL ? NULL : (ui = (g_object_unref (ui), NULL)));
}


#line 103 "document-manager.vala"
void valide_document_manager_buffer_changed (ValideDocumentManager* self) {
#line 103 "document-manager.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT_MANAGER (self));
#line 105 "document-manager.vala"
	valide_document_set_is_save (valide_document_manager_get_current (self), FALSE);
}


#line 108 "document-manager.vala"
static ValideDocumentManager* valide_document_manager_new (void) {
	ValideDocumentManager * self;
	self = g_object_newv (VALIDE_TYPE_DOCUMENT_MANAGER, 0, NULL);
	return self;
}


#line 117 "document-manager.vala"
ValideDocumentManager* valide_document_manager_get_instance (void) {
	ValideDocumentManager* _tmp1;
#line 119 "document-manager.vala"
	if (valide_document_manager_instance == NULL) {
		ValideDocumentManager* _tmp0;
		_tmp0 = NULL;
#line 121 "document-manager.vala"
		valide_document_manager_instance = (_tmp0 = g_object_ref_sink (valide_document_manager_new ()), (valide_document_manager_instance == NULL ? NULL : (valide_document_manager_instance = (g_object_unref (valide_document_manager_instance), NULL))), _tmp0);
	}
#line 123 "document-manager.vala"
	_tmp1 = NULL;
#line 123 "document-manager.vala"
	return (_tmp1 = valide_document_manager_instance, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
}


#line 42 "document-manager.vala"
static void _valide_document_manager_title_change_valide_document_title_change (ValideDocument* sender, gpointer self) {
	valide_document_manager_title_change (self);
}


#line 103 "document-manager.vala"
static void _valide_document_manager_buffer_changed_gtk_text_buffer_changed (GtkTextBuffer* sender, gpointer self) {
	valide_document_manager_buffer_changed (self);
}


#line 82 "document-manager.vala"
static void _valide_document_manager_setup_ui_gtk_object_destroy (GtkObject* sender, gpointer self) {
	valide_document_manager_setup_ui (self);
}


#line 126 "document-manager.vala"
void valide_document_manager_create (ValideDocumentManager* self, const char* filename) {
	ValideDocument* document;
	GtkLabel* _tmp1;
#line 126 "document-manager.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT_MANAGER (self));
	document = g_object_ref_sink (valide_document_new (filename));
#line 130 "document-manager.vala"
	if (filename != NULL) {
		ValideRecentManagerUI* _tmp0;
#line 132 "document-manager.vala"
		_tmp0 = NULL;
#line 132 "document-manager.vala"
		valide_recent_manager_ui_add_file ((_tmp0 = valide_recent_manager_ui_get_instance ()), filename);
		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
	}
#line 135 "document-manager.vala"
	g_signal_connect_object (document, "title-change", ((GCallback) _valide_document_manager_title_change_valide_document_title_change), self, 0);
#line 136 "document-manager.vala"
	_tmp1 = NULL;
#line 136 "document-manager.vala"
	gtk_notebook_append_page (GTK_NOTEBOOK (self), GTK_WIDGET (document), GTK_WIDGET ((_tmp1 = g_object_ref_sink (gtk_label_new ("")))));
	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
#line 137 "document-manager.vala"
	gtk_widget_show_all (GTK_WIDGET (document));
#line 138 "document-manager.vala"
	valide_document_manager_set_current (self, document);
#line 139 "document-manager.vala"
	g_signal_connect_object (valide_document_manager_get_current (self)->buffer, "changed", ((GCallback) _valide_document_manager_buffer_changed_gtk_text_buffer_changed), self, 0);
#line 140 "document-manager.vala"
	g_signal_connect_object (valide_document_manager_get_current (self), "destroy", ((GCallback) _valide_document_manager_setup_ui_gtk_object_destroy), self, 0);
#line 141 "document-manager.vala"
	g_signal_emit_by_name (G_OBJECT (document), "title-change");
#line 142 "document-manager.vala"
	valide_document_manager_setup_ui (self);
	(document == NULL ? NULL : (document = (g_object_unref (document), NULL)));
}


#line 145 "document-manager.vala"
void valide_document_manager_open (ValideDocumentManager* self) {
	GtkFileChooserDialog* dialog;
	GtkFileFilter* _tmp0;
	char* _tmp1;
#line 145 "document-manager.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT_MANAGER (self));
	dialog = g_object_ref_sink (gtk_file_chooser_dialog_new (_ ("Open file"), NULL, GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL, NULL));
	/* Add filter */
#line 154 "document-manager.vala"
	_tmp0 = NULL;
#line 154 "document-manager.vala"
	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), (_tmp0 = g_object_ref_sink (gtk_file_filter_new ())));
	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
#line 155 "document-manager.vala"
	gtk_file_filter_set_name (gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog)), _ ("Vala source file"));
	_tmp1 = NULL;
#line 156 "document-manager.vala"
	gtk_file_filter_add_pattern (gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog)), (_tmp1 = g_strconcat ("*", VALIDE_DOCUMENT_FILE_EXT, NULL)));
	_tmp1 = (g_free (_tmp1), NULL);
#line 158 "document-manager.vala"
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
#line 160 "document-manager.vala"
		valide_document_manager_create (self, gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog)));
#line 161 "document-manager.vala"
		valide_document_set_is_save (valide_document_manager_get_current (self), TRUE);
	}
#line 163 "document-manager.vala"
	gtk_object_destroy (GTK_OBJECT (dialog));
	(dialog == NULL ? NULL : (dialog = (g_object_unref (dialog), NULL)));
}


#line 166 "document-manager.vala"
gboolean valide_document_manager_close_all (ValideDocumentManager* self) {
	gboolean ret;
#line 166 "document-manager.vala"
	g_return_val_if_fail (VALIDE_IS_DOCUMENT_MANAGER (self), FALSE);
	ret = TRUE;
#line 170 "document-manager.vala"
	while (gtk_notebook_get_n_pages (GTK_NOTEBOOK (self)) != 0) {
#line 172 "document-manager.vala"
		gtk_notebook_set_current_page (GTK_NOTEBOOK (self), -1);
#line 173 "document-manager.vala"
		if (!valide_document_close (valide_document_manager_get_current (self))) {
#line 175 "document-manager.vala"
			ret = FALSE;
#line 176 "document-manager.vala"
			break;
		}
	}
#line 179 "document-manager.vala"
	return ret;
}


ValideDocument* valide_document_manager_get_current (ValideDocumentManager* self) {
	gint _tmp0;
	g_return_val_if_fail (VALIDE_IS_DOCUMENT_MANAGER (self), NULL);
#line 33 "document-manager.vala"
	return VALIDE_DOCUMENT (gtk_notebook_get_nth_page (GTK_NOTEBOOK (self), (g_object_get (G_OBJECT (self), "page", &_tmp0, NULL), _tmp0)));
}


void valide_document_manager_set_current (ValideDocumentManager* self, ValideDocument* value) {
	g_return_if_fail (VALIDE_IS_DOCUMENT_MANAGER (self));
#line 37 "document-manager.vala"
	gtk_notebook_set_current_page (GTK_NOTEBOOK (self), gtk_notebook_page_num (GTK_NOTEBOOK (self), GTK_WIDGET (value)));
}


static GObject * valide_document_manager_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	ValideDocumentManagerClass * klass;
	GObjectClass * parent_class;
	ValideDocumentManager * self;
	klass = VALIDE_DOCUMENT_MANAGER_CLASS (g_type_class_peek (VALIDE_TYPE_DOCUMENT_MANAGER));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = VALIDE_DOCUMENT_MANAGER (obj);
	{
#line 114 "document-manager.vala"
		valide_document_manager_setup_ui (self);
	}
	return obj;
}


static void valide_document_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValideDocumentManager * self;
	self = VALIDE_DOCUMENT_MANAGER (object);
	switch (property_id) {
		case VALIDE_DOCUMENT_MANAGER_CURRENT:
		g_value_set_object (value, valide_document_manager_get_current (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_document_manager_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValideDocumentManager * self;
	self = VALIDE_DOCUMENT_MANAGER (object);
	switch (property_id) {
		case VALIDE_DOCUMENT_MANAGER_CURRENT:
		valide_document_manager_set_current (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_document_manager_class_init (ValideDocumentManagerClass * klass) {
	valide_document_manager_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = valide_document_manager_get_property;
	G_OBJECT_CLASS (klass)->set_property = valide_document_manager_set_property;
	G_OBJECT_CLASS (klass)->constructor = valide_document_manager_constructor;
	G_OBJECT_CLASS (klass)->dispose = valide_document_manager_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_DOCUMENT_MANAGER_CURRENT, g_param_spec_object ("current", "current", "current", VALIDE_TYPE_DOCUMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void valide_document_manager_init (ValideDocumentManager * self) {
}


static void valide_document_manager_dispose (GObject * obj) {
	ValideDocumentManager * self;
	self = VALIDE_DOCUMENT_MANAGER (obj);
	G_OBJECT_CLASS (valide_document_manager_parent_class)->dispose (obj);
}


GType valide_document_manager_get_type (void) {
	static GType valide_document_manager_type_id = 0;
	if (G_UNLIKELY (valide_document_manager_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideDocumentManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_document_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideDocumentManager), 0, (GInstanceInitFunc) valide_document_manager_init };
		valide_document_manager_type_id = g_type_register_static (GTK_TYPE_NOTEBOOK, "ValideDocumentManager", &g_define_type_info, 0);
	}
	return valide_document_manager_type_id;
}




