/* document-manager.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

using GLib;

public class Valide.DocumentManager : Gtk.Notebook
{
  private static DocumentManager instance = null;

  public Document current
  {
    get
    {
      return (Document)this.get_nth_page (this.page);
    }
    set
    {
      this.set_current_page (this.page_num (value));
    }
  }

  [Callback]
  private void title_change ()
  {
    Gtk.HBox title = new Gtk.HBox (false, 4);
/*
    Too big icon !

    Gtk.Button button = new Gtk.Button ();
    button.set_relief (Gtk.ReliefStyle.NONE);
    button.set_focus_on_click (false);
    button.add (new Gtk.Image.from_stock (Gtk.STOCK_CLOSE, Gtk.IconSize.MENU));
    button.set_tooltip_text (_("Close document"));
    title.pack_start (button, false, false, 0);
*/
/*
    Can't return alloc string

    string text = this.current.title;
*/
    string text = "";

    if (this.current.path == null)
    {
      text = _("New file");
    }
    else
    {
      text = GLib.Path.get_basename (this.current.path);
    }
    if (!this.current.is_save)
    {
      text += " *";
    }

    var label = new Gtk.Label (text);
    title.pack_start (label, false, false, 0);
    title.show_all ();
    this.set_tab_label (this.current, title);
  }

  [Callback]
  private void setup_ui ()
  {
    bool active = false;
    UIManager ui = UIManager.get_instance ();

    if (this.current != null)
    {
      active = true;
    }
    ui.get_action ("file-save").sensitive = active;
    ui.get_action ("file-save-as").sensitive = active;
    ui.get_action ("file-close").sensitive = active;
    ui.get_action ("file-close-all").sensitive = active;
    ui.get_action ("edit-undo").sensitive = active;
    ui.get_action ("edit-redo").sensitive = active;
    ui.get_action ("edit-copy").sensitive = active;
    ui.get_action ("edit-cut").sensitive = active;
    ui.get_action ("edit-paste").sensitive = active;
  }

  [Callback]
  public void buffer_changed ()
  {
    this.current.is_save = false;
  }

  private DocumentManager ()
  {
  }

  construct
  {
    this.setup_ui ();
  }

  public static DocumentManager get_instance ()
  {
    if (DocumentManager.instance == null)
    {
      DocumentManager.instance = new DocumentManager ();
    }
    return DocumentManager.instance;
  }

  public void create (string? filename = null)
  {
    Document document = new Document (filename);

    if (filename != null)
    {
      RecentManagerUI.get_instance ().add_file (filename);
    }

    document.title_change += this.title_change;
    this.append_page (document, new Gtk.Label (""));
    document.show_all ();
    this.current = document;
    this.current.buffer.changed += this.buffer_changed;
    this.current.destroy += this.setup_ui;
    document.title_change ();
    this.setup_ui ();
  }

  public void open ()
  {
    Gtk.FileChooserDialog dialog = new Gtk.FileChooserDialog (_("Open file"), null,
                                                              Gtk.FileChooserAction.OPEN,
                                                              Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
                                                              Gtk.STOCK_OPEN, Gtk.ResponseType.ACCEPT,
                                                              null);

    /* Add filter */
    dialog.filter = new Gtk.FileFilter ();
    dialog.filter.set_name (_("Vala source file"));
    dialog.filter.add_pattern ("*" + Document.FILE_EXT);

    if (dialog.run () == Gtk.ResponseType.ACCEPT)
    {
      this.create (dialog.get_filename ());
      this.current.is_save = true;
    }
    dialog.destroy ();
  }

  public bool close_all ()
  {
    bool ret = true;

    while (this.get_n_pages () != 0)
    {
      this.set_current_page (-1);
      if (!this.current.close ())
      {
        ret = false;
        break;
      }
    }
    return ret;
  }
}

