/* document.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/document.h>
#include <glib/gi18n-lib.h>
#include <glib/gstdio.h>
#include <gtksourceview/gtksourceview.h>
#include <gdk/gdk.h>
#include "src/sourceview.h"




struct _ValideDocumentPrivate {
	ValideSourceView* text_view;
	char* path_;
	char* filename_;
	gboolean save_;
};

#define VALIDE_DOCUMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_DOCUMENT, ValideDocumentPrivate))
enum  {
	VALIDE_DOCUMENT_DUMMY_PROPERTY,
	VALIDE_DOCUMENT_IS_SAVE,
	VALIDE_DOCUMENT_PATH
};
static GObject * valide_document_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer valide_document_parent_class = NULL;
static void valide_document_dispose (GObject * obj);



/**
  @FIXME : Can't return alloc string

  public string title
  {
    get
    {
      string text = "";

      if (this.path == null)
      {
        text = "New";
      }
      else
      {
        text = this.path;
        if (!this.is_save)
        {
          text += " *";
        }
      }
      return text;
    }
  }


   * Methods
   */
#line 124 "document.vala"
ValideDocument* valide_document_new (const char* path) {
	ValideDocument * self;
	self = g_object_newv (VALIDE_TYPE_DOCUMENT, 0, NULL);
#line 126 "document.vala"
	valide_document_set_path (self, path);
	return self;
}


#line 137 "document.vala"
void valide_document_save (ValideDocument* self) {
	GError * inner_error;
#line 137 "document.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT (self));
	inner_error = NULL;
#line 139 "document.vala"
	if (!valide_document_get_is_save (self)) {
#line 141 "document.vala"
		if (self->priv->path_ == NULL) {
			GtkFileChooserDialog* dialog;
			dialog = g_object_ref_sink (gtk_file_chooser_dialog_new (_ ("Save file"), NULL, GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL, NULL));
#line 148 "document.vala"
			if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
				char* _tmp1;
				const char* _tmp0;
				_tmp1 = NULL;
#line 150 "document.vala"
				_tmp0 = NULL;
#line 150 "document.vala"
				self->priv->path_ = (_tmp1 = (_tmp0 = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->path_ = (g_free (self->priv->path_), NULL)), _tmp1);
			}
#line 152 "document.vala"
			gtk_object_destroy (GTK_OBJECT (dialog));
			(dialog == NULL ? NULL : (dialog = (g_object_unref (dialog), NULL)));
		}
#line 154 "document.vala"
		if (self->priv->path_ != NULL) {
			GtkTextIter start = {0};
			GtkTextIter end = {0};
			char* contents;
			char* _tmp3;
			const char* _tmp2;
			contents = NULL;
#line 160 "document.vala"
			gtk_text_buffer_get_bounds (self->buffer, &start, &end);
			_tmp3 = NULL;
#line 161 "document.vala"
			_tmp2 = NULL;
#line 161 "document.vala"
			contents = (_tmp3 = (_tmp2 = gtk_text_buffer_get_text (self->buffer, &start, &end, FALSE), (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (contents = (g_free (contents), NULL)), _tmp3);
			{
#line 164 "document.vala"
				g_file_set_contents (valide_document_get_path (self), contents, ((glong) -1), &inner_error);
				if (inner_error != NULL) {
					goto __catch2_g_error;
				}
#line 165 "document.vala"
				valide_document_set_is_save (self, TRUE);
			}
			goto __finally2;
			__catch2_g_error:
			{
				GError * e;
				e = inner_error;
				inner_error = NULL;
				{
#line 169 "document.vala"
					g_critical (e->message);
				}
			}
			__finally2:
			;
			contents = (g_free (contents), NULL);
		}
	}
}


#line 175 "document.vala"
void valide_document_save_as (ValideDocument* self) {
	gboolean old_is_save;
	const char* _tmp0;
	char* old_path;
#line 175 "document.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT (self));
	old_is_save = valide_document_get_is_save (self);
#line 178 "document.vala"
	_tmp0 = NULL;
	old_path = (_tmp0 = valide_document_get_path (self), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
#line 180 "document.vala"
	valide_document_set_path (self, NULL);
#line 181 "document.vala"
	valide_document_set_is_save (self, FALSE);
#line 182 "document.vala"
	valide_document_save (self);
#line 183 "document.vala"
	if (!valide_document_get_is_save (self)) {
#line 185 "document.vala"
		valide_document_set_is_save (self, old_is_save);
#line 186 "document.vala"
		valide_document_set_path (self, old_path);
	}
	old_path = (g_free (old_path), NULL);
}


#line 190 "document.vala"
gboolean valide_document_close (ValideDocument* self) {
	gboolean is_close;
#line 190 "document.vala"
	g_return_val_if_fail (VALIDE_IS_DOCUMENT (self), FALSE);
	is_close = TRUE;
#line 194 "document.vala"
	if (!valide_document_get_is_save (self)) {
		GtkDialog* dialog;
		GtkLabel* label;
		GtkBox* vbox;
		gint _tmp0;
		dialog = g_object_ref_sink (gtk_dialog_new ());
#line 197 "document.vala"
		gtk_window_set_title (GTK_WINDOW (dialog), _ ("Are you sure?"));
#line 198 "document.vala"
		gtk_dialog_add_button (dialog, GTK_STOCK_YES, ((gint) GTK_RESPONSE_YES));
#line 199 "document.vala"
		gtk_dialog_add_button (dialog, GTK_STOCK_NO, ((gint) GTK_RESPONSE_NO));
#line 200 "document.vala"
		gtk_dialog_add_button (dialog, GTK_STOCK_CANCEL, ((gint) GTK_RESPONSE_CANCEL));
#line 201 "document.vala"
		gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
		label = g_object_ref_sink (gtk_label_new (_ ("Document with unsaved changes. Save changes before closing?")));
		vbox = GTK_BOX (dialog->vbox);
#line 205 "document.vala"
		gtk_box_pack_start (vbox, GTK_WIDGET (label), TRUE, FALSE, ((guint) 10));
#line 206 "document.vala"
		gtk_widget_show_all (GTK_WIDGET (dialog));
		_tmp0 = gtk_dialog_run (dialog);
		if (_tmp0 == GTK_RESPONSE_YES)
		do {
#line 210 "document.vala"
			valide_document_save (self);
#line 211 "document.vala"
			break;
		} while (0); else if (_tmp0 == GTK_RESPONSE_NO)
		do {
#line 213 "document.vala"
			break;
		} while (0); else if (_tmp0 == GTK_RESPONSE_CANCEL)
		do {
#line 215 "document.vala"
			is_close = FALSE;
#line 216 "document.vala"
			break;
		} while (0);
#line 218 "document.vala"
		gtk_object_destroy (GTK_OBJECT (dialog));
		(dialog == NULL ? NULL : (dialog = (g_object_unref (dialog), NULL)));
		(label == NULL ? NULL : (label = (g_object_unref (label), NULL)));
	}
#line 220 "document.vala"
	if (is_close) {
#line 222 "document.vala"
		gtk_object_destroy (GTK_OBJECT (self));
	}
#line 224 "document.vala"
	return is_close;
}


#line 227 "document.vala"
void valide_document_undo (ValideDocument* self) {
#line 227 "document.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT (self));
#line 229 "document.vala"
	gtk_source_buffer_undo ((GTK_SOURCE_BUFFER (self->buffer)));
}


#line 232 "document.vala"
void valide_document_redo (ValideDocument* self) {
#line 232 "document.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT (self));
#line 234 "document.vala"
	gtk_source_buffer_redo ((GTK_SOURCE_BUFFER (self->buffer)));
}


#line 237 "document.vala"
void valide_document_copy (ValideDocument* self) {
	GtkClipboard* clipboard;
	GtkClipboard* _tmp1;
	GtkClipboard* _tmp0;
#line 237 "document.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT (self));
	clipboard = NULL;
	_tmp1 = NULL;
#line 241 "document.vala"
	_tmp0 = NULL;
#line 241 "document.vala"
	clipboard = (_tmp1 = (_tmp0 = gtk_widget_get_clipboard (GTK_WIDGET (self->priv->text_view), GDK_SELECTION_CLIPBOARD), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (clipboard == NULL ? NULL : (clipboard = (g_object_unref (clipboard), NULL))), _tmp1);
#line 242 "document.vala"
	gtk_text_buffer_copy_clipboard (self->buffer, clipboard);
	(clipboard == NULL ? NULL : (clipboard = (g_object_unref (clipboard), NULL)));
}


#line 245 "document.vala"
void valide_document_cut (ValideDocument* self) {
	GtkClipboard* clipboard;
	GtkClipboard* _tmp1;
	GtkClipboard* _tmp0;
#line 245 "document.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT (self));
	clipboard = NULL;
	_tmp1 = NULL;
#line 249 "document.vala"
	_tmp0 = NULL;
#line 249 "document.vala"
	clipboard = (_tmp1 = (_tmp0 = gtk_widget_get_clipboard (GTK_WIDGET (self->priv->text_view), GDK_SELECTION_CLIPBOARD), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (clipboard == NULL ? NULL : (clipboard = (g_object_unref (clipboard), NULL))), _tmp1);
#line 250 "document.vala"
	gtk_text_buffer_cut_clipboard (self->buffer, clipboard, TRUE);
	(clipboard == NULL ? NULL : (clipboard = (g_object_unref (clipboard), NULL)));
}


#line 253 "document.vala"
void valide_document_paste (ValideDocument* self) {
	GtkClipboard* clipboard;
	GtkClipboard* _tmp1;
	GtkClipboard* _tmp0;
#line 253 "document.vala"
	g_return_if_fail (VALIDE_IS_DOCUMENT (self));
	clipboard = NULL;
	_tmp1 = NULL;
#line 257 "document.vala"
	_tmp0 = NULL;
#line 257 "document.vala"
	clipboard = (_tmp1 = (_tmp0 = gtk_widget_get_clipboard (GTK_WIDGET (self->priv->text_view), GDK_SELECTION_CLIPBOARD), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (clipboard == NULL ? NULL : (clipboard = (g_object_unref (clipboard), NULL))), _tmp1);
#line 258 "document.vala"
	gtk_text_buffer_paste_clipboard (self->buffer, clipboard, NULL, TRUE);
	(clipboard == NULL ? NULL : (clipboard = (g_object_unref (clipboard), NULL)));
}


gboolean valide_document_get_is_save (ValideDocument* self) {
	g_return_val_if_fail (VALIDE_IS_DOCUMENT (self), FALSE);
#line 49 "document.vala"
	return self->priv->save_;
}


void valide_document_set_is_save (ValideDocument* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_DOCUMENT (self));
#line 53 "document.vala"
	self->priv->save_ = value;
#line 54 "document.vala"
	g_signal_emit_by_name (G_OBJECT (self), "title-change");
}


const char* valide_document_get_path (ValideDocument* self) {
	g_return_val_if_fail (VALIDE_IS_DOCUMENT (self), NULL);
#line 65 "document.vala"
	return self->priv->path_;
}


void valide_document_set_path (ValideDocument* self, const char* value) {
	GError * inner_error;
	g_return_if_fail (VALIDE_IS_DOCUMENT (self));
	inner_error = NULL;
#line 69 "document.vala"
	if (value != NULL && self->priv->path_ == NULL) {
		char* contents;
		GtkTextIter iter = {0};
		contents = NULL;
		{
			gboolean _tmp2;
			char* _tmp1;
			char* _tmp4;
			const char* _tmp3;
			_tmp1 = NULL;
#line 76 "document.vala"
			_tmp2 = g_file_get_contents (value, &_tmp1, NULL, &inner_error);
#line 76 "document.vala"
			(contents = (g_free (contents), NULL));
#line 76 "document.vala"
			contents = _tmp1;
#line 76 "document.vala"
			_tmp2;
			if (inner_error != NULL) {
				goto __catch3_g_error;
			}
#line 77 "document.vala"
			gtk_text_buffer_get_start_iter (self->buffer, &iter);
#line 78 "document.vala"
			gtk_text_buffer_insert (self->buffer, &iter, contents, -1);
			_tmp4 = NULL;
#line 79 "document.vala"
			_tmp3 = NULL;
#line 79 "document.vala"
			self->priv->path_ = (_tmp4 = (_tmp3 = value, (_tmp3 == NULL ? NULL : g_strdup (_tmp3))), (self->priv->path_ = (g_free (self->priv->path_), NULL)), _tmp4);
#line 80 "document.vala"
			valide_document_set_is_save (self, TRUE);
		}
		goto __finally3;
		__catch3_g_error:
		{
			GError * e;
			e = inner_error;
			inner_error = NULL;
			{
#line 84 "document.vala"
				g_critical (e->message);
			}
		}
		__finally3:
		;
		contents = (g_free (contents), NULL);
	} else {
		char* _tmp6;
		const char* _tmp5;
		_tmp6 = NULL;
#line 89 "document.vala"
		_tmp5 = NULL;
#line 89 "document.vala"
		self->priv->path_ = (_tmp6 = (_tmp5 = value, (_tmp5 == NULL ? NULL : g_strdup (_tmp5))), (self->priv->path_ = (g_free (self->priv->path_), NULL)), _tmp6);
#line 90 "document.vala"
		valide_document_set_is_save (self, FALSE);
	}
}


static GObject * valide_document_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	ValideDocumentClass * klass;
	GObjectClass * parent_class;
	ValideDocument * self;
	klass = VALIDE_DOCUMENT_CLASS (g_type_class_peek (VALIDE_TYPE_DOCUMENT));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = VALIDE_DOCUMENT (obj);
	{
		ValideSourceView* _tmp0;
		GtkTextBuffer* _tmp2;
		GtkTextBuffer* _tmp1;
#line 131 "document.vala"
		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (self), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
		_tmp0 = NULL;
#line 132 "document.vala"
		self->priv->text_view = (_tmp0 = g_object_ref_sink (valide_source_view_new ()), (self->priv->text_view == NULL ? NULL : (self->priv->text_view = (g_object_unref (self->priv->text_view), NULL))), _tmp0);
#line 133 "document.vala"
		gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (self->priv->text_view));
		_tmp2 = NULL;
#line 134 "document.vala"
		_tmp1 = NULL;
#line 134 "document.vala"
		self->buffer = (_tmp2 = (_tmp1 = gtk_text_view_get_buffer (GTK_TEXT_VIEW (self->priv->text_view)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->buffer == NULL ? NULL : (self->buffer = (g_object_unref (self->buffer), NULL))), _tmp2);
	}
	return obj;
}


static void valide_document_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValideDocument * self;
	self = VALIDE_DOCUMENT (object);
	switch (property_id) {
		case VALIDE_DOCUMENT_IS_SAVE:
		g_value_set_boolean (value, valide_document_get_is_save (self));
		break;
		case VALIDE_DOCUMENT_PATH:
		g_value_set_string (value, valide_document_get_path (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_document_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValideDocument * self;
	self = VALIDE_DOCUMENT (object);
	switch (property_id) {
		case VALIDE_DOCUMENT_IS_SAVE:
		valide_document_set_is_save (self, g_value_get_boolean (value));
		break;
		case VALIDE_DOCUMENT_PATH:
		valide_document_set_path (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_document_class_init (ValideDocumentClass * klass) {
	valide_document_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideDocumentPrivate));
	G_OBJECT_CLASS (klass)->get_property = valide_document_get_property;
	G_OBJECT_CLASS (klass)->set_property = valide_document_set_property;
	G_OBJECT_CLASS (klass)->constructor = valide_document_constructor;
	G_OBJECT_CLASS (klass)->dispose = valide_document_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_DOCUMENT_IS_SAVE, g_param_spec_boolean ("is-save", "is-save", "is-save", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_DOCUMENT_PATH, g_param_spec_string ("path", "path", "path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_signal_new ("title_change", VALIDE_TYPE_DOCUMENT, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}


static void valide_document_init (ValideDocument * self) {
	self->priv = VALIDE_DOCUMENT_GET_PRIVATE (self);
}


static void valide_document_dispose (GObject * obj) {
	ValideDocument * self;
	self = VALIDE_DOCUMENT (obj);
	(self->buffer == NULL ? NULL : (self->buffer = (g_object_unref (self->buffer), NULL)));
	(self->priv->text_view == NULL ? NULL : (self->priv->text_view = (g_object_unref (self->priv->text_view), NULL)));
	self->priv->path_ = (g_free (self->priv->path_), NULL);
	self->priv->filename_ = (g_free (self->priv->filename_), NULL);
	G_OBJECT_CLASS (valide_document_parent_class)->dispose (obj);
}


GType valide_document_get_type (void) {
	static GType valide_document_type_id = 0;
	if (G_UNLIKELY (valide_document_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideDocumentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_document_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideDocument), 0, (GInstanceInitFunc) valide_document_init };
		valide_document_type_id = g_type_register_static (GTK_TYPE_SCROLLED_WINDOW, "ValideDocument", &g_define_type_info, 0);
	}
	return valide_document_type_id;
}




