/* document.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#ifndef __SRC_DOCUMENT_H__
#define __SRC_DOCUMENT_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS


#define VALIDE_TYPE_DOCUMENT (valide_document_get_type ())
#define VALIDE_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALIDE_TYPE_DOCUMENT, ValideDocument))
#define VALIDE_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALIDE_TYPE_DOCUMENT, ValideDocumentClass))
#define VALIDE_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALIDE_TYPE_DOCUMENT))
#define VALIDE_IS_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALIDE_TYPE_DOCUMENT))
#define VALIDE_DOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALIDE_TYPE_DOCUMENT, ValideDocumentClass))

typedef struct _ValideDocument ValideDocument;
typedef struct _ValideDocumentClass ValideDocumentClass;
typedef struct _ValideDocumentPrivate ValideDocumentPrivate;

struct _ValideDocument {
	GtkScrolledWindow parent_instance;
	ValideDocumentPrivate * priv;
	GtkTextBuffer* buffer;
};

struct _ValideDocumentClass {
	GtkScrolledWindowClass parent_class;
};


#define VALIDE_DOCUMENT_FILE_EXT ".vala"
ValideDocument* valide_document_new (const char* path);
void valide_document_save (ValideDocument* self);
void valide_document_save_as (ValideDocument* self);
gboolean valide_document_close (ValideDocument* self);
void valide_document_undo (ValideDocument* self);
void valide_document_redo (ValideDocument* self);
void valide_document_copy (ValideDocument* self);
void valide_document_cut (ValideDocument* self);
void valide_document_paste (ValideDocument* self);
gboolean valide_document_get_is_save (ValideDocument* self);
void valide_document_set_is_save (ValideDocument* self, gboolean value);
const char* valide_document_get_path (ValideDocument* self);
void valide_document_set_path (ValideDocument* self, const char* value);
GType valide_document_get_type (void);


G_END_DECLS

#endif
