/* project-dialog-options.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/project-dialog-options.h>
#include <stdlib.h>
#include <string.h>
#include <gdk-pixbuf/gdk-pixdata.h>
#include <config.h>
#include <glib/gi18n-lib.h>


#define TYPE_FRAME_GENERAL (frame_general_get_type ())
#define FRAME_GENERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FRAME_GENERAL, FrameGeneral))
#define FRAME_GENERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FRAME_GENERAL, FrameGeneralClass))
#define IS_FRAME_GENERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FRAME_GENERAL))
#define IS_FRAME_GENERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FRAME_GENERAL))
#define FRAME_GENERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FRAME_GENERAL, FrameGeneralClass))

typedef struct _FrameGeneral FrameGeneral;
typedef struct _FrameGeneralClass FrameGeneralClass;
typedef struct _FrameGeneralPrivate FrameGeneralPrivate;

#define TYPE_FRAME_LIST (frame_list_get_type ())
#define FRAME_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FRAME_LIST, FrameList))
#define FRAME_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FRAME_LIST, FrameListClass))
#define IS_FRAME_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FRAME_LIST))
#define IS_FRAME_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FRAME_LIST))
#define FRAME_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FRAME_LIST, FrameListClass))

typedef struct _FrameList FrameList;
typedef struct _FrameListClass FrameListClass;
typedef struct _FrameListPrivate FrameListPrivate;

#define TYPE_FRAME_PKG (frame_pkg_get_type ())
#define FRAME_PKG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FRAME_PKG, FramePkg))
#define FRAME_PKG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FRAME_PKG, FramePkgClass))
#define IS_FRAME_PKG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FRAME_PKG))
#define IS_FRAME_PKG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FRAME_PKG))
#define FRAME_PKG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FRAME_PKG, FramePkgClass))

typedef struct _FramePkg FramePkg;
typedef struct _FramePkgClass FramePkgClass;
typedef struct _FramePkgPrivate FramePkgPrivate;

#define TYPE_FRAME_VAPI (frame_vapi_get_type ())
#define FRAME_VAPI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FRAME_VAPI, FrameVapi))
#define FRAME_VAPI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FRAME_VAPI, FrameVapiClass))
#define IS_FRAME_VAPI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FRAME_VAPI))
#define IS_FRAME_VAPI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FRAME_VAPI))
#define FRAME_VAPI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FRAME_VAPI, FrameVapiClass))

typedef struct _FrameVapi FrameVapi;
typedef struct _FrameVapiClass FrameVapiClass;
typedef struct _FrameVapiPrivate FrameVapiPrivate;

struct _FrameGeneral {
	GtkVBox parent_instance;
	FrameGeneralPrivate * priv;
};

struct _FrameGeneralClass {
	GtkVBoxClass parent_class;
};

struct _FrameList {
	GtkFrame parent_instance;
	FrameListPrivate * priv;
};

struct _FrameListClass {
	GtkFrameClass parent_class;
};

/**
 * @todo Grab focus for entry
 */
struct _FramePkg {
	FrameList parent_instance;
	FramePkgPrivate * priv;
};

struct _FramePkgClass {
	FrameListClass parent_class;
};

struct _FrameVapi {
	FrameList parent_instance;
	FrameVapiPrivate * priv;
};

struct _FrameVapiClass {
	FrameListClass parent_class;
};



struct _ValideProjectDialogOptionsPrivate {
	ValideProject* project_;
	GtkNotebook* notebook;
	FrameGeneral* frame_general;
	FramePkg* frame_pkg;
	FrameVapi* frame_vapi;
};

#define VALIDE_PROJECT_DIALOG_OPTIONS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_PROJECT_DIALOG_OPTIONS, ValideProjectDialogOptionsPrivate))
enum  {
	VALIDE_PROJECT_DIALOG_OPTIONS_DUMMY_PROPERTY,
	VALIDE_PROJECT_DIALOG_OPTIONS_PKG,
	VALIDE_PROJECT_DIALOG_OPTIONS_VAPI_DIR,
	VALIDE_PROJECT_DIALOG_OPTIONS_DEBUG,
	VALIDE_PROJECT_DIALOG_OPTIONS_THREAD,
	VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_ASSERT,
	VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_CHECKING,
	VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_NON_NULL,
	VALIDE_PROJECT_DIALOG_OPTIONS_SAVE_TEMPS,
	VALIDE_PROJECT_DIALOG_OPTIONS_QUIET,
	VALIDE_PROJECT_DIALOG_OPTIONS_VERBOSE,
	VALIDE_PROJECT_DIALOG_OPTIONS_PROJECT
};
static void __lambda0 (GtkIconView* sender, ValideProjectDialogOptions* self);
static void ___lambda0_gtk_icon_view_selection_changed (GtkIconView* sender, gpointer self);
static GObject * valide_project_dialog_options_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer valide_project_dialog_options_parent_class = NULL;
static void valide_project_dialog_options_dispose (GObject * obj);
struct _FrameGeneralPrivate {
	GtkCheckButton* debug_btn;
	GtkCheckButton* thread_btn;
	GtkCheckButton* disable_assert_btn;
	GtkCheckButton* disable_checking_btn;
	GtkCheckButton* disable_non_null_btn;
	GtkCheckButton* save_temps_btn;
	GtkCheckButton* quiet_btn;
	GtkCheckButton* verbose_btn;
};

#define FRAME_GENERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_FRAME_GENERAL, FrameGeneralPrivate))
enum  {
	FRAME_GENERAL_DUMMY_PROPERTY,
	FRAME_GENERAL_DEBUG,
	FRAME_GENERAL_THREAD,
	FRAME_GENERAL_DISABLE_ASSERT,
	FRAME_GENERAL_DISABLE_CHECKING,
	FRAME_GENERAL_DISABLE_NON_NULL,
	FRAME_GENERAL_SAVE_TEMPS,
	FRAME_GENERAL_QUIET,
	FRAME_GENERAL_VERBOSE
};
static FrameGeneral* frame_general_new (void);
static gboolean frame_general_get_debug (FrameGeneral* self);
static void frame_general_set_debug (FrameGeneral* self, gboolean value);
static gboolean frame_general_get_thread (FrameGeneral* self);
static void frame_general_set_thread (FrameGeneral* self, gboolean value);
static gboolean frame_general_get_disable_assert (FrameGeneral* self);
static void frame_general_set_disable_assert (FrameGeneral* self, gboolean value);
static gboolean frame_general_get_disable_checking (FrameGeneral* self);
static void frame_general_set_disable_checking (FrameGeneral* self, gboolean value);
static gboolean frame_general_get_disable_non_null (FrameGeneral* self);
static void frame_general_set_disable_non_null (FrameGeneral* self, gboolean value);
static gboolean frame_general_get_save_temps (FrameGeneral* self);
static void frame_general_set_save_temps (FrameGeneral* self, gboolean value);
static gboolean frame_general_get_quiet (FrameGeneral* self);
static void frame_general_set_quiet (FrameGeneral* self, gboolean value);
static gboolean frame_general_get_verbose (FrameGeneral* self);
static void frame_general_set_verbose (FrameGeneral* self, gboolean value);
static GObject * frame_general_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer frame_general_parent_class = NULL;
static void frame_general_dispose (GObject * obj);
static GType frame_general_get_type (void);
struct _FrameListPrivate {
	GtkTreeView* tree_view;
	GtkListStore* list_store;
	GtkEntry* entry;
};

#define FRAME_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_FRAME_LIST, FrameListPrivate))
enum  {
	FRAME_LIST_DUMMY_PROPERTY,
	FRAME_LIST_ITEMS
};
static GtkScrolledWindow* frame_list_create_tree_view (FrameList* self, GList* pkg);
static FrameList* frame_list_new (void);
static void _g_list_free_g_free (GList* self);
static GList* frame_list_get_items (FrameList* self);
static void frame_list_set_items (FrameList* self, GList* value);
static void __lambda1 (FrameList* self);
static void ___lambda1_gtk_button_clicked (GtkButton* sender, gpointer self);
static void __lambda2 (FrameList* self);
static void ___lambda2_gtk_button_clicked (GtkButton* sender, gpointer self);
static GObject * frame_list_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer frame_list_parent_class = NULL;
static void frame_list_dispose (GObject * obj);
static GType frame_list_get_type (void);
enum  {
	FRAME_PKG_DUMMY_PROPERTY
};
static FramePkg* frame_pkg_new (void);
static gpointer frame_pkg_parent_class = NULL;
static GType frame_pkg_get_type (void);
enum  {
	FRAME_VAPI_DUMMY_PROPERTY
};
static FrameVapi* frame_vapi_new (void);
static gpointer frame_vapi_parent_class = NULL;
static GType frame_vapi_get_type (void);



#line 115 "project-dialog-options.vala"
ValideProjectDialogOptions* valide_project_dialog_options_new (ValideProject* project) {
	ValideProjectDialogOptions * self;
	gint _tmp0;
	gint _tmp1;
#line 115 "project-dialog-options.vala"
	g_return_val_if_fail (VALIDE_IS_PROJECT (project), NULL);
	self = g_object_newv (VALIDE_TYPE_PROJECT_DIALOG_OPTIONS, 0, NULL);
#line 117 "project-dialog-options.vala"
	valide_project_dialog_options_set_project (self, project);
#line 118 "project-dialog-options.vala"
	g_object_set (GTK_WINDOW (self), "default-height", 600, NULL);
#line 119 "project-dialog-options.vala"
	g_object_set (GTK_WINDOW (self), "default-width", 800, NULL);
	return self;
}


GList* valide_project_dialog_options_get_pkg (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), NULL);
#line 35 "project-dialog-options.vala"
	return frame_list_get_items (FRAME_LIST (self->priv->frame_pkg));
}


void valide_project_dialog_options_set_pkg (ValideProjectDialogOptions* self, GList* value) {
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
#line 36 "project-dialog-options.vala"
	frame_list_set_items (FRAME_LIST (self->priv->frame_pkg), value);
}


GList* valide_project_dialog_options_get_vapi_dir (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), NULL);
#line 41 "project-dialog-options.vala"
	return frame_list_get_items (FRAME_LIST (self->priv->frame_vapi));
}


void valide_project_dialog_options_set_vapi_dir (ValideProjectDialogOptions* self, GList* value) {
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
#line 42 "project-dialog-options.vala"
	frame_list_set_items (FRAME_LIST (self->priv->frame_vapi), value);
}


gboolean valide_project_dialog_options_get_debug (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), FALSE);
#line 47 "project-dialog-options.vala"
	return frame_general_get_debug (self->priv->frame_general);
}


void valide_project_dialog_options_set_debug (ValideProjectDialogOptions* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
#line 48 "project-dialog-options.vala"
	frame_general_set_debug (self->priv->frame_general, value);
}


gboolean valide_project_dialog_options_get_thread (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), FALSE);
#line 53 "project-dialog-options.vala"
	return frame_general_get_thread (self->priv->frame_general);
}


void valide_project_dialog_options_set_thread (ValideProjectDialogOptions* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
#line 54 "project-dialog-options.vala"
	frame_general_set_thread (self->priv->frame_general, value);
}


gboolean valide_project_dialog_options_get_disable_assert (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), FALSE);
#line 59 "project-dialog-options.vala"
	return frame_general_get_disable_assert (self->priv->frame_general);
}


void valide_project_dialog_options_set_disable_assert (ValideProjectDialogOptions* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
#line 60 "project-dialog-options.vala"
	frame_general_set_disable_assert (self->priv->frame_general, value);
}


gboolean valide_project_dialog_options_get_disable_checking (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), FALSE);
#line 65 "project-dialog-options.vala"
	return frame_general_get_disable_checking (self->priv->frame_general);
}


void valide_project_dialog_options_set_disable_checking (ValideProjectDialogOptions* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
#line 66 "project-dialog-options.vala"
	frame_general_set_disable_checking (self->priv->frame_general, value);
}


gboolean valide_project_dialog_options_get_disable_non_null (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), FALSE);
#line 71 "project-dialog-options.vala"
	return frame_general_get_disable_non_null (self->priv->frame_general);
}


void valide_project_dialog_options_set_disable_non_null (ValideProjectDialogOptions* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
#line 72 "project-dialog-options.vala"
	frame_general_set_disable_non_null (self->priv->frame_general, value);
}


gboolean valide_project_dialog_options_get_save_temps (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), FALSE);
#line 77 "project-dialog-options.vala"
	return frame_general_get_save_temps (self->priv->frame_general);
}


void valide_project_dialog_options_set_save_temps (ValideProjectDialogOptions* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
#line 78 "project-dialog-options.vala"
	frame_general_set_save_temps (self->priv->frame_general, value);
}


gboolean valide_project_dialog_options_get_quiet (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), FALSE);
#line 83 "project-dialog-options.vala"
	return frame_general_get_quiet (self->priv->frame_general);
}


void valide_project_dialog_options_set_quiet (ValideProjectDialogOptions* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
#line 84 "project-dialog-options.vala"
	frame_general_set_quiet (self->priv->frame_general, value);
}


gboolean valide_project_dialog_options_get_verbose (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), FALSE);
#line 89 "project-dialog-options.vala"
	return frame_general_get_verbose (self->priv->frame_general);
}


void valide_project_dialog_options_set_verbose (ValideProjectDialogOptions* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
#line 90 "project-dialog-options.vala"
	frame_general_set_verbose (self->priv->frame_general, value);
}


ValideProject* valide_project_dialog_options_get_project (ValideProjectDialogOptions* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self), NULL);
#line 97 "project-dialog-options.vala"
	return self->priv->project_;
}


void valide_project_dialog_options_set_project (ValideProjectDialogOptions* self, ValideProject* value) {
	ValideProject* _tmp2;
	ValideProject* _tmp1;
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_OPTIONS (self));
	_tmp2 = NULL;
#line 101 "project-dialog-options.vala"
	_tmp1 = NULL;
#line 101 "project-dialog-options.vala"
	self->priv->project_ = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->project_ == NULL ? NULL : (self->priv->project_ = (g_object_unref (self->priv->project_), NULL))), _tmp2);
#line 102 "project-dialog-options.vala"
	valide_project_dialog_options_set_pkg (self, valide_project_get_pkg (valide_project_dialog_options_get_project (self)));
#line 103 "project-dialog-options.vala"
	valide_project_dialog_options_set_vapi_dir (self, valide_project_get_vapi_dir (valide_project_dialog_options_get_project (self)));
#line 104 "project-dialog-options.vala"
	valide_project_dialog_options_set_debug (self, valide_project_get_debug (valide_project_dialog_options_get_project (self)));
#line 105 "project-dialog-options.vala"
	valide_project_dialog_options_set_thread (self, valide_project_get_thread (valide_project_dialog_options_get_project (self)));
#line 106 "project-dialog-options.vala"
	valide_project_dialog_options_set_disable_assert (self, valide_project_get_disable_assert (valide_project_dialog_options_get_project (self)));
#line 107 "project-dialog-options.vala"
	valide_project_dialog_options_set_disable_checking (self, valide_project_get_disable_checking (valide_project_dialog_options_get_project (self)));
#line 108 "project-dialog-options.vala"
	valide_project_dialog_options_set_disable_non_null (self, valide_project_get_disable_non_null (valide_project_dialog_options_get_project (self)));
#line 109 "project-dialog-options.vala"
	valide_project_dialog_options_set_save_temps (self, valide_project_get_save_temps (valide_project_dialog_options_get_project (self)));
#line 110 "project-dialog-options.vala"
	valide_project_dialog_options_set_quiet (self, valide_project_get_quiet (valide_project_dialog_options_get_project (self)));
#line 111 "project-dialog-options.vala"
	valide_project_dialog_options_set_verbose (self, valide_project_get_verbose (valide_project_dialog_options_get_project (self)));
}


static void __lambda0 (GtkIconView* sender, ValideProjectDialogOptions* self) {
	GList* onglets;
	g_return_if_fail (GTK_IS_ICON_VIEW (sender));
	onglets = gtk_icon_view_get_selected_items (sender);
#line 174 "project-dialog-options.vala"
	if (onglets != NULL) {
		gint index;
		GtkTreeIter iter = {0};
		index = 0;
#line 179 "project-dialog-options.vala"
		gtk_tree_model_get_iter (gtk_icon_view_get_model (sender), &iter, ((GtkTreePath*) onglets->data));
#line 180 "project-dialog-options.vala"
		gtk_tree_model_get (gtk_icon_view_get_model (sender), &iter, 2, &index, -1, -1);
#line 181 "project-dialog-options.vala"
		gtk_notebook_set_current_page (self->priv->notebook, index);
	}
}


static void ___lambda0_gtk_icon_view_selection_changed (GtkIconView* sender, gpointer self) {
	__lambda0 (sender, self);
}


static GObject * valide_project_dialog_options_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	ValideProjectDialogOptionsClass * klass;
	GObjectClass * parent_class;
	ValideProjectDialogOptions * self;
	GError * inner_error;
	klass = VALIDE_PROJECT_DIALOG_OPTIONS_CLASS (g_type_class_peek (VALIDE_TYPE_PROJECT_DIALOG_OPTIONS));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = VALIDE_PROJECT_DIALOG_OPTIONS (obj);
	inner_error = NULL;
	{
		GtkVBox* main_box;
		GtkHBox* hbox;
		GtkScrolledWindow* scrolled_window;
		GtkIconView* icon_view;
		GtkListStore* list_store;
		GtkTreeIter iter = {0};
		GtkNotebook* _tmp0;
		GtkTreePath* _tmp10;
#line 124 "project-dialog-options.vala"
		gtk_dialog_add_button (GTK_DIALOG (self), GTK_STOCK_OK, ((gint) GTK_RESPONSE_ACCEPT));
#line 125 "project-dialog-options.vala"
		gtk_dialog_add_button (GTK_DIALOG (self), GTK_STOCK_CANCEL, ((gint) GTK_RESPONSE_CANCEL));
		main_box = GTK_VBOX (GTK_DIALOG (self)->vbox);
		hbox = g_object_ref_sink (gtk_hbox_new (FALSE, 0));
#line 130 "project-dialog-options.vala"
		gtk_box_pack_start (GTK_BOX (main_box), GTK_WIDGET (hbox), TRUE, TRUE, ((guint) 0));
		scrolled_window = g_object_ref_sink (gtk_scrolled_window_new (NULL, NULL));
#line 133 "project-dialog-options.vala"
		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (scrolled_window), FALSE, TRUE, ((guint) 0));
#line 134 "project-dialog-options.vala"
		gtk_scrolled_window_set_policy (scrolled_window, GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
		icon_view = g_object_ref_sink (gtk_icon_view_new ());
#line 137 "project-dialog-options.vala"
		gtk_container_add (GTK_CONTAINER (scrolled_window), GTK_WIDGET (icon_view));
		list_store = gtk_list_store_new (3, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_INT, NULL);
#line 142 "project-dialog-options.vala"
		gtk_icon_view_set_pixbuf_column (icon_view, 0);
#line 143 "project-dialog-options.vala"
		gtk_icon_view_set_text_column (icon_view, 1);
#line 144 "project-dialog-options.vala"
		gtk_icon_view_set_model (icon_view, GTK_TREE_MODEL (list_store));
#line 145 "project-dialog-options.vala"
		gtk_icon_view_set_item_width (icon_view, 80);
		_tmp0 = NULL;
#line 148 "project-dialog-options.vala"
		self->priv->notebook = (_tmp0 = g_object_ref_sink (gtk_notebook_new ()), (self->priv->notebook == NULL ? NULL : (self->priv->notebook = (g_object_unref (self->priv->notebook), NULL))), _tmp0);
#line 149 "project-dialog-options.vala"
		gtk_notebook_set_show_tabs (self->priv->notebook, FALSE);
#line 150 "project-dialog-options.vala"
		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->notebook), TRUE, TRUE, ((guint) 0));
		{
			char* _tmp1;
			GdkPixbuf* _tmp2;
			GdkPixbuf* icon;
			FrameGeneral* _tmp3;
			GtkLabel* _tmp4;
#line 153 "project-dialog-options.vala"
			gtk_list_store_append (list_store, &iter);
#line 154 "project-dialog-options.vala"
			_tmp1 = NULL;
#line 154 "project-dialog-options.vala"
			_tmp2 = NULL;
			icon = (_tmp2 = gdk_pixbuf_new_from_file ((_tmp1 = g_build_filename (PACKAGE_PIXMAPS_DIR, "pref-general.png", NULL)), &inner_error), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
			if (inner_error != NULL) {
				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
				g_clear_error (&inner_error);
			}
#line 155 "project-dialog-options.vala"
			gtk_list_store_set (list_store, &iter, 0, icon, 1, _ ("General"), 2, 0, -1, -1);
			_tmp3 = NULL;
#line 156 "project-dialog-options.vala"
			self->priv->frame_general = (_tmp3 = g_object_ref_sink (frame_general_new ()), (self->priv->frame_general == NULL ? NULL : (self->priv->frame_general = (g_object_unref (self->priv->frame_general), NULL))), _tmp3);
#line 157 "project-dialog-options.vala"
			_tmp4 = NULL;
#line 157 "project-dialog-options.vala"
			gtk_notebook_append_page (self->priv->notebook, GTK_WIDGET (self->priv->frame_general), GTK_WIDGET ((_tmp4 = g_object_ref_sink (gtk_label_new (_ ("General"))))));
			(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
			(icon == NULL ? NULL : (icon = (g_object_unref (icon), NULL)));
		}
		{
			char* _tmp5;
			GdkPixbuf* _tmp6;
			GdkPixbuf* icon;
			FramePkg* _tmp7;
			FrameVapi* _tmp8;
			GtkVBox* vbox;
			GtkLabel* _tmp9;
#line 160 "project-dialog-options.vala"
			gtk_list_store_append (list_store, &iter);
#line 161 "project-dialog-options.vala"
			_tmp5 = NULL;
#line 161 "project-dialog-options.vala"
			_tmp6 = NULL;
			icon = (_tmp6 = gdk_pixbuf_new_from_file ((_tmp5 = g_build_filename (PACKAGE_PIXMAPS_DIR, "pref-pkg.png", NULL)), &inner_error), (_tmp5 = (g_free (_tmp5), NULL)), _tmp6);
			if (inner_error != NULL) {
				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
				g_clear_error (&inner_error);
			}
#line 162 "project-dialog-options.vala"
			gtk_list_store_set (list_store, &iter, 0, icon, 1, _ ("Packages"), 2, 1, -1, -1);
			_tmp7 = NULL;
#line 163 "project-dialog-options.vala"
			self->priv->frame_pkg = (_tmp7 = g_object_ref_sink (frame_pkg_new ()), (self->priv->frame_pkg == NULL ? NULL : (self->priv->frame_pkg = (g_object_unref (self->priv->frame_pkg), NULL))), _tmp7);
			_tmp8 = NULL;
#line 164 "project-dialog-options.vala"
			self->priv->frame_vapi = (_tmp8 = g_object_ref_sink (frame_vapi_new ()), (self->priv->frame_vapi == NULL ? NULL : (self->priv->frame_vapi = (g_object_unref (self->priv->frame_vapi), NULL))), _tmp8);
			vbox = g_object_ref_sink (gtk_vbox_new (TRUE, 10));
#line 167 "project-dialog-options.vala"
			gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (self->priv->frame_pkg), TRUE, TRUE, ((guint) 0));
#line 168 "project-dialog-options.vala"
			gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (self->priv->frame_vapi), TRUE, TRUE, ((guint) 0));
#line 169 "project-dialog-options.vala"
			_tmp9 = NULL;
#line 169 "project-dialog-options.vala"
			gtk_notebook_append_page (self->priv->notebook, GTK_WIDGET (vbox), GTK_WIDGET ((_tmp9 = g_object_ref_sink (gtk_label_new (_ ("Packages"))))));
			(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
			(icon == NULL ? NULL : (icon = (g_object_unref (icon), NULL)));
			(vbox == NULL ? NULL : (vbox = (g_object_unref (vbox), NULL)));
		}
#line 172 "project-dialog-options.vala"
		g_signal_connect_object (icon_view, "selection-changed", ((GCallback) ___lambda0_gtk_icon_view_selection_changed), self, 0);
		/* Set first item */
#line 185 "project-dialog-options.vala"
		_tmp10 = NULL;
#line 185 "project-dialog-options.vala"
		gtk_icon_view_select_path (icon_view, (_tmp10 = gtk_tree_path_new_from_string ("0")));
		(_tmp10 == NULL ? NULL : (_tmp10 = (gtk_tree_path_free (_tmp10), NULL)));
		(hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL)));
		(scrolled_window == NULL ? NULL : (scrolled_window = (g_object_unref (scrolled_window), NULL)));
		(icon_view == NULL ? NULL : (icon_view = (g_object_unref (icon_view), NULL)));
		(list_store == NULL ? NULL : (list_store = (g_object_unref (list_store), NULL)));
	}
	return obj;
}


static void valide_project_dialog_options_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValideProjectDialogOptions * self;
	self = VALIDE_PROJECT_DIALOG_OPTIONS (object);
	switch (property_id) {
		case VALIDE_PROJECT_DIALOG_OPTIONS_PKG:
		g_value_set_pointer (value, valide_project_dialog_options_get_pkg (self));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_VAPI_DIR:
		g_value_set_pointer (value, valide_project_dialog_options_get_vapi_dir (self));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_DEBUG:
		g_value_set_boolean (value, valide_project_dialog_options_get_debug (self));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_THREAD:
		g_value_set_boolean (value, valide_project_dialog_options_get_thread (self));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_ASSERT:
		g_value_set_boolean (value, valide_project_dialog_options_get_disable_assert (self));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_CHECKING:
		g_value_set_boolean (value, valide_project_dialog_options_get_disable_checking (self));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_NON_NULL:
		g_value_set_boolean (value, valide_project_dialog_options_get_disable_non_null (self));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_SAVE_TEMPS:
		g_value_set_boolean (value, valide_project_dialog_options_get_save_temps (self));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_QUIET:
		g_value_set_boolean (value, valide_project_dialog_options_get_quiet (self));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_VERBOSE:
		g_value_set_boolean (value, valide_project_dialog_options_get_verbose (self));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_PROJECT:
		g_value_set_object (value, valide_project_dialog_options_get_project (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_project_dialog_options_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValideProjectDialogOptions * self;
	self = VALIDE_PROJECT_DIALOG_OPTIONS (object);
	switch (property_id) {
		case VALIDE_PROJECT_DIALOG_OPTIONS_PKG:
		valide_project_dialog_options_set_pkg (self, g_value_get_pointer (value));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_VAPI_DIR:
		valide_project_dialog_options_set_vapi_dir (self, g_value_get_pointer (value));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_DEBUG:
		valide_project_dialog_options_set_debug (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_THREAD:
		valide_project_dialog_options_set_thread (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_ASSERT:
		valide_project_dialog_options_set_disable_assert (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_CHECKING:
		valide_project_dialog_options_set_disable_checking (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_NON_NULL:
		valide_project_dialog_options_set_disable_non_null (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_SAVE_TEMPS:
		valide_project_dialog_options_set_save_temps (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_QUIET:
		valide_project_dialog_options_set_quiet (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_VERBOSE:
		valide_project_dialog_options_set_verbose (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DIALOG_OPTIONS_PROJECT:
		valide_project_dialog_options_set_project (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_project_dialog_options_class_init (ValideProjectDialogOptionsClass * klass) {
	valide_project_dialog_options_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideProjectDialogOptionsPrivate));
	G_OBJECT_CLASS (klass)->get_property = valide_project_dialog_options_get_property;
	G_OBJECT_CLASS (klass)->set_property = valide_project_dialog_options_set_property;
	G_OBJECT_CLASS (klass)->constructor = valide_project_dialog_options_constructor;
	G_OBJECT_CLASS (klass)->dispose = valide_project_dialog_options_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_PKG, g_param_spec_pointer ("pkg", "pkg", "pkg", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_VAPI_DIR, g_param_spec_pointer ("vapi-dir", "vapi-dir", "vapi-dir", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_DEBUG, g_param_spec_boolean ("debug", "debug", "debug", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_THREAD, g_param_spec_boolean ("thread", "thread", "thread", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_ASSERT, g_param_spec_boolean ("disable-assert", "disable-assert", "disable-assert", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_CHECKING, g_param_spec_boolean ("disable-checking", "disable-checking", "disable-checking", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_DISABLE_NON_NULL, g_param_spec_boolean ("disable-non-null", "disable-non-null", "disable-non-null", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_SAVE_TEMPS, g_param_spec_boolean ("save-temps", "save-temps", "save-temps", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_QUIET, g_param_spec_boolean ("quiet", "quiet", "quiet", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_VERBOSE, g_param_spec_boolean ("verbose", "verbose", "verbose", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_OPTIONS_PROJECT, g_param_spec_object ("project", "project", "project", VALIDE_TYPE_PROJECT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void valide_project_dialog_options_init (ValideProjectDialogOptions * self) {
	self->priv = VALIDE_PROJECT_DIALOG_OPTIONS_GET_PRIVATE (self);
}


static void valide_project_dialog_options_dispose (GObject * obj) {
	ValideProjectDialogOptions * self;
	self = VALIDE_PROJECT_DIALOG_OPTIONS (obj);
	(self->priv->project_ == NULL ? NULL : (self->priv->project_ = (g_object_unref (self->priv->project_), NULL)));
	(self->priv->notebook == NULL ? NULL : (self->priv->notebook = (g_object_unref (self->priv->notebook), NULL)));
	(self->priv->frame_general == NULL ? NULL : (self->priv->frame_general = (g_object_unref (self->priv->frame_general), NULL)));
	(self->priv->frame_pkg == NULL ? NULL : (self->priv->frame_pkg = (g_object_unref (self->priv->frame_pkg), NULL)));
	(self->priv->frame_vapi == NULL ? NULL : (self->priv->frame_vapi = (g_object_unref (self->priv->frame_vapi), NULL)));
	G_OBJECT_CLASS (valide_project_dialog_options_parent_class)->dispose (obj);
}


GType valide_project_dialog_options_get_type (void) {
	static GType valide_project_dialog_options_type_id = 0;
	if (G_UNLIKELY (valide_project_dialog_options_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideProjectDialogOptionsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_project_dialog_options_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideProjectDialogOptions), 0, (GInstanceInitFunc) valide_project_dialog_options_init };
		valide_project_dialog_options_type_id = g_type_register_static (GTK_TYPE_DIALOG, "ValideProjectDialogOptions", &g_define_type_info, 0);
	}
	return valide_project_dialog_options_type_id;
}


#line 189 "project-dialog-options.vala"
static FrameGeneral* frame_general_new (void) {
	FrameGeneral * self;
	self = g_object_newv (TYPE_FRAME_GENERAL, 0, NULL);
	return self;
}


static gboolean frame_general_get_debug (FrameGeneral* self) {
	g_return_val_if_fail (IS_FRAME_GENERAL (self), FALSE);
#line 202 "project-dialog-options.vala"
	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->priv->debug_btn));
}


static void frame_general_set_debug (FrameGeneral* self, gboolean value) {
	g_return_if_fail (IS_FRAME_GENERAL (self));
#line 203 "project-dialog-options.vala"
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->debug_btn), value);
}


static gboolean frame_general_get_thread (FrameGeneral* self) {
	g_return_val_if_fail (IS_FRAME_GENERAL (self), FALSE);
#line 208 "project-dialog-options.vala"
	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->priv->thread_btn));
}


static void frame_general_set_thread (FrameGeneral* self, gboolean value) {
	g_return_if_fail (IS_FRAME_GENERAL (self));
#line 209 "project-dialog-options.vala"
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->thread_btn), value);
}


static gboolean frame_general_get_disable_assert (FrameGeneral* self) {
	g_return_val_if_fail (IS_FRAME_GENERAL (self), FALSE);
#line 214 "project-dialog-options.vala"
	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->priv->disable_assert_btn));
}


static void frame_general_set_disable_assert (FrameGeneral* self, gboolean value) {
	g_return_if_fail (IS_FRAME_GENERAL (self));
#line 215 "project-dialog-options.vala"
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->disable_assert_btn), value);
}


static gboolean frame_general_get_disable_checking (FrameGeneral* self) {
	g_return_val_if_fail (IS_FRAME_GENERAL (self), FALSE);
#line 220 "project-dialog-options.vala"
	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->priv->disable_checking_btn));
}


static void frame_general_set_disable_checking (FrameGeneral* self, gboolean value) {
	g_return_if_fail (IS_FRAME_GENERAL (self));
#line 221 "project-dialog-options.vala"
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->disable_checking_btn), value);
}


static gboolean frame_general_get_disable_non_null (FrameGeneral* self) {
	g_return_val_if_fail (IS_FRAME_GENERAL (self), FALSE);
#line 226 "project-dialog-options.vala"
	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->priv->disable_non_null_btn));
}


static void frame_general_set_disable_non_null (FrameGeneral* self, gboolean value) {
	g_return_if_fail (IS_FRAME_GENERAL (self));
#line 227 "project-dialog-options.vala"
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->disable_non_null_btn), value);
}


static gboolean frame_general_get_save_temps (FrameGeneral* self) {
	g_return_val_if_fail (IS_FRAME_GENERAL (self), FALSE);
#line 232 "project-dialog-options.vala"
	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->priv->save_temps_btn));
}


static void frame_general_set_save_temps (FrameGeneral* self, gboolean value) {
	g_return_if_fail (IS_FRAME_GENERAL (self));
#line 233 "project-dialog-options.vala"
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->save_temps_btn), value);
}


static gboolean frame_general_get_quiet (FrameGeneral* self) {
	g_return_val_if_fail (IS_FRAME_GENERAL (self), FALSE);
#line 238 "project-dialog-options.vala"
	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->priv->quiet_btn));
}


static void frame_general_set_quiet (FrameGeneral* self, gboolean value) {
	g_return_if_fail (IS_FRAME_GENERAL (self));
#line 239 "project-dialog-options.vala"
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->quiet_btn), value);
}


static gboolean frame_general_get_verbose (FrameGeneral* self) {
	g_return_val_if_fail (IS_FRAME_GENERAL (self), FALSE);
#line 244 "project-dialog-options.vala"
	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->priv->verbose_btn));
}


static void frame_general_set_verbose (FrameGeneral* self, gboolean value) {
	g_return_if_fail (IS_FRAME_GENERAL (self));
#line 245 "project-dialog-options.vala"
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->verbose_btn), value);
}


static GObject * frame_general_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	FrameGeneralClass * klass;
	GObjectClass * parent_class;
	FrameGeneral * self;
	klass = FRAME_GENERAL_CLASS (g_type_class_peek (TYPE_FRAME_GENERAL));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = FRAME_GENERAL (obj);
	{
		GtkCheckButton* _tmp11;
		GtkCheckButton* _tmp12;
		GtkCheckButton* _tmp13;
		GtkCheckButton* _tmp14;
		GtkCheckButton* _tmp15;
		GtkCheckButton* _tmp16;
		GtkCheckButton* _tmp17;
		GtkCheckButton* _tmp18;
		_tmp11 = NULL;
#line 250 "project-dialog-options.vala"
		self->priv->debug_btn = (_tmp11 = g_object_ref_sink (gtk_check_button_new_with_label (_ ("Produce debug information"))), (self->priv->debug_btn == NULL ? NULL : (self->priv->debug_btn = (g_object_unref (self->priv->debug_btn), NULL))), _tmp11);
#line 251 "project-dialog-options.vala"
		gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (self->priv->debug_btn));
		_tmp12 = NULL;
#line 252 "project-dialog-options.vala"
		self->priv->thread_btn = (_tmp12 = g_object_ref_sink (gtk_check_button_new_with_label (_ ("Enable multithreading support"))), (self->priv->thread_btn == NULL ? NULL : (self->priv->thread_btn = (g_object_unref (self->priv->thread_btn), NULL))), _tmp12);
#line 253 "project-dialog-options.vala"
		gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (self->priv->thread_btn));
		_tmp13 = NULL;
#line 254 "project-dialog-options.vala"
		self->priv->disable_assert_btn = (_tmp13 = g_object_ref_sink (gtk_check_button_new_with_label (_ ("Disable assertions"))), (self->priv->disable_assert_btn == NULL ? NULL : (self->priv->disable_assert_btn = (g_object_unref (self->priv->disable_assert_btn), NULL))), _tmp13);
#line 255 "project-dialog-options.vala"
		gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (self->priv->disable_assert_btn));
		_tmp14 = NULL;
#line 256 "project-dialog-options.vala"
		self->priv->disable_checking_btn = (_tmp14 = g_object_ref_sink (gtk_check_button_new_with_label (_ ("Disable run-time checks"))), (self->priv->disable_checking_btn == NULL ? NULL : (self->priv->disable_checking_btn = (g_object_unref (self->priv->disable_checking_btn), NULL))), _tmp14);
#line 257 "project-dialog-options.vala"
		gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (self->priv->disable_checking_btn));
		_tmp15 = NULL;
#line 258 "project-dialog-options.vala"
		self->priv->disable_non_null_btn = (_tmp15 = g_object_ref_sink (gtk_check_button_new_with_label (_ ("Disable non-null types"))), (self->priv->disable_non_null_btn == NULL ? NULL : (self->priv->disable_non_null_btn = (g_object_unref (self->priv->disable_non_null_btn), NULL))), _tmp15);
#line 259 "project-dialog-options.vala"
		gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (self->priv->disable_non_null_btn));
		_tmp16 = NULL;
#line 260 "project-dialog-options.vala"
		self->priv->save_temps_btn = (_tmp16 = g_object_ref_sink (gtk_check_button_new_with_label (_ ("Keep temporary files"))), (self->priv->save_temps_btn == NULL ? NULL : (self->priv->save_temps_btn = (g_object_unref (self->priv->save_temps_btn), NULL))), _tmp16);
#line 261 "project-dialog-options.vala"
		gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (self->priv->save_temps_btn));
		_tmp17 = NULL;
#line 262 "project-dialog-options.vala"
		self->priv->quiet_btn = (_tmp17 = g_object_ref_sink (gtk_check_button_new_with_label (_ ("Do not print messages to the console"))), (self->priv->quiet_btn == NULL ? NULL : (self->priv->quiet_btn = (g_object_unref (self->priv->quiet_btn), NULL))), _tmp17);
#line 263 "project-dialog-options.vala"
		gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (self->priv->quiet_btn));
		_tmp18 = NULL;
#line 264 "project-dialog-options.vala"
		self->priv->verbose_btn = (_tmp18 = g_object_ref_sink (gtk_check_button_new_with_label (_ ("Include the source line text when reporting errors or warnings"))), (self->priv->verbose_btn == NULL ? NULL : (self->priv->verbose_btn = (g_object_unref (self->priv->verbose_btn), NULL))), _tmp18);
#line 265 "project-dialog-options.vala"
		gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (self->priv->verbose_btn));
	}
	return obj;
}


static void frame_general_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	FrameGeneral * self;
	self = FRAME_GENERAL (object);
	switch (property_id) {
		case FRAME_GENERAL_DEBUG:
		g_value_set_boolean (value, frame_general_get_debug (self));
		break;
		case FRAME_GENERAL_THREAD:
		g_value_set_boolean (value, frame_general_get_thread (self));
		break;
		case FRAME_GENERAL_DISABLE_ASSERT:
		g_value_set_boolean (value, frame_general_get_disable_assert (self));
		break;
		case FRAME_GENERAL_DISABLE_CHECKING:
		g_value_set_boolean (value, frame_general_get_disable_checking (self));
		break;
		case FRAME_GENERAL_DISABLE_NON_NULL:
		g_value_set_boolean (value, frame_general_get_disable_non_null (self));
		break;
		case FRAME_GENERAL_SAVE_TEMPS:
		g_value_set_boolean (value, frame_general_get_save_temps (self));
		break;
		case FRAME_GENERAL_QUIET:
		g_value_set_boolean (value, frame_general_get_quiet (self));
		break;
		case FRAME_GENERAL_VERBOSE:
		g_value_set_boolean (value, frame_general_get_verbose (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void frame_general_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	FrameGeneral * self;
	self = FRAME_GENERAL (object);
	switch (property_id) {
		case FRAME_GENERAL_DEBUG:
		frame_general_set_debug (self, g_value_get_boolean (value));
		break;
		case FRAME_GENERAL_THREAD:
		frame_general_set_thread (self, g_value_get_boolean (value));
		break;
		case FRAME_GENERAL_DISABLE_ASSERT:
		frame_general_set_disable_assert (self, g_value_get_boolean (value));
		break;
		case FRAME_GENERAL_DISABLE_CHECKING:
		frame_general_set_disable_checking (self, g_value_get_boolean (value));
		break;
		case FRAME_GENERAL_DISABLE_NON_NULL:
		frame_general_set_disable_non_null (self, g_value_get_boolean (value));
		break;
		case FRAME_GENERAL_SAVE_TEMPS:
		frame_general_set_save_temps (self, g_value_get_boolean (value));
		break;
		case FRAME_GENERAL_QUIET:
		frame_general_set_quiet (self, g_value_get_boolean (value));
		break;
		case FRAME_GENERAL_VERBOSE:
		frame_general_set_verbose (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void frame_general_class_init (FrameGeneralClass * klass) {
	frame_general_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (FrameGeneralPrivate));
	G_OBJECT_CLASS (klass)->get_property = frame_general_get_property;
	G_OBJECT_CLASS (klass)->set_property = frame_general_set_property;
	G_OBJECT_CLASS (klass)->constructor = frame_general_constructor;
	G_OBJECT_CLASS (klass)->dispose = frame_general_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), FRAME_GENERAL_DEBUG, g_param_spec_boolean ("debug", "debug", "debug", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FRAME_GENERAL_THREAD, g_param_spec_boolean ("thread", "thread", "thread", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FRAME_GENERAL_DISABLE_ASSERT, g_param_spec_boolean ("disable-assert", "disable-assert", "disable-assert", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FRAME_GENERAL_DISABLE_CHECKING, g_param_spec_boolean ("disable-checking", "disable-checking", "disable-checking", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FRAME_GENERAL_DISABLE_NON_NULL, g_param_spec_boolean ("disable-non-null", "disable-non-null", "disable-non-null", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FRAME_GENERAL_SAVE_TEMPS, g_param_spec_boolean ("save-temps", "save-temps", "save-temps", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FRAME_GENERAL_QUIET, g_param_spec_boolean ("quiet", "quiet", "quiet", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), FRAME_GENERAL_VERBOSE, g_param_spec_boolean ("verbose", "verbose", "verbose", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void frame_general_init (FrameGeneral * self) {
	self->priv = FRAME_GENERAL_GET_PRIVATE (self);
}


static void frame_general_dispose (GObject * obj) {
	FrameGeneral * self;
	self = FRAME_GENERAL (obj);
	(self->priv->debug_btn == NULL ? NULL : (self->priv->debug_btn = (g_object_unref (self->priv->debug_btn), NULL)));
	(self->priv->thread_btn == NULL ? NULL : (self->priv->thread_btn = (g_object_unref (self->priv->thread_btn), NULL)));
	(self->priv->disable_assert_btn == NULL ? NULL : (self->priv->disable_assert_btn = (g_object_unref (self->priv->disable_assert_btn), NULL)));
	(self->priv->disable_checking_btn == NULL ? NULL : (self->priv->disable_checking_btn = (g_object_unref (self->priv->disable_checking_btn), NULL)));
	(self->priv->disable_non_null_btn == NULL ? NULL : (self->priv->disable_non_null_btn = (g_object_unref (self->priv->disable_non_null_btn), NULL)));
	(self->priv->save_temps_btn == NULL ? NULL : (self->priv->save_temps_btn = (g_object_unref (self->priv->save_temps_btn), NULL)));
	(self->priv->quiet_btn == NULL ? NULL : (self->priv->quiet_btn = (g_object_unref (self->priv->quiet_btn), NULL)));
	(self->priv->verbose_btn == NULL ? NULL : (self->priv->verbose_btn = (g_object_unref (self->priv->verbose_btn), NULL)));
	G_OBJECT_CLASS (frame_general_parent_class)->dispose (obj);
}


static GType frame_general_get_type (void) {
	static GType frame_general_type_id = 0;
	if (G_UNLIKELY (frame_general_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (FrameGeneralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) frame_general_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FrameGeneral), 0, (GInstanceInitFunc) frame_general_init };
		frame_general_type_id = g_type_register_static (GTK_TYPE_VBOX, "FrameGeneral", &g_define_type_info, 0);
	}
	return frame_general_type_id;
}


#line 343 "project-dialog-options.vala"
static GtkScrolledWindow* frame_list_create_tree_view (FrameList* self, GList* pkg) {
	GtkListStore* _tmp0;
	GtkTreeView* _tmp1;
	GtkCellRendererText* render;
	GtkTreeViewColumn* column;
	GtkScrolledWindow* scrolled_window;
	GtkScrolledWindow* _tmp2;
#line 343 "project-dialog-options.vala"
	g_return_val_if_fail (IS_FRAME_LIST (self), NULL);
	_tmp0 = NULL;
#line 345 "project-dialog-options.vala"
	self->priv->list_store = (_tmp0 = gtk_list_store_new (1, G_TYPE_STRING, NULL), (self->priv->list_store == NULL ? NULL : (self->priv->list_store = (g_object_unref (self->priv->list_store), NULL))), _tmp0);
	_tmp1 = NULL;
#line 346 "project-dialog-options.vala"
	self->priv->tree_view = (_tmp1 = g_object_ref_sink (gtk_tree_view_new_with_model (GTK_TREE_MODEL (self->priv->list_store))), (self->priv->tree_view == NULL ? NULL : (self->priv->tree_view = (g_object_unref (self->priv->tree_view), NULL))), _tmp1);
	render = g_object_ref_sink (gtk_cell_renderer_text_new ());
	column = g_object_ref_sink (gtk_tree_view_column_new_with_attributes ("", GTK_CELL_RENDERER (render), "text", 0, NULL, NULL));
#line 349 "project-dialog-options.vala"
	gtk_tree_view_append_column (self->priv->tree_view, column);
#line 350 "project-dialog-options.vala"
	gtk_tree_view_set_headers_visible (self->priv->tree_view, FALSE);
	scrolled_window = g_object_ref_sink (gtk_scrolled_window_new (NULL, NULL));
#line 353 "project-dialog-options.vala"
	gtk_container_add (GTK_CONTAINER (scrolled_window), GTK_WIDGET (self->priv->tree_view));
#line 354 "project-dialog-options.vala"
	gtk_scrolled_window_set_policy (scrolled_window, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
#line 356 "project-dialog-options.vala"
	_tmp2 = NULL;
#line 356 "project-dialog-options.vala"
	return (_tmp2 = scrolled_window, (render == NULL ? NULL : (render = (g_object_unref (render), NULL))), (column == NULL ? NULL : (column = (g_object_unref (column), NULL))), _tmp2);
}


#line 269 "project-dialog-options.vala"
static FrameList* frame_list_new (void) {
	FrameList * self;
	self = g_object_newv (TYPE_FRAME_LIST, 0, NULL);
	return self;
}


static void _g_list_free_g_free (GList* self) {
	g_list_foreach (self, ((GFunc) g_free), NULL);
	g_list_free (self);
}


static GList* frame_list_get_items (FrameList* self) {
	GList* it;
	GtkTreeIter iter = {0};
	g_return_val_if_fail (IS_FRAME_LIST (self), NULL);
	it = NULL;
#line 282 "project-dialog-options.vala"
	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (self->priv->list_store), &iter)) {
#line 284 "project-dialog-options.vala"
		do {
			char* str;
			const char* _tmp0;
			str = NULL;
#line 288 "project-dialog-options.vala"
			gtk_tree_model_get (GTK_TREE_MODEL (self->priv->list_store), &iter, 0, &str, -1);
#line 289 "project-dialog-options.vala"
			_tmp0 = NULL;
#line 289 "project-dialog-options.vala"
			it = g_list_append (it, (_tmp0 = str, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))));
			str = (g_free (str), NULL);
		} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (self->priv->list_store), &iter));
	}
#line 292 "project-dialog-options.vala"
	return it;
}


static void frame_list_set_items (FrameList* self, GList* value) {
	g_return_if_fail (IS_FRAME_LIST (self));
	{
		GList* it_collection;
		GList* it_it;
#line 297 "project-dialog-options.vala"
		it_collection = value;
		for (it_it = it_collection; it_it != NULL; it_it = it_it->next) {
			const char* _tmp2;
			char* it;
			_tmp2 = NULL;
#line 297 "project-dialog-options.vala"
			it = (_tmp2 = ((char*) it_it->data), (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
			{
				GtkTreeIter iter = {0};
#line 301 "project-dialog-options.vala"
				gtk_list_store_append (self->priv->list_store, &iter);
#line 302 "project-dialog-options.vala"
				gtk_list_store_set (self->priv->list_store, &iter, 0, it, -1);
				it = (g_free (it), NULL);
			}
		}
	}
}


static void __lambda1 (FrameList* self) {
	GtkTreeIter iter = {0};
#line 325 "project-dialog-options.vala"
	gtk_list_store_append (self->priv->list_store, &iter);
#line 326 "project-dialog-options.vala"
	gtk_list_store_set (self->priv->list_store, &iter, 0, gtk_entry_get_text (self->priv->entry), -1);
#line 327 "project-dialog-options.vala"
	gtk_entry_set_text (self->priv->entry, "");
}


static void ___lambda1_gtk_button_clicked (GtkButton* sender, gpointer self) {
	__lambda1 (self);
}


static void __lambda2 (FrameList* self) {
	GtkTreeIter iter = {0};
	GtkTreeSelection* _tmp0;
	GtkTreeSelection* selection;
#line 333 "project-dialog-options.vala"
	_tmp0 = NULL;
	selection = (_tmp0 = gtk_tree_view_get_selection (self->priv->tree_view), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
#line 335 "project-dialog-options.vala"
	gtk_tree_selection_get_selected (selection, NULL, &iter);
#line 336 "project-dialog-options.vala"
	gtk_list_store_remove (self->priv->list_store, &iter);
	(selection == NULL ? NULL : (selection = (g_object_unref (selection), NULL)));
}


static void ___lambda2_gtk_button_clicked (GtkButton* sender, gpointer self) {
	__lambda2 (self);
}


static GObject * frame_list_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	FrameListClass * klass;
	GObjectClass * parent_class;
	FrameList * self;
	klass = FRAME_LIST_CLASS (g_type_class_peek (TYPE_FRAME_LIST));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = FRAME_LIST (obj);
	{
		GtkVBox* main_box;
		GtkHBox* hbox;
		GtkEntry* _tmp19;
		GtkButton* button;
		GtkButton* _tmp20;
		GtkScrolledWindow* _tmp21;
		main_box = g_object_ref_sink (gtk_vbox_new (FALSE, 0));
#line 310 "project-dialog-options.vala"
		gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (main_box));
		hbox = g_object_ref_sink (gtk_hbox_new (FALSE, 0));
#line 313 "project-dialog-options.vala"
		gtk_box_pack_start (GTK_BOX (main_box), GTK_WIDGET (hbox), FALSE, TRUE, ((guint) 0));
		_tmp19 = NULL;
#line 315 "project-dialog-options.vala"
		self->priv->entry = (_tmp19 = g_object_ref_sink (gtk_entry_new ()), (self->priv->entry == NULL ? NULL : (self->priv->entry = (g_object_unref (self->priv->entry), NULL))), _tmp19);
#line 316 "project-dialog-options.vala"
		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->entry), TRUE, TRUE, ((guint) 0));
		button = g_object_ref_sink (gtk_button_new_from_stock (GTK_STOCK_ADD));
#line 322 "project-dialog-options.vala"
		g_signal_connect_object (button, "clicked", ((GCallback) ___lambda1_gtk_button_clicked), self, 0);
#line 329 "project-dialog-options.vala"
		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (button), FALSE, FALSE, ((guint) 0));
		_tmp20 = NULL;
#line 330 "project-dialog-options.vala"
		button = (_tmp20 = g_object_ref_sink (gtk_button_new_from_stock (GTK_STOCK_REMOVE)), (button == NULL ? NULL : (button = (g_object_unref (button), NULL))), _tmp20);
#line 331 "project-dialog-options.vala"
		g_signal_connect_object (button, "clicked", ((GCallback) ___lambda2_gtk_button_clicked), self, 0);
#line 338 "project-dialog-options.vala"
		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (button), FALSE, FALSE, ((guint) 0));
#line 340 "project-dialog-options.vala"
		_tmp21 = NULL;
#line 340 "project-dialog-options.vala"
		gtk_box_pack_start (GTK_BOX (main_box), GTK_WIDGET ((_tmp21 = frame_list_create_tree_view (self, NULL))), TRUE, TRUE, ((guint) 0));
		(_tmp21 == NULL ? NULL : (_tmp21 = (g_object_unref (_tmp21), NULL)));
		(main_box == NULL ? NULL : (main_box = (g_object_unref (main_box), NULL)));
		(hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL)));
		(button == NULL ? NULL : (button = (g_object_unref (button), NULL)));
	}
	return obj;
}


static void frame_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	FrameList * self;
	self = FRAME_LIST (object);
	switch (property_id) {
		case FRAME_LIST_ITEMS:
		g_value_set_pointer (value, frame_list_get_items (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void frame_list_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	FrameList * self;
	self = FRAME_LIST (object);
	switch (property_id) {
		case FRAME_LIST_ITEMS:
		frame_list_set_items (self, g_value_get_pointer (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void frame_list_class_init (FrameListClass * klass) {
	frame_list_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (FrameListPrivate));
	G_OBJECT_CLASS (klass)->get_property = frame_list_get_property;
	G_OBJECT_CLASS (klass)->set_property = frame_list_set_property;
	G_OBJECT_CLASS (klass)->constructor = frame_list_constructor;
	G_OBJECT_CLASS (klass)->dispose = frame_list_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), FRAME_LIST_ITEMS, g_param_spec_pointer ("items", "items", "items", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void frame_list_init (FrameList * self) {
	self->priv = FRAME_LIST_GET_PRIVATE (self);
}


static void frame_list_dispose (GObject * obj) {
	FrameList * self;
	self = FRAME_LIST (obj);
	(self->priv->tree_view == NULL ? NULL : (self->priv->tree_view = (g_object_unref (self->priv->tree_view), NULL)));
	(self->priv->list_store == NULL ? NULL : (self->priv->list_store = (g_object_unref (self->priv->list_store), NULL)));
	(self->priv->entry == NULL ? NULL : (self->priv->entry = (g_object_unref (self->priv->entry), NULL)));
	G_OBJECT_CLASS (frame_list_parent_class)->dispose (obj);
}


static GType frame_list_get_type (void) {
	static GType frame_list_type_id = 0;
	if (G_UNLIKELY (frame_list_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (FrameListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) frame_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FrameList), 0, (GInstanceInitFunc) frame_list_init };
		frame_list_type_id = g_type_register_static (GTK_TYPE_FRAME, "FrameList", &g_define_type_info, 0);
	}
	return frame_list_type_id;
}


#line 365 "project-dialog-options.vala"
static FramePkg* frame_pkg_new (void) {
	FramePkg * self;
	self = g_object_newv (TYPE_FRAME_PKG, 0, NULL);
#line 367 "project-dialog-options.vala"
	gtk_frame_set_label (GTK_FRAME (self), "Package list");
	return self;
}


static void frame_pkg_class_init (FramePkgClass * klass) {
	frame_pkg_parent_class = g_type_class_peek_parent (klass);
}


static void frame_pkg_init (FramePkg * self) {
}


static GType frame_pkg_get_type (void) {
	static GType frame_pkg_type_id = 0;
	if (G_UNLIKELY (frame_pkg_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (FramePkgClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) frame_pkg_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FramePkg), 0, (GInstanceInitFunc) frame_pkg_init };
		frame_pkg_type_id = g_type_register_static (TYPE_FRAME_LIST, "FramePkg", &g_define_type_info, 0);
	}
	return frame_pkg_type_id;
}


#line 373 "project-dialog-options.vala"
static FrameVapi* frame_vapi_new (void) {
	FrameVapi * self;
	self = g_object_newv (TYPE_FRAME_VAPI, 0, NULL);
#line 375 "project-dialog-options.vala"
	gtk_frame_set_label (GTK_FRAME (self), "Vapi directory list");
	return self;
}


static void frame_vapi_class_init (FrameVapiClass * klass) {
	frame_vapi_parent_class = g_type_class_peek_parent (klass);
}


static void frame_vapi_init (FrameVapi * self) {
}


static GType frame_vapi_get_type (void) {
	static GType frame_vapi_type_id = 0;
	if (G_UNLIKELY (frame_vapi_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (FrameVapiClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) frame_vapi_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FrameVapi), 0, (GInstanceInitFunc) frame_vapi_init };
		frame_vapi_type_id = g_type_register_static (TYPE_FRAME_LIST, "FrameVapi", &g_define_type_info, 0);
	}
	return frame_vapi_type_id;
}




