/* project-dialog-options.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

using GLib;

public class Valide.ProjectDialogOptions : Gtk.Dialog
{
  private Project project_;
  private Gtk.Notebook notebook;
  private FrameGeneral frame_general;
  private FramePkg frame_pkg;
  private FrameVapi frame_vapi;

  public GLib.List<string> pkg
  {
    get { return this.frame_pkg.items; }
    set { this.frame_pkg.items = value; }
  }

  public GLib.List<string> vapi_dir
  {
    get { return this.frame_vapi.items; }
    set { this.frame_vapi.items = value; }
  }

  public bool debug
  {
    get { return this.frame_general.debug; }
    set { this.frame_general.debug = value; }
  }

  public bool thread
  {
    get { return this.frame_general.thread; }
    set { this.frame_general.thread = value; }
  }

  public bool disable_assert
  {
    get { return this.frame_general.disable_assert; }
    set { this.frame_general.disable_assert = value; }
  }

  public bool disable_checking
  {
    get { return this.frame_general.disable_checking; }
    set { this.frame_general.disable_checking = value; }
  }

  public bool disable_non_null
  {
    get { return this.frame_general.disable_non_null; }
    set { this.frame_general.disable_non_null = value; }
  }

  public bool save_temps
  {
    get { return this.frame_general.save_temps; }
    set { this.frame_general.save_temps = value; }
  }

  public bool quiet
  {
    get { return this.frame_general.quiet; }
    set { this.frame_general.quiet = value; }
  }

  public bool verbose
  {
    get { return this.frame_general.verbose; }
    set { this.frame_general.verbose = value; }
  }

  public Project project
  {
    get
    {
      return this.project_;
    }
    set
    {
      this.project_ = value;
      this.pkg = this.project.pkg;
      this.vapi_dir = this.project.vapi_dir;
      this.debug = this.project.debug;
      this.thread = this.project.thread;
      this.disable_assert = this.project.disable_assert;
      this.disable_checking = this.project.disable_checking;
      this.disable_non_null = this.project.disable_non_null;
      this.save_temps = this.project.save_temps;
      this.quiet = this.project.quiet;
      this.verbose = this.project.verbose;
    }
  }

  public ProjectDialogOptions (Project project)
  {
    this.project = project;
    this.default_height = 600;
    this.default_width = 800;
  }

  construct
  {
    this.add_button (Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT);
    this.add_button (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL);

    weak Gtk.VBox main_box = (Gtk.VBox)this.vbox;

    Gtk.HBox hbox = new Gtk.HBox (false, 0);
    main_box.pack_start (hbox, true, true, 0);

    Gtk.ScrolledWindow scrolled_window = new Gtk.ScrolledWindow (null, null);
    hbox.pack_start (scrolled_window, false, true, 0);
    scrolled_window.set_policy (Gtk.PolicyType.NEVER,
                                Gtk.PolicyType.AUTOMATIC);
    Gtk.IconView icon_view = new Gtk.IconView ();
    scrolled_window.add (icon_view);

    Gtk.ListStore list_store = new Gtk.ListStore (3, typeof (Gdk.Pixbuf),
                                                     typeof (string),
                                                     typeof (int));
    icon_view.set_pixbuf_column (0);
    icon_view.set_text_column (1);
    icon_view.set_model (list_store);
    icon_view.set_item_width (80);

    Gtk.TreeIter iter;
    this.notebook = new Gtk.Notebook ();
    this.notebook.show_tabs = false;
    hbox.pack_start (this.notebook, true, true, 0);    

    {
      list_store.append (out iter);
      Gdk.Pixbuf icon = new Gdk.Pixbuf.from_file (GLib.Path.build_filename (Config.PACKAGE_PIXMAPS_DIR, "pref-general.png"));
      list_store.set (iter, 0, icon, 1, _("General"), 2, 0, -1);
      this.frame_general = new FrameGeneral ();
      this.notebook.append_page (this.frame_general, new Gtk.Label (_("General")));
    }
    {
      list_store.append (out iter);
      Gdk.Pixbuf icon = new Gdk.Pixbuf.from_file (GLib.Path.build_filename (Config.PACKAGE_PIXMAPS_DIR, "pref-pkg.png"));
      list_store.set (iter, 0, icon, 1, _("Packages"), 2, 1, -1);
      this.frame_pkg = new FramePkg ();
      this.frame_vapi = new FrameVapi ();

      Gtk.VBox vbox = new Gtk.VBox (true, 10);
      vbox.pack_start (this.frame_pkg, true, true, 0);
      vbox.pack_start (this.frame_vapi, true, true, 0);
      this.notebook.append_page (vbox, new Gtk.Label (_("Packages")));
    }

    icon_view.selection_changed += sender => {
      weak GLib.List<Gtk.TreePath> onglets = sender.get_selected_items ();
      if (onglets != null)
      {
        int index;
        Gtk.TreeIter iter;

        sender.model.get_iter (out iter, onglets.data);
        sender.model.get (iter, 2, out index, -1);
        this.notebook.set_current_page (index);
      }
    };
    /* Set first item */
    icon_view.select_path (new Gtk.TreePath.from_string ("0"));
  }
}

private class FrameGeneral : Gtk.VBox
{
  private Gtk.CheckButton debug_btn;
  private Gtk.CheckButton thread_btn;
  private Gtk.CheckButton disable_assert_btn;
  private Gtk.CheckButton disable_checking_btn;
  private Gtk.CheckButton disable_non_null_btn;
  private Gtk.CheckButton save_temps_btn;
  private Gtk.CheckButton quiet_btn;
  private Gtk.CheckButton verbose_btn;

  public bool debug
  {
    get { return this.debug_btn.active; }
    set { this.debug_btn.active = value; }
  }

  public bool thread
  {
    get { return this.thread_btn.active; }
    set { this.thread_btn.active = value; }
  }

  public bool disable_assert
  {
    get { return this.disable_assert_btn.active; }
    set { this.disable_assert_btn.active = value; }
  }

  public bool disable_checking
  {
    get { return this.disable_checking_btn.active; }
    set { this.disable_checking_btn.active = value; }
  }

  public bool disable_non_null
  {
    get { return this.disable_non_null_btn.active; }
    set { this.disable_non_null_btn.active = value; }
  }

  public bool save_temps
  {
    get { return this.save_temps_btn.active; }
    set { this.save_temps_btn.active = value; }
  }

  public bool quiet
  {
    get { return this.quiet_btn.active; }
    set { this.quiet_btn.active = value; }
  }

  public bool verbose
  {
    get { return this.verbose_btn.active; }
    set { this.verbose_btn.active = value; }
  }

  construct
  {
    this.debug_btn = new Gtk.CheckButton.with_label (_("Produce debug information"));
    this.add (this.debug_btn);
    this.thread_btn = new Gtk.CheckButton.with_label (_("Enable multithreading support"));
    this.add (this.thread_btn);
    this.disable_assert_btn = new Gtk.CheckButton.with_label (_("Disable assertions"));
    this.add (this.disable_assert_btn);
    this.disable_checking_btn = new Gtk.CheckButton.with_label (_("Disable run-time checks"));
    this.add (this.disable_checking_btn);
    this.disable_non_null_btn = new Gtk.CheckButton.with_label (_("Disable non-null types"));
    this.add (this.disable_non_null_btn);
    this.save_temps_btn = new Gtk.CheckButton.with_label (_("Keep temporary files"));
    this.add (this.save_temps_btn);
    this.quiet_btn = new Gtk.CheckButton.with_label (_("Do not print messages to the console"));
    this.add (this.quiet_btn);
    this.verbose_btn = new Gtk.CheckButton.with_label (_("Include the source line text when reporting errors or warnings"));
    this.add (this.verbose_btn);
  }
}

private class FrameList : Gtk.Frame
{
  private Gtk.TreeView tree_view;
  private Gtk.ListStore list_store;
  private Gtk.Entry entry;

  public GLib.List<string># items
  {
    get
    {
      GLib.List<string> it;
      Gtk.TreeIter iter;

      if (this.list_store.get_iter_first (out iter))
      {
        do
        {
          string str;

          this.list_store.get (iter, 0, out str);
          it.append (str);
        } while (this.list_store.iter_next (ref iter));
      }
      return it;
    }

    set
    {
      foreach (string it in value)
      {
        Gtk.TreeIter iter;

        this.list_store.append (out iter);
        this.list_store.set (iter, 0, it);
      }
    }
  }

  construct
  {
    Gtk.VBox main_box = new Gtk.VBox (false, 0);
    this.add (main_box);

    Gtk.HBox hbox = new Gtk.HBox (false, 0);
    main_box.pack_start (hbox, false, true, 0);

    this.entry = new Gtk.Entry ();
    hbox.pack_start (this.entry, true, true, 0);

    Gtk.Button button = new Gtk.Button.from_stock (Gtk.STOCK_ADD);
    /**
     * @todo Check duplicate
     */
    button.clicked += () => {
      Gtk.TreeIter iter;

      this.list_store.append (out iter);
      this.list_store.set (iter, 0, entry.text);
      entry.text = "";
    };
    hbox.pack_start (button, false, false, 0);
    button = new Gtk.Button.from_stock (Gtk.STOCK_REMOVE);
    button.clicked += () => {
      Gtk.TreeIter iter;
      Gtk.TreeSelection selection = this.tree_view.get_selection ();

      selection.get_selected (null, out iter);
      this.list_store.remove (iter);
    };
    hbox.pack_start (button, false, false, 0);

    main_box.pack_start (this.create_tree_view (null), true, true, 0);
  }

  private Gtk.ScrolledWindow create_tree_view (GLib.List<string>? pkg)
  {
    this.list_store = new Gtk.ListStore (1, typeof (string));
    this.tree_view = new Gtk.TreeView.with_model (this.list_store);
    Gtk.CellRendererText render = new Gtk.CellRendererText ();
    Gtk.TreeViewColumn column = new Gtk.TreeViewColumn.with_attributes ("", render, "text", 0, null);
    this.tree_view.append_column (column);
    this.tree_view.headers_visible = false;

    Gtk.ScrolledWindow scrolled_window = new Gtk.ScrolledWindow (null, null);
    scrolled_window.add (this.tree_view);
    scrolled_window.set_policy (Gtk.PolicyType.AUTOMATIC,
                                Gtk.PolicyType.AUTOMATIC);
    return scrolled_window;
  }
}

/**
 * @todo Grab focus for entry
 */
private class FramePkg : FrameList
{
  public FramePkg ()
  {
    this.label = "Package list";
  }
}

private class FrameVapi : FrameList
{
  public FrameVapi ()
  {
    this.label = "Vapi directory list";
  }
}


