/* project-dialog-remove.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/project-dialog-remove.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>




struct _ValideProjectDialogRemovePrivate {
	GtkLabel* label;
	GtkListStore* list_store;
};

#define VALIDE_PROJECT_DIALOG_REMOVE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_PROJECT_DIALOG_REMOVE, ValideProjectDialogRemovePrivate))
enum  {
	VALIDE_PROJECT_DIALOG_REMOVE_DUMMY_PROPERTY,
	VALIDE_PROJECT_DIALOG_REMOVE_PROJECT,
	VALIDE_PROJECT_DIALOG_REMOVE_SELECTED_FILES
};
static void valide_project_dialog_remove_toggled (ValideProjectDialogRemove* self, GtkCellRendererToggle* sender, const char* path);
static void _g_list_free_g_free (GList* self);
static void _valide_project_dialog_remove_toggled_gtk_cell_renderer_toggle_toggled (GtkCellRendererToggle* sender, const char* path, gpointer self);
static GObject * valide_project_dialog_remove_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer valide_project_dialog_remove_parent_class = NULL;
static void valide_project_dialog_remove_dispose (GObject * obj);



#line 73 "project-dialog-remove.vala"
static void valide_project_dialog_remove_toggled (ValideProjectDialogRemove* self, GtkCellRendererToggle* sender, const char* path) {
	GtkTreeIter iter = {0};
	gboolean enable;
#line 73 "project-dialog-remove.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_REMOVE (self));
#line 73 "project-dialog-remove.vala"
	g_return_if_fail (GTK_IS_CELL_RENDERER_TOGGLE (sender));
#line 73 "project-dialog-remove.vala"
	g_return_if_fail (path != NULL);
	enable = FALSE;
#line 78 "project-dialog-remove.vala"
	gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (self->priv->list_store), &iter, path);
#line 79 "project-dialog-remove.vala"
	gtk_tree_model_get (GTK_TREE_MODEL (self->priv->list_store), &iter, 0, &enable, -1, -1);
#line 80 "project-dialog-remove.vala"
	gtk_list_store_set (self->priv->list_store, &iter, 0, !enable, -1, -1);
}


#line 108 "project-dialog-remove.vala"
ValideProjectDialogRemove* valide_project_dialog_remove_new (ValideProject* project) {
	ValideProjectDialogRemove * self;
#line 108 "project-dialog-remove.vala"
	g_return_val_if_fail (VALIDE_IS_PROJECT (project), NULL);
	self = g_object_newv (VALIDE_TYPE_PROJECT_DIALOG_REMOVE, 0, NULL);
#line 110 "project-dialog-remove.vala"
	valide_project_dialog_remove_set_project (self, project);
	return self;
}


void valide_project_dialog_remove_set_project (ValideProjectDialogRemove* self, ValideProject* value) {
	char* _tmp0;
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG_REMOVE (self));
#line 34 "project-dialog-remove.vala"
	_tmp0 = NULL;
#line 34 "project-dialog-remove.vala"
	gtk_label_set_text (self->priv->label, (_tmp0 = g_strdup_printf (_ ("Select files to remove from %s:"), valide_project_get_name (value))));
	_tmp0 = (g_free (_tmp0), NULL);
	{
		GList* file_collection;
		GList* file_it;
#line 35 "project-dialog-remove.vala"
		file_collection = valide_project_get_files (value);
		for (file_it = file_collection; file_it != NULL; file_it = file_it->next) {
			const char* _tmp1;
			char* file;
			_tmp1 = NULL;
#line 35 "project-dialog-remove.vala"
			file = (_tmp1 = ((char*) file_it->data), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
			{
				GtkTreeIter iter = {0};
#line 39 "project-dialog-remove.vala"
				gtk_list_store_append (self->priv->list_store, &iter);
#line 40 "project-dialog-remove.vala"
				gtk_list_store_set (self->priv->list_store, &iter, 0, FALSE, 1, file, -1);
				file = (g_free (file), NULL);
			}
		}
	}
}


static void _g_list_free_g_free (GList* self) {
	g_list_foreach (self, ((GFunc) g_free), NULL);
	g_list_free (self);
}


GList* valide_project_dialog_remove_get_selected_files (ValideProjectDialogRemove* self) {
	GtkTreeIter iter = {0};
	GList* files;
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG_REMOVE (self), NULL);
	files = NULL;
	/**
	       * @fixme Error if no file
	       */
#line 55 "project-dialog-remove.vala"
	gtk_tree_model_get_iter_first (GTK_TREE_MODEL (self->priv->list_store), &iter);
#line 56 "project-dialog-remove.vala"
	do {
		gboolean enable;
		enable = FALSE;
#line 60 "project-dialog-remove.vala"
		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->list_store), &iter, 0, &enable, -1, -1);
#line 61 "project-dialog-remove.vala"
		if (enable) {
			char* file;
			const char* _tmp0;
			file = NULL;
#line 65 "project-dialog-remove.vala"
			gtk_tree_model_get (GTK_TREE_MODEL (self->priv->list_store), &iter, 1, &file, -1, -1);
#line 66 "project-dialog-remove.vala"
			_tmp0 = NULL;
#line 66 "project-dialog-remove.vala"
			files = g_list_append (files, (_tmp0 = file, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))));
			file = (g_free (file), NULL);
		}
	} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (self->priv->list_store), &iter) == TRUE);
#line 69 "project-dialog-remove.vala"
	return files;
}


#line 73 "project-dialog-remove.vala"
static void _valide_project_dialog_remove_toggled_gtk_cell_renderer_toggle_toggled (GtkCellRendererToggle* sender, const char* path, gpointer self) {
	valide_project_dialog_remove_toggled (self, sender, path);
}


static GObject * valide_project_dialog_remove_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	ValideProjectDialogRemoveClass * klass;
	GObjectClass * parent_class;
	ValideProjectDialogRemove * self;
	klass = VALIDE_PROJECT_DIALOG_REMOVE_CLASS (g_type_class_peek (VALIDE_TYPE_PROJECT_DIALOG_REMOVE));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = VALIDE_PROJECT_DIALOG_REMOVE (obj);
	{
		GtkVBox* _tmp0;
		GtkVBox* box;
		GtkLabel* _tmp1;
		GtkListStore* _tmp2;
		GtkTreeView* tree_view;
		GtkCellRendererToggle* render1;
		GtkTreeViewColumn* column;
		GtkCellRendererText* render2;
		GtkTreeViewColumn* _tmp3;
#line 85 "project-dialog-remove.vala"
		_tmp0 = NULL;
		box = (_tmp0 = GTK_VBOX (GTK_DIALOG (self)->vbox), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
		_tmp1 = NULL;
#line 87 "project-dialog-remove.vala"
		self->priv->label = (_tmp1 = g_object_ref_sink (gtk_label_new (_ ("Select files to remove:"))), (self->priv->label == NULL ? NULL : (self->priv->label = (g_object_unref (self->priv->label), NULL))), _tmp1);
#line 88 "project-dialog-remove.vala"
		gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (self->priv->label), FALSE, FALSE, ((guint) 0));
		_tmp2 = NULL;
#line 90 "project-dialog-remove.vala"
		self->priv->list_store = (_tmp2 = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING, NULL), (self->priv->list_store == NULL ? NULL : (self->priv->list_store = (g_object_unref (self->priv->list_store), NULL))), _tmp2);
		tree_view = g_object_ref_sink (gtk_tree_view_new_with_model (GTK_TREE_MODEL (self->priv->list_store)));
		render1 = g_object_ref_sink (gtk_cell_renderer_toggle_new ());
		column = g_object_ref_sink (gtk_tree_view_column_new_with_attributes (_ ("Remove"), GTK_CELL_RENDERER (render1), "active", 0, NULL, NULL));
#line 94 "project-dialog-remove.vala"
		gtk_tree_view_append_column (tree_view, column);
#line 95 "project-dialog-remove.vala"
		g_signal_connect_object (render1, "toggled", ((GCallback) _valide_project_dialog_remove_toggled_gtk_cell_renderer_toggle_toggled), self, 0);
		render2 = g_object_ref_sink (gtk_cell_renderer_text_new ());
		_tmp3 = NULL;
#line 98 "project-dialog-remove.vala"
		column = (_tmp3 = g_object_ref_sink (gtk_tree_view_column_new_with_attributes (_ ("File"), GTK_CELL_RENDERER (render2), "text", 1, NULL, NULL)), (column == NULL ? NULL : (column = (g_object_unref (column), NULL))), _tmp3);
#line 99 "project-dialog-remove.vala"
		gtk_tree_view_append_column (tree_view, column);
#line 100 "project-dialog-remove.vala"
		gtk_tree_view_set_headers_visible (tree_view, FALSE);
#line 102 "project-dialog-remove.vala"
		gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (tree_view), TRUE, TRUE, ((guint) 0));
#line 104 "project-dialog-remove.vala"
		gtk_dialog_add_buttons (GTK_DIALOG (self), GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL, NULL);
		(box == NULL ? NULL : (box = (g_object_unref (box), NULL)));
		(tree_view == NULL ? NULL : (tree_view = (g_object_unref (tree_view), NULL)));
		(render1 == NULL ? NULL : (render1 = (g_object_unref (render1), NULL)));
		(column == NULL ? NULL : (column = (g_object_unref (column), NULL)));
		(render2 == NULL ? NULL : (render2 = (g_object_unref (render2), NULL)));
	}
	return obj;
}


static void valide_project_dialog_remove_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValideProjectDialogRemove * self;
	self = VALIDE_PROJECT_DIALOG_REMOVE (object);
	switch (property_id) {
		case VALIDE_PROJECT_DIALOG_REMOVE_SELECTED_FILES:
		g_value_set_pointer (value, valide_project_dialog_remove_get_selected_files (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_project_dialog_remove_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValideProjectDialogRemove * self;
	self = VALIDE_PROJECT_DIALOG_REMOVE (object);
	switch (property_id) {
		case VALIDE_PROJECT_DIALOG_REMOVE_PROJECT:
		valide_project_dialog_remove_set_project (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_project_dialog_remove_class_init (ValideProjectDialogRemoveClass * klass) {
	valide_project_dialog_remove_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideProjectDialogRemovePrivate));
	G_OBJECT_CLASS (klass)->get_property = valide_project_dialog_remove_get_property;
	G_OBJECT_CLASS (klass)->set_property = valide_project_dialog_remove_set_property;
	G_OBJECT_CLASS (klass)->constructor = valide_project_dialog_remove_constructor;
	G_OBJECT_CLASS (klass)->dispose = valide_project_dialog_remove_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_REMOVE_PROJECT, g_param_spec_object ("project", "project", "project", VALIDE_TYPE_PROJECT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_REMOVE_SELECTED_FILES, g_param_spec_pointer ("selected-files", "selected-files", "selected-files", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void valide_project_dialog_remove_init (ValideProjectDialogRemove * self) {
	self->priv = VALIDE_PROJECT_DIALOG_REMOVE_GET_PRIVATE (self);
}


static void valide_project_dialog_remove_dispose (GObject * obj) {
	ValideProjectDialogRemove * self;
	self = VALIDE_PROJECT_DIALOG_REMOVE (obj);
	(self->priv->label == NULL ? NULL : (self->priv->label = (g_object_unref (self->priv->label), NULL)));
	(self->priv->list_store == NULL ? NULL : (self->priv->list_store = (g_object_unref (self->priv->list_store), NULL)));
	G_OBJECT_CLASS (valide_project_dialog_remove_parent_class)->dispose (obj);
}


GType valide_project_dialog_remove_get_type (void) {
	static GType valide_project_dialog_remove_type_id = 0;
	if (G_UNLIKELY (valide_project_dialog_remove_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideProjectDialogRemoveClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_project_dialog_remove_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideProjectDialogRemove), 0, (GInstanceInitFunc) valide_project_dialog_remove_init };
		valide_project_dialog_remove_type_id = g_type_register_static (GTK_TYPE_DIALOG, "ValideProjectDialogRemove", &g_define_type_info, 0);
	}
	return valide_project_dialog_remove_type_id;
}




