/* project-dialog-remove.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

using GLib;

public class Valide.ProjectDialogRemove : Gtk.Dialog
{
  Gtk.Label label;
  Gtk.ListStore list_store;

  public Project project
  {
    set
    {
      this.label.set_text (_("Select files to remove from %s:").printf (value.name));
      foreach (string file in value.files)
      {
        Gtk.TreeIter iter;

        this.list_store.append (out iter);
        this.list_store.set (iter, 0, false, 1, file);
      }
    }
  }

  public GLib.List<string># selected_files
  {
    get
    {
      Gtk.TreeIter iter;
      GLib.List<string> files;

      /**
       * @fixme Error if no file
       */
      this.list_store.get_iter_first (out iter);
      do
      {
        bool enable;

        this.list_store.get (iter, 0, &enable, -1);
        if (enable)
        {
          string file;

          this.list_store.get (iter, 1, &file, -1);
          files.append (file);
        }
      } while (this.list_store.iter_next (ref iter) == true);
      return files;
    }
  }

  private void toggled (Gtk.CellRendererToggle sender, string path)
  {
    Gtk.TreeIter iter;
    bool enable = false;

    this.list_store.get_iter_from_string (out iter, path);
    this.list_store.get (iter, 0, &enable, -1);
    this.list_store.set (iter, 0, !enable, -1);
  }

  construct
  {
    Gtk.VBox box = (Gtk.VBox)this.vbox;

    this.label = new Gtk.Label (_("Select files to remove:"));
    box.pack_start (this.label, false, false, 0);

    this.list_store = new Gtk.ListStore (2, typeof (bool), typeof (string));
    Gtk.TreeView tree_view = new Gtk.TreeView.with_model (this.list_store);
    Gtk.CellRendererToggle render1 = new Gtk.CellRendererToggle ();
    Gtk.TreeViewColumn column = new Gtk.TreeViewColumn.with_attributes (_("Remove"), render1, "active", 0, null);
    tree_view.append_column (column);
    render1.toggled += this.toggled;

    Gtk.CellRendererText render2 = new Gtk.CellRendererText ();
    column = new Gtk.TreeViewColumn.with_attributes (_("File"), render2, "text", 1, null);
    tree_view.append_column (column);
    tree_view.headers_visible = false;

    box.pack_start (tree_view, true, true, 0);

    this.add_buttons (Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT,
                      Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, null);
  }

  public ProjectDialogRemove (Project project)
  {
    this.project = project;
  }
}

