/* project-dialog.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/project-dialog.h>
#include <glib/gi18n-lib.h>
#include "src/template-manager.h"
#include "src/template.h"


#define VALIDE_TYPE_COLUMN_TYPE (valide_column_type_get_type ())

typedef enum  {
	VALIDE_COLUMN_TYPE_ICON,
	VALIDE_COLUMN_TYPE_NAME,
	VALIDE_COLUMN_TYPE_DESCRIPTION,
	VALIDE_COLUMN_TYPE_PATH,
	VALIDE_COLUMN_TYPE_NB_COLUMNS
} ValideColumnType;



GType valide_column_type_get_type (void);
struct _ValideProjectDialogPrivate {
	GtkListStore* list_store;
	GtkIconView* icon_view;
	GtkLabel* desc_label;
	GtkEntry* name_entry;
	GtkEntry* dir_entry;
	GtkEntry* path_entry;
	char* template_path_;
};

#define VALIDE_PROJECT_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_PROJECT_DIALOG, ValideProjectDialogPrivate))
enum  {
	VALIDE_PROJECT_DIALOG_DUMMY_PROPERTY,
	VALIDE_PROJECT_DIALOG_PROJECT_NAME,
	VALIDE_PROJECT_DIALOG_PROJECT_PATH,
	VALIDE_PROJECT_DIALOG_PROJECT_DIR,
	VALIDE_PROJECT_DIALOG_TEMPLATE,
	VALIDE_PROJECT_DIALOG_PROJECT_DESC
};
static void _g_list_free_g_free (GList* self);
static void valide_project_dialog_populate_icon_view (ValideProjectDialog* self);
static void valide_project_dialog_selection_changed (ValideProjectDialog* self, GtkIconView* icon_view);
static void valide_project_dialog_btn_clicked (ValideProjectDialog* self);
static void valide_project_dialog_project_path_change (ValideProjectDialog* self);
static void _valide_project_dialog_project_path_change_gtk_editable_changed (GtkEditable* sender, gpointer self);
static void _valide_project_dialog_btn_clicked_gtk_button_clicked (GtkButton* sender, gpointer self);
static void _valide_project_dialog_selection_changed_gtk_icon_view_selection_changed (GtkIconView* sender, gpointer self);
static GObject * valide_project_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer valide_project_dialog_parent_class = NULL;
static void valide_project_dialog_dispose (GObject * obj);




GType valide_column_type_get_type (void) {
	static GType valide_column_type_type_id = 0;
	if (G_UNLIKELY (valide_column_type_type_id == 0)) {
		static const GEnumValue values[] = {{VALIDE_COLUMN_TYPE_ICON, "VALIDE_COLUMN_TYPE_ICON", "icon"}, {VALIDE_COLUMN_TYPE_NAME, "VALIDE_COLUMN_TYPE_NAME", "name"}, {VALIDE_COLUMN_TYPE_DESCRIPTION, "VALIDE_COLUMN_TYPE_DESCRIPTION", "description"}, {VALIDE_COLUMN_TYPE_PATH, "VALIDE_COLUMN_TYPE_PATH", "path"}, {VALIDE_COLUMN_TYPE_NB_COLUMNS, "VALIDE_COLUMN_TYPE_NB_COLUMNS", "nb-columns"}, {0, NULL, NULL}};
		valide_column_type_type_id = g_enum_register_static ("ValideColumnType", values);
	}
	return valide_column_type_type_id;
}


#line 139 "project-dialog.vala"
ValideProjectDialog* valide_project_dialog_new (void) {
	ValideProjectDialog * self;
	gint _tmp0;
	gint _tmp1;
	self = g_object_newv (VALIDE_TYPE_PROJECT_DIALOG, 0, NULL);
#line 141 "project-dialog.vala"
	gtk_window_set_title (GTK_WINDOW (self), _ ("Create new project"));
#line 142 "project-dialog.vala"
	g_object_set (GTK_WINDOW (self), "default-height", 600, NULL);
#line 143 "project-dialog.vala"
	g_object_set (GTK_WINDOW (self), "default-width", 800, NULL);
	return self;
}


static void _g_list_free_g_free (GList* self) {
	g_list_foreach (self, ((GFunc) g_free), NULL);
	g_list_free (self);
}


#line 146 "project-dialog.vala"
static void valide_project_dialog_populate_icon_view (ValideProjectDialog* self) {
	GError * inner_error;
#line 146 "project-dialog.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG (self));
	inner_error = NULL;
	{
		ValideTemplateManager* _tmp0;
		GList* _tmp1;
		GList* files;
#line 150 "project-dialog.vala"
		_tmp0 = NULL;
#line 150 "project-dialog.vala"
		_tmp1 = NULL;
		files = (_tmp1 = valide_template_manager_get_list ((_tmp0 = valide_template_manager_get_instance ())), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1);
		{
			GList* filename_collection;
			GList* filename_it;
#line 152 "project-dialog.vala"
			filename_collection = files;
			for (filename_it = filename_collection; filename_it != NULL; filename_it = filename_it->next) {
				const char* _tmp2;
				char* filename;
				_tmp2 = NULL;
#line 152 "project-dialog.vala"
				filename = (_tmp2 = ((char*) filename_it->data), (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
				{
					{
						GtkTreeIter iter = {0};
						ValideTemplate* template;
						template = valide_template_new (filename);
#line 159 "project-dialog.vala"
						gtk_list_store_append (self->priv->list_store, &iter);
#line 160 "project-dialog.vala"
						gtk_list_store_set (self->priv->list_store, &iter, VALIDE_COLUMN_TYPE_ICON, valide_template_get_icon (template), VALIDE_COLUMN_TYPE_NAME, valide_template_get_name (template), VALIDE_COLUMN_TYPE_DESCRIPTION, valide_template_get_desc (template), VALIDE_COLUMN_TYPE_PATH, valide_template_get_path (template), -1, -1);
						(template == NULL ? NULL : (template = (g_object_unref (template), NULL)));
					}
					goto __finally6;
					__catch6_g_error:
					{
						GError * e;
						e = inner_error;
						inner_error = NULL;
						{
#line 168 "project-dialog.vala"
							g_warning (e->message);
						}
					}
					__finally6:
					;
					filename = (g_free (filename), NULL);
				}
			}
		}
		(files == NULL ? NULL : (files = (_g_list_free_g_free (files), NULL)));
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError * e;
		e = inner_error;
		inner_error = NULL;
		{
#line 174 "project-dialog.vala"
			g_warning (e->message);
		}
	}
	__finally5:
	;
}


#line 179 "project-dialog.vala"
static void valide_project_dialog_selection_changed (ValideProjectDialog* self, GtkIconView* icon_view) {
	GtkTreeIter iter = {0};
	GList* item;
#line 179 "project-dialog.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG (self));
#line 179 "project-dialog.vala"
	g_return_if_fail (GTK_IS_ICON_VIEW (icon_view));
	item = gtk_icon_view_get_selected_items (self->priv->icon_view);
#line 185 "project-dialog.vala"
	if (item != NULL) {
		GtkTreePath* path;
		GtkTreePath* path2;
		char* tmp;
		char* _tmp0;
		path = item->data;
		path2 = gtk_tree_path_new_from_string (gtk_tree_path_to_string (path));
#line 189 "project-dialog.vala"
		gtk_tree_model_get_iter (GTK_TREE_MODEL (self->priv->list_store), &iter, path2);
		tmp = NULL;
#line 192 "project-dialog.vala"
		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->list_store), &iter, VALIDE_COLUMN_TYPE_PATH, &tmp, -1);
		_tmp0 = NULL;
#line 193 "project-dialog.vala"
		self->priv->template_path_ = (_tmp0 = g_build_filename (tmp, "template.xml", NULL), (self->priv->template_path_ = (g_free (self->priv->template_path_), NULL)), _tmp0);
#line 195 "project-dialog.vala"
		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->list_store), &iter, VALIDE_COLUMN_TYPE_DESCRIPTION, &tmp, -1);
#line 196 "project-dialog.vala"
		valide_project_dialog_set_project_desc (self, tmp);
		(path2 == NULL ? NULL : (path2 = (gtk_tree_path_free (path2), NULL)));
		tmp = (g_free (tmp), NULL);
	}
}


#line 201 "project-dialog.vala"
static void valide_project_dialog_btn_clicked (ValideProjectDialog* self) {
	GtkFileChooserDialog* dialog;
#line 201 "project-dialog.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG (self));
	dialog = g_object_ref_sink (gtk_file_chooser_dialog_new (_ ("Select projects directory"), NULL, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL, NULL));
#line 211 "project-dialog.vala"
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
#line 213 "project-dialog.vala"
		gtk_entry_set_text (self->priv->dir_entry, gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog)));
	}
#line 215 "project-dialog.vala"
	gtk_object_destroy (GTK_OBJECT (dialog));
	(dialog == NULL ? NULL : (dialog = (g_object_unref (dialog), NULL)));
}


#line 219 "project-dialog.vala"
static void valide_project_dialog_project_path_change (ValideProjectDialog* self) {
	char* _tmp1;
	char* _tmp0;
#line 219 "project-dialog.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG (self));
	_tmp1 = NULL;
#line 221 "project-dialog.vala"
	_tmp0 = NULL;
#line 221 "project-dialog.vala"
	gtk_entry_set_text (self->priv->path_entry, (_tmp1 = g_strconcat ((_tmp0 = g_build_filename (gtk_entry_get_text (self->priv->dir_entry), valide_project_dialog_get_project_name (self), NULL)), G_DIR_SEPARATOR_S, NULL)));
	_tmp1 = (g_free (_tmp1), NULL);
	_tmp0 = (g_free (_tmp0), NULL);
}


const char* valide_project_dialog_get_project_name (ValideProjectDialog* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG (self), NULL);
#line 48 "project-dialog.vala"
	return gtk_entry_get_text (self->priv->name_entry);
}


const char* valide_project_dialog_get_project_path (ValideProjectDialog* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG (self), NULL);
#line 56 "project-dialog.vala"
	return gtk_entry_get_text (self->priv->path_entry);
}


const char* valide_project_dialog_get_project_dir (ValideProjectDialog* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG (self), NULL);
#line 64 "project-dialog.vala"
	return gtk_entry_get_text (self->priv->dir_entry);
}


const char* valide_project_dialog_get_template (ValideProjectDialog* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_DIALOG (self), NULL);
#line 72 "project-dialog.vala"
	return self->priv->template_path_;
}


void valide_project_dialog_set_project_desc (ValideProjectDialog* self, const char* value) {
	char* _tmp0;
	g_return_if_fail (VALIDE_IS_PROJECT_DIALOG (self));
	_tmp0 = NULL;
#line 80 "project-dialog.vala"
	gtk_label_set_text (self->priv->desc_label, (_tmp0 = g_strconcat (_ ("Description: "), value, NULL)));
	_tmp0 = (g_free (_tmp0), NULL);
}


#line 219 "project-dialog.vala"
static void _valide_project_dialog_project_path_change_gtk_editable_changed (GtkEditable* sender, gpointer self) {
	valide_project_dialog_project_path_change (self);
}


#line 201 "project-dialog.vala"
static void _valide_project_dialog_btn_clicked_gtk_button_clicked (GtkButton* sender, gpointer self) {
	valide_project_dialog_btn_clicked (self);
}


#line 179 "project-dialog.vala"
static void _valide_project_dialog_selection_changed_gtk_icon_view_selection_changed (GtkIconView* sender, gpointer self) {
	valide_project_dialog_selection_changed (self, sender);
}


static GObject * valide_project_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	ValideProjectDialogClass * klass;
	GObjectClass * parent_class;
	ValideProjectDialog * self;
	klass = VALIDE_PROJECT_DIALOG_CLASS (g_type_class_peek (VALIDE_TYPE_PROJECT_DIALOG));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = VALIDE_PROJECT_DIALOG (obj);
	{
		GtkListStore* _tmp0;
		GtkIconView* _tmp1;
		GtkBox* main_box;
		GtkLabel* _tmp2;
		GtkHBox* hbox;
		GtkVBox* vbox;
		GtkLabel* _tmp3;
		GtkLabel* _tmp4;
		GtkLabel* _tmp5;
		GtkVBox* _tmp6;
		GtkEntry* _tmp7;
		GtkHBox* hbox2;
		GtkEntry* _tmp8;
		GtkButton* button;
		GtkEntry* _tmp9;
		GtkTreePath* _tmp10;
		_tmp0 = NULL;
#line 86 "project-dialog.vala"
		self->priv->list_store = (_tmp0 = gtk_list_store_new (((gint) VALIDE_COLUMN_TYPE_NB_COLUMNS), GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, NULL), (self->priv->list_store == NULL ? NULL : (self->priv->list_store = (g_object_unref (self->priv->list_store), NULL))), _tmp0);
		_tmp1 = NULL;
#line 91 "project-dialog.vala"
		self->priv->icon_view = (_tmp1 = g_object_ref_sink (gtk_icon_view_new ()), (self->priv->icon_view == NULL ? NULL : (self->priv->icon_view = (g_object_unref (self->priv->icon_view), NULL))), _tmp1);
#line 92 "project-dialog.vala"
		gtk_icon_view_set_selection_mode (self->priv->icon_view, GTK_SELECTION_SINGLE);
#line 93 "project-dialog.vala"
		gtk_icon_view_set_pixbuf_column (self->priv->icon_view, 0);
#line 94 "project-dialog.vala"
		gtk_icon_view_set_text_column (self->priv->icon_view, 1);
#line 95 "project-dialog.vala"
		gtk_icon_view_set_model (self->priv->icon_view, GTK_TREE_MODEL (self->priv->list_store));
#line 96 "project-dialog.vala"
		valide_project_dialog_populate_icon_view (self);
		main_box = GTK_BOX (GTK_DIALOG (self)->vbox);
#line 98 "project-dialog.vala"
		gtk_box_pack_start (main_box, GTK_WIDGET (self->priv->icon_view), TRUE, TRUE, ((guint) 0));
		_tmp2 = NULL;
#line 100 "project-dialog.vala"
		self->priv->desc_label = (_tmp2 = g_object_ref_sink (gtk_label_new ("")), (self->priv->desc_label == NULL ? NULL : (self->priv->desc_label = (g_object_unref (self->priv->desc_label), NULL))), _tmp2);
#line 101 "project-dialog.vala"
		gtk_box_pack_start (main_box, GTK_WIDGET (self->priv->desc_label), FALSE, TRUE, ((guint) 5));
		hbox = g_object_ref_sink (gtk_hbox_new (FALSE, 20));
		vbox = g_object_ref_sink (gtk_vbox_new (TRUE, 0));
#line 105 "project-dialog.vala"
		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (vbox), FALSE, TRUE, ((guint) 0));
#line 106 "project-dialog.vala"
		_tmp3 = NULL;
#line 106 "project-dialog.vala"
		gtk_container_add (GTK_CONTAINER (vbox), GTK_WIDGET ((_tmp3 = g_object_ref_sink (gtk_label_new (_ ("Project name : "))))));
		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
#line 107 "project-dialog.vala"
		_tmp4 = NULL;
#line 107 "project-dialog.vala"
		gtk_container_add (GTK_CONTAINER (vbox), GTK_WIDGET ((_tmp4 = g_object_ref_sink (gtk_label_new (_ ("Project directory : "))))));
		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
#line 108 "project-dialog.vala"
		_tmp5 = NULL;
#line 108 "project-dialog.vala"
		gtk_container_add (GTK_CONTAINER (vbox), GTK_WIDGET ((_tmp5 = g_object_ref_sink (gtk_label_new (_ ("Project path : "))))));
		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
		_tmp6 = NULL;
#line 109 "project-dialog.vala"
		vbox = (_tmp6 = g_object_ref_sink (gtk_vbox_new (TRUE, 0)), (vbox == NULL ? NULL : (vbox = (g_object_unref (vbox), NULL))), _tmp6);
#line 110 "project-dialog.vala"
		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (vbox), TRUE, TRUE, ((guint) 0));
		_tmp7 = NULL;
#line 111 "project-dialog.vala"
		self->priv->name_entry = (_tmp7 = g_object_ref_sink (gtk_entry_new ()), (self->priv->name_entry == NULL ? NULL : (self->priv->name_entry = (g_object_unref (self->priv->name_entry), NULL))), _tmp7);
#line 112 "project-dialog.vala"
		g_signal_connect_object (self->priv->name_entry, "changed", ((GCallback) _valide_project_dialog_project_path_change_gtk_editable_changed), self, 0);
#line 113 "project-dialog.vala"
		gtk_container_add (GTK_CONTAINER (vbox), GTK_WIDGET (self->priv->name_entry));
		hbox2 = g_object_ref_sink (gtk_hbox_new (FALSE, 0));
#line 116 "project-dialog.vala"
		gtk_container_add (GTK_CONTAINER (vbox), GTK_WIDGET (hbox2));
		_tmp8 = NULL;
#line 118 "project-dialog.vala"
		self->priv->dir_entry = (_tmp8 = g_object_ref_sink (gtk_entry_new ()), (self->priv->dir_entry == NULL ? NULL : (self->priv->dir_entry = (g_object_unref (self->priv->dir_entry), NULL))), _tmp8);
#line 119 "project-dialog.vala"
		g_signal_connect_object (self->priv->dir_entry, "changed", ((GCallback) _valide_project_dialog_project_path_change_gtk_editable_changed), self, 0);
#line 120 "project-dialog.vala"
		gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (self->priv->dir_entry), TRUE, TRUE, ((guint) 0));
		button = g_object_ref_sink (gtk_button_new_with_label ("..."));
#line 123 "project-dialog.vala"
		g_signal_connect_object (button, "clicked", ((GCallback) _valide_project_dialog_btn_clicked_gtk_button_clicked), self, 0);
#line 124 "project-dialog.vala"
		gtk_box_pack_start (GTK_BOX (hbox2), GTK_WIDGET (button), FALSE, TRUE, ((guint) 0));
		_tmp9 = NULL;
#line 126 "project-dialog.vala"
		self->priv->path_entry = (_tmp9 = g_object_ref_sink (gtk_entry_new ()), (self->priv->path_entry == NULL ? NULL : (self->priv->path_entry = (g_object_unref (self->priv->path_entry), NULL))), _tmp9);
#line 127 "project-dialog.vala"
		gtk_container_add (GTK_CONTAINER (vbox), GTK_WIDGET (self->priv->path_entry));
#line 128 "project-dialog.vala"
		gtk_box_pack_start (main_box, GTK_WIDGET (hbox), FALSE, TRUE, ((guint) 0));
#line 130 "project-dialog.vala"
		gtk_dialog_add_button (GTK_DIALOG (self), GTK_STOCK_CANCEL, ((gint) GTK_RESPONSE_CANCEL));
#line 131 "project-dialog.vala"
		gtk_dialog_add_button (GTK_DIALOG (self), GTK_STOCK_OK, ((gint) GTK_RESPONSE_OK));
#line 132 "project-dialog.vala"
		gtk_window_set_modal (GTK_WINDOW (self), TRUE);
#line 133 "project-dialog.vala"
		g_signal_connect_object (self->priv->icon_view, "selection-changed", ((GCallback) _valide_project_dialog_selection_changed_gtk_icon_view_selection_changed), self, 0);
#line 134 "project-dialog.vala"
		_tmp10 = NULL;
#line 134 "project-dialog.vala"
		gtk_icon_view_select_path (self->priv->icon_view, (_tmp10 = gtk_tree_path_new_from_string ("0")));
		(_tmp10 == NULL ? NULL : (_tmp10 = (gtk_tree_path_free (_tmp10), NULL)));
#line 135 "project-dialog.vala"
		gtk_widget_show_all (GTK_WIDGET (main_box));
#line 136 "project-dialog.vala"
		gtk_widget_grab_focus (GTK_WIDGET (self->priv->name_entry));
		(hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL)));
		(vbox == NULL ? NULL : (vbox = (g_object_unref (vbox), NULL)));
		(hbox2 == NULL ? NULL : (hbox2 = (g_object_unref (hbox2), NULL)));
		(button == NULL ? NULL : (button = (g_object_unref (button), NULL)));
	}
	return obj;
}


static void valide_project_dialog_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValideProjectDialog * self;
	self = VALIDE_PROJECT_DIALOG (object);
	switch (property_id) {
		case VALIDE_PROJECT_DIALOG_PROJECT_NAME:
		g_value_set_string (value, valide_project_dialog_get_project_name (self));
		break;
		case VALIDE_PROJECT_DIALOG_PROJECT_PATH:
		g_value_set_string (value, valide_project_dialog_get_project_path (self));
		break;
		case VALIDE_PROJECT_DIALOG_PROJECT_DIR:
		g_value_set_string (value, valide_project_dialog_get_project_dir (self));
		break;
		case VALIDE_PROJECT_DIALOG_TEMPLATE:
		g_value_set_string (value, valide_project_dialog_get_template (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_project_dialog_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValideProjectDialog * self;
	self = VALIDE_PROJECT_DIALOG (object);
	switch (property_id) {
		case VALIDE_PROJECT_DIALOG_PROJECT_DESC:
		valide_project_dialog_set_project_desc (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_project_dialog_class_init (ValideProjectDialogClass * klass) {
	valide_project_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideProjectDialogPrivate));
	G_OBJECT_CLASS (klass)->get_property = valide_project_dialog_get_property;
	G_OBJECT_CLASS (klass)->set_property = valide_project_dialog_set_property;
	G_OBJECT_CLASS (klass)->constructor = valide_project_dialog_constructor;
	G_OBJECT_CLASS (klass)->dispose = valide_project_dialog_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_PROJECT_NAME, g_param_spec_string ("project-name", "project-name", "project-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_PROJECT_PATH, g_param_spec_string ("project-path", "project-path", "project-path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_PROJECT_DIR, g_param_spec_string ("project-dir", "project-dir", "project-dir", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_TEMPLATE, g_param_spec_string ("template", "template", "template", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DIALOG_PROJECT_DESC, g_param_spec_string ("project-desc", "project-desc", "project-desc", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
}


static void valide_project_dialog_init (ValideProjectDialog * self) {
	self->priv = VALIDE_PROJECT_DIALOG_GET_PRIVATE (self);
}


static void valide_project_dialog_dispose (GObject * obj) {
	ValideProjectDialog * self;
	self = VALIDE_PROJECT_DIALOG (obj);
	(self->priv->list_store == NULL ? NULL : (self->priv->list_store = (g_object_unref (self->priv->list_store), NULL)));
	(self->priv->icon_view == NULL ? NULL : (self->priv->icon_view = (g_object_unref (self->priv->icon_view), NULL)));
	(self->priv->desc_label == NULL ? NULL : (self->priv->desc_label = (g_object_unref (self->priv->desc_label), NULL)));
	(self->priv->name_entry == NULL ? NULL : (self->priv->name_entry = (g_object_unref (self->priv->name_entry), NULL)));
	(self->priv->dir_entry == NULL ? NULL : (self->priv->dir_entry = (g_object_unref (self->priv->dir_entry), NULL)));
	(self->priv->path_entry == NULL ? NULL : (self->priv->path_entry = (g_object_unref (self->priv->path_entry), NULL)));
	self->priv->template_path_ = (g_free (self->priv->template_path_), NULL);
	G_OBJECT_CLASS (valide_project_dialog_parent_class)->dispose (obj);
}


GType valide_project_dialog_get_type (void) {
	static GType valide_project_dialog_type_id = 0;
	if (G_UNLIKELY (valide_project_dialog_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideProjectDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_project_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideProjectDialog), 0, (GInstanceInitFunc) valide_project_dialog_init };
		valide_project_dialog_type_id = g_type_register_static (GTK_TYPE_DIALOG, "ValideProjectDialog", &g_define_type_info, 0);
	}
	return valide_project_dialog_type_id;
}




