/* project-manager.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/project-manager.h>
#include <libxml/parser.h>
#include <libxml/tree.h>
#include <libxml/xpath.h>
#include <glib/gstdio.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>
#include <config.h>
#include "src/template.h"
#include "src/uimanager.h"
#include "src/project-dialog.h"
#include "src/recent-manager-ui.h"




struct _ValideProjectManagerPrivate {
	ValideProject* project;
	GList* projects;
	GtkTreeStore* tree_store;
	ValideProject* current_;
	GtkMenu* popup;
};

#define VALIDE_PROJECT_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_PROJECT_MANAGER, ValideProjectManagerPrivate))
enum  {
	VALIDE_PROJECT_MANAGER_DUMMY_PROPERTY,
	VALIDE_PROJECT_MANAGER_CURRENT
};
static ValideProjectManager* valide_project_manager_instance = NULL;
static void _g_list_free_g_object_unref (GList* self);
static char* valide_project_manager_copy_template (ValideProjectManager* self, ValideTemplate* template, const char* path, const char* name, GError** error);
static ValideProjectManager* valide_project_manager_new (void);
static gboolean valide_project_manager_button_press (ValideProjectManager* self, GdkEventButton* event);
static void valide_project_manager_file_select (ValideProjectManager* self, GtkTreeView* sender, GtkTreePath* path, GtkTreeViewColumn* column);
static void valide_project_manager_setup_ui (ValideProjectManager* self);
static void _valide_project_manager_close_valide_project_closed (ValideProject* sender, gpointer self);
static void _valide_project_manager_refresh_valide_project_added_file (ValideProject* sender, gpointer self);
static void _valide_project_manager_refresh_valide_project_removed_file (ValideProject* sender, gpointer self);
static void valide_project_manager_refresh (ValideProjectManager* self);
static void _valide_project_manager_file_select_gtk_tree_view_row_activated (GtkTreeView* sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self);
static gboolean _valide_project_manager_button_press_gtk_widget_button_press_event (GtkWidget* sender, GdkEvent* event, gpointer self);
static GObject * valide_project_manager_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer valide_project_manager_parent_class = NULL;
static void valide_project_manager_dispose (GObject * obj);



GQuark project_error_quark (void) {
	return g_quark_from_static_string ("project_error-quark");
}


static void _g_list_free_g_object_unref (GList* self) {
	g_list_foreach (self, ((GFunc) g_object_unref), NULL);
	g_list_free (self);
}


#line 39 "project-manager.vala"
static char* valide_project_manager_copy_template (ValideProjectManager* self, ValideTemplate* template, const char* path, const char* name, GError** error) {
	GError * inner_error;
	char* filename;
	xmlDoc* xml;
	xmlXPathContext* xpath;
	xmlXPathObject* xpath_obj;
	char* _tmp1;
	char* _tmp0;
	char* _tmp7;
#line 39 "project-manager.vala"
	g_return_val_if_fail (VALIDE_IS_PROJECT_MANAGER (self), NULL);
#line 39 "project-manager.vala"
	g_return_val_if_fail (VALIDE_IS_TEMPLATE (template), NULL);
#line 39 "project-manager.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 39 "project-manager.vala"
	g_return_val_if_fail (name != NULL, NULL);
	inner_error = NULL;
	filename = NULL;
	/* Transform XML*/
	xml = xmlParseFile (valide_template_get_filename (template));
	xpath = xmlXPathNewContext (xml);
	xpath_obj = xmlXPathEval ("/template", xpath);
#line 48 "project-manager.vala"
	xmlXPathNodeSetItem (xpath_obj->nodesetval, 0)->name = "project";
#line 50 "project-manager.vala"
	xpath_obj = xmlXPathEval ("/project/description", xpath);
#line 51 "project-manager.vala"
	xmlUnlinkNode (xmlXPathNodeSetItem (xpath_obj->nodesetval, 0));
#line 52 "project-manager.vala"
	xpath_obj = xmlXPathEval ("/project/icon", xpath);
#line 53 "project-manager.vala"
	xmlUnlinkNode (xmlXPathNodeSetItem (xpath_obj->nodesetval, 0));
#line 54 "project-manager.vala"
	xpath_obj = xmlXPathEval ("/project/name", xpath);
#line 55 "project-manager.vala"
	xmlNodeSetContent (xmlXPathNodeSetItem (xpath_obj->nodesetval, 0), name);
	/* Copy xml*/
	_tmp1 = NULL;
	_tmp0 = NULL;
#line 58 "project-manager.vala"
	filename = (_tmp1 = g_build_filename (path, (_tmp0 = g_strconcat (name, VALIDE_PROJECT_FILE_EXT, NULL)), NULL), (filename = (g_free (filename), NULL)), _tmp1);
	_tmp0 = (g_free (_tmp0), NULL);
#line 59 "project-manager.vala"
	xmlSaveFile (filename, xml);
	/* Copy source files*/
	{
		GList* file_collection;
		GList* file_it;
#line 62 "project-manager.vala"
		file_collection = valide_template_get_files (template);
		for (file_it = file_collection; file_it != NULL; file_it = file_it->next) {
			const char* _tmp6;
			char* file;
			_tmp6 = NULL;
#line 62 "project-manager.vala"
			file = (_tmp6 = ((char*) file_it->data), (_tmp6 == NULL ? NULL : g_strdup (_tmp6)));
			{
				char* contents;
				gboolean _tmp3;
				char* _tmp2;
				char* _tmp5;
				char* _tmp4;
				contents = NULL;
				_tmp2 = NULL;
#line 66 "project-manager.vala"
				_tmp3 = g_file_get_contents (file, &_tmp2, NULL, &inner_error);
#line 66 "project-manager.vala"
				(contents = (g_free (contents), NULL));
#line 66 "project-manager.vala"
				contents = _tmp2;
#line 66 "project-manager.vala"
				_tmp3;
				if (inner_error != NULL) {
					g_propagate_error (error, inner_error);
					return NULL;
				}
#line 67 "project-manager.vala"
				_tmp5 = NULL;
#line 67 "project-manager.vala"
				_tmp4 = NULL;
#line 67 "project-manager.vala"
				g_file_set_contents ((_tmp5 = g_build_filename (path, (_tmp4 = g_path_get_basename (file)), NULL)), contents, ((glong) -1), &inner_error);
				if (inner_error != NULL) {
					g_propagate_error (error, inner_error);
					return NULL;
				}
				_tmp5 = (g_free (_tmp5), NULL);
				_tmp4 = (g_free (_tmp4), NULL);
				file = (g_free (file), NULL);
				contents = (g_free (contents), NULL);
			}
		}
	}
#line 70 "project-manager.vala"
	_tmp7 = NULL;
#line 70 "project-manager.vala"
	return (_tmp7 = filename, (xpath == NULL ? NULL : (xpath = (xmlXPathFreeContext (xpath), NULL))), _tmp7);
}


#line 86 "project-manager.vala"
static ValideProjectManager* valide_project_manager_new (void) {
	ValideProjectManager * self;
	gint _tmp0;
	self = g_object_newv (VALIDE_TYPE_PROJECT_MANAGER, 0, NULL);
#line 88 "project-manager.vala"
	g_object_set (GTK_WIDGET (self), "width-request", 200, NULL);
#line 89 "project-manager.vala"
	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (self), FALSE);
	return self;
}


#line 109 "project-manager.vala"
static gboolean valide_project_manager_button_press (ValideProjectManager* self, GdkEventButton* event) {
#line 109 "project-manager.vala"
	g_return_val_if_fail (VALIDE_IS_PROJECT_MANAGER (self), FALSE);
#line 111 "project-manager.vala"
	if ((*event).button == 3 && (*event).type == GDK_BUTTON_PRESS) {
#line 113 "project-manager.vala"
		gtk_menu_popup (self->priv->popup, NULL, NULL, NULL, NULL, (*event).button, (*event).time);
#line 114 "project-manager.vala"
		return TRUE;
	}
#line 116 "project-manager.vala"
	return FALSE;
}


#line 120 "project-manager.vala"
static void valide_project_manager_file_select (ValideProjectManager* self, GtkTreeView* sender, GtkTreePath* path, GtkTreeViewColumn* column) {
#line 120 "project-manager.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_MANAGER (self));
#line 120 "project-manager.vala"
	g_return_if_fail (GTK_IS_TREE_VIEW (sender));
#line 120 "project-manager.vala"
	g_return_if_fail (path != NULL);
#line 120 "project-manager.vala"
	g_return_if_fail (GTK_IS_TREE_VIEW_COLUMN (column));
#line 123 "project-manager.vala"
	if (gtk_tree_path_get_depth (path) == 2) {
		GtkTreeIter iter = {0};
		char* filename;
		filename = NULL;
#line 128 "project-manager.vala"
		gtk_tree_model_get_iter (GTK_TREE_MODEL (self->priv->tree_store), &iter, path);
#line 129 "project-manager.vala"
		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->tree_store), &iter, 0, &filename, -1);
#line 130 "project-manager.vala"
		valide_project_open_file (valide_project_manager_get_current (self), filename);
		filename = (g_free (filename), NULL);
	} else {
	}
}


/*/@todo Active project
*/
#line 138 "project-manager.vala"
static void valide_project_manager_setup_ui (ValideProjectManager* self) {
	gboolean active;
	ValideUIManager* ui;
	GtkAction* _tmp0;
	GtkAction* _tmp1;
	GtkAction* _tmp2;
	GtkAction* _tmp3;
	GtkAction* _tmp4;
	GtkAction* _tmp5;
#line 138 "project-manager.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_MANAGER (self));
	active = FALSE;
	ui = valide_ui_manager_get_instance ();
#line 143 "project-manager.vala"
	if (valide_project_manager_get_current (self) != NULL) {
#line 145 "project-manager.vala"
		active = TRUE;
	}
#line 147 "project-manager.vala"
	_tmp0 = NULL;
#line 147 "project-manager.vala"
	gtk_action_set_sensitive ((_tmp0 = valide_ui_manager_get_action (ui, "project-add")), active);
	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
#line 148 "project-manager.vala"
	_tmp1 = NULL;
#line 148 "project-manager.vala"
	gtk_action_set_sensitive ((_tmp1 = valide_ui_manager_get_action (ui, "project-remove")), active);
	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
#line 149 "project-manager.vala"
	_tmp2 = NULL;
#line 149 "project-manager.vala"
	gtk_action_set_sensitive ((_tmp2 = valide_ui_manager_get_action (ui, "project-options")), active);
	(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
#line 150 "project-manager.vala"
	_tmp3 = NULL;
#line 150 "project-manager.vala"
	gtk_action_set_sensitive ((_tmp3 = valide_ui_manager_get_action (ui, "project-compile")), active);
	(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
#line 151 "project-manager.vala"
	_tmp4 = NULL;
#line 151 "project-manager.vala"
	gtk_action_set_sensitive ((_tmp4 = valide_ui_manager_get_action (ui, "project-execute")), active);
	(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
#line 152 "project-manager.vala"
	_tmp5 = NULL;
#line 152 "project-manager.vala"
	gtk_action_set_sensitive ((_tmp5 = valide_ui_manager_get_action (ui, "project-close")), active);
	(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
	(ui == NULL ? NULL : (ui = (g_object_unref (ui), NULL)));
}


#line 155 "project-manager.vala"
void valide_project_manager_destroy (ValideProjectManager* self) {
	ValideProjectManager* _tmp0;
#line 155 "project-manager.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_MANAGER (self));
	_tmp0 = NULL;
#line 157 "project-manager.vala"
	valide_project_manager_instance = (_tmp0 = NULL, (valide_project_manager_instance == NULL ? NULL : (valide_project_manager_instance = (g_object_unref (valide_project_manager_instance), NULL))), _tmp0);
#line 158 "project-manager.vala"
	gtk_object_destroy (GTK_OBJECT (GTK_TREE_VIEW (self)));
}


#line 161 "project-manager.vala"
ValideProjectManager* valide_project_manager_get_instance (void) {
	ValideProjectManager* _tmp1;
#line 163 "project-manager.vala"
	if (valide_project_manager_instance == NULL) {
		ValideProjectManager* _tmp0;
		_tmp0 = NULL;
#line 165 "project-manager.vala"
		valide_project_manager_instance = (_tmp0 = g_object_ref_sink (valide_project_manager_new ()), (valide_project_manager_instance == NULL ? NULL : (valide_project_manager_instance = (g_object_unref (valide_project_manager_instance), NULL))), _tmp0);
	}
#line 167 "project-manager.vala"
	_tmp1 = NULL;
#line 167 "project-manager.vala"
	return (_tmp1 = valide_project_manager_instance, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
}


#line 297 "project-manager.vala"
static void _valide_project_manager_close_valide_project_closed (ValideProject* sender, gpointer self) {
	valide_project_manager_close (self, sender);
}


#line 304 "project-manager.vala"
static void _valide_project_manager_refresh_valide_project_added_file (ValideProject* sender, gpointer self) {
	valide_project_manager_refresh (self);
}


#line 304 "project-manager.vala"
static void _valide_project_manager_refresh_valide_project_removed_file (ValideProject* sender, gpointer self) {
	valide_project_manager_refresh (self);
}


#line 170 "project-manager.vala"
void valide_project_manager_create (ValideProjectManager* self, const char* filename, GError** error) {
	GError * inner_error;
	char* prj;
#line 170 "project-manager.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_MANAGER (self));
	inner_error = NULL;
	prj = NULL;
#line 174 "project-manager.vala"
	if (valide_project_manager_get_current (self) == NULL) {
#line 176 "project-manager.vala"
		if (filename == NULL) {
			ValideProjectDialog* dialog;
			dialog = g_object_ref_sink (valide_project_dialog_new ());
#line 180 "project-manager.vala"
			if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
				gboolean create;
				const char* _tmp0;
				char* path;
				create = FALSE;
#line 183 "project-manager.vala"
				_tmp0 = NULL;
				path = (_tmp0 = valide_project_dialog_get_project_dir (dialog), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
#line 185 "project-manager.vala"
				if (!g_file_test (path, G_FILE_TEST_EXISTS)) {
					GtkDialog* msg;
					GtkBox* main_box;
					GtkLabel* _tmp1;
					msg = g_object_ref_sink (gtk_dialog_new_with_buttons (_ ("New project"), NULL, GTK_DIALOG_MODAL, GTK_STOCK_NO, GTK_RESPONSE_NO, GTK_STOCK_YES, GTK_RESPONSE_YES, NULL, NULL));
					main_box = GTK_BOX (msg->vbox);
#line 194 "project-manager.vala"
					_tmp1 = NULL;
#line 194 "project-manager.vala"
					gtk_box_pack_start (main_box, GTK_WIDGET ((_tmp1 = g_object_ref_sink (gtk_label_new (_ ("Projects directory doesn't exist. Would you create it?"))))), TRUE, TRUE, ((guint) 10));
					(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
#line 196 "project-manager.vala"
					gtk_widget_show_all (GTK_WIDGET (msg));
#line 197 "project-manager.vala"
					if (gtk_dialog_run (msg) == GTK_RESPONSE_YES) {
#line 199 "project-manager.vala"
						g_mkdir_with_parents (path, 0755);
#line 200 "project-manager.vala"
						create = TRUE;
					}
#line 202 "project-manager.vala"
					gtk_object_destroy (GTK_OBJECT (msg));
					(msg == NULL ? NULL : (msg = (g_object_unref (msg), NULL)));
				} else {
#line 206 "project-manager.vala"
					create = TRUE;
				}
#line 209 "project-manager.vala"
				if (create == TRUE) {
					char* _tmp3;
					const char* _tmp2;
					_tmp3 = NULL;
#line 211 "project-manager.vala"
					_tmp2 = NULL;
#line 211 "project-manager.vala"
					path = (_tmp3 = (_tmp2 = valide_project_dialog_get_project_path (dialog), (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (path = (g_free (path), NULL)), _tmp3);
#line 212 "project-manager.vala"
					if (g_file_test (path, G_FILE_TEST_EXISTS)) {
						GtkDialog* msg;
						GtkBox* main_box;
						GtkLabel* _tmp4;
						msg = g_object_ref_sink (gtk_dialog_new_with_buttons (_ ("New project"), NULL, GTK_DIALOG_MODAL, GTK_STOCK_NO, GTK_RESPONSE_NO, GTK_STOCK_YES, GTK_RESPONSE_YES, NULL, NULL));
						main_box = GTK_BOX (msg->vbox);
#line 221 "project-manager.vala"
						_tmp4 = NULL;
#line 221 "project-manager.vala"
						gtk_box_pack_start (main_box, GTK_WIDGET ((_tmp4 = g_object_ref_sink (gtk_label_new (_ ("Directory already exist. Would you overwrite it?"))))), TRUE, TRUE, ((guint) 10));
						(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
#line 223 "project-manager.vala"
						gtk_widget_show_all (GTK_WIDGET (msg));
#line 224 "project-manager.vala"
						if (gtk_dialog_run (msg) == GTK_RESPONSE_NO) {
#line 226 "project-manager.vala"
							create = FALSE;
						}
#line 228 "project-manager.vala"
						gtk_object_destroy (GTK_OBJECT (msg));
						(msg == NULL ? NULL : (msg = (g_object_unref (msg), NULL)));
					} else {
#line 232 "project-manager.vala"
						g_mkdir (path, 0755);
					}
				}
#line 236 "project-manager.vala"
				if (create == TRUE) {
					{
						char* _tmp6;
						ValideTemplate* _tmp5;
						_tmp6 = NULL;
#line 240 "project-manager.vala"
						_tmp5 = NULL;
#line 240 "project-manager.vala"
						prj = (_tmp6 = valide_project_manager_copy_template (self, (_tmp5 = valide_template_new (valide_project_dialog_get_template (dialog))), path, valide_project_dialog_get_project_name (dialog), &inner_error), (prj = (g_free (prj), NULL)), _tmp6);
						if (inner_error != NULL) {
							goto __catch7_g_error;
						}
						(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
					}
					goto __finally7;
					__catch7_g_error:
					{
						GError * e;
						e = inner_error;
						inner_error = NULL;
						{
#line 245 "project-manager.vala"
							g_warning (e->message);
						}
					}
					__finally7:
					;
				}
				path = (g_free (path), NULL);
			}
#line 249 "project-manager.vala"
			gtk_object_destroy (GTK_OBJECT (dialog));
			(dialog == NULL ? NULL : (dialog = (g_object_unref (dialog), NULL)));
		} else {
			char* _tmp8;
			const char* _tmp7;
			_tmp8 = NULL;
#line 253 "project-manager.vala"
			_tmp7 = NULL;
#line 253 "project-manager.vala"
			prj = (_tmp8 = (_tmp7 = filename, (_tmp7 == NULL ? NULL : g_strdup (_tmp7))), (prj = (g_free (prj), NULL)), _tmp8);
		}
#line 256 "project-manager.vala"
		if (prj != NULL) {
			ValideProject* p;
			ValideRecentManagerUI* _tmp9;
			ValideProject* _tmp10;
			p = valide_project_new (prj);
#line 260 "project-manager.vala"
			_tmp9 = NULL;
#line 260 "project-manager.vala"
			valide_recent_manager_ui_add_file ((_tmp9 = valide_recent_manager_ui_get_instance ()), prj);
			(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
#line 261 "project-manager.vala"
			g_signal_connect_object (p, "closed", ((GCallback) _valide_project_manager_close_valide_project_closed), self, 0);
#line 262 "project-manager.vala"
			g_signal_connect_object (p, "added-file", ((GCallback) _valide_project_manager_refresh_valide_project_added_file), self, 0);
#line 263 "project-manager.vala"
			g_signal_connect_object (p, "removed-file", ((GCallback) _valide_project_manager_refresh_valide_project_removed_file), self, 0);
#line 264 "project-manager.vala"
			_tmp10 = NULL;
#line 264 "project-manager.vala"
			self->priv->projects = g_list_append (self->priv->projects, (_tmp10 = p, (_tmp10 == NULL ? NULL : g_object_ref (_tmp10))));
#line 265 "project-manager.vala"
			valide_project_manager_set_current (self, p);
#line 266 "project-manager.vala"
			valide_project_manager_refresh (self);
			(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
		}
	} else {
		inner_error = g_error_new (PROJECT_ERROR, PROJECT_ERROR_MAX_OPEN, _ ("Maximum project open!"));
		if (inner_error != NULL) {
			g_propagate_error (error, inner_error);
			return;
		}
	}
	prj = (g_free (prj), NULL);
}


#line 275 "project-manager.vala"
void valide_project_manager_open (ValideProjectManager* self) {
	GError * inner_error;
	GtkFileChooserDialog* dialog;
	GtkFileFilter* _tmp0;
	char* _tmp1;
#line 275 "project-manager.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_MANAGER (self));
	inner_error = NULL;
	dialog = g_object_ref_sink (gtk_file_chooser_dialog_new (_ ("Open project"), NULL, GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL, NULL));
	/* Add filter */
#line 284 "project-manager.vala"
	_tmp0 = NULL;
#line 284 "project-manager.vala"
	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), (_tmp0 = g_object_ref_sink (gtk_file_filter_new ())));
	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
#line 285 "project-manager.vala"
	gtk_file_filter_set_name (gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog)), _ ("Val(a)IDE project file"));
	_tmp1 = NULL;
#line 286 "project-manager.vala"
	gtk_file_filter_add_pattern (gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog)), (_tmp1 = g_strconcat ("*", VALIDE_PROJECT_FILE_EXT, NULL)));
	_tmp1 = (g_free (_tmp1), NULL);
#line 288 "project-manager.vala"
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
		GtkRecentManager* _tmp2;
		GtkRecentManager* recent_manager;
#line 290 "project-manager.vala"
		valide_project_manager_create (self, gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog)), &inner_error);
		if (inner_error != NULL) {
			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
			g_clear_error (&inner_error);
		}
#line 291 "project-manager.vala"
		_tmp2 = NULL;
		recent_manager = (_tmp2 = gtk_recent_manager_get_default (), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
#line 292 "project-manager.vala"
		gtk_recent_manager_add_item (recent_manager, gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog)));
		(recent_manager == NULL ? NULL : (recent_manager = (g_object_unref (recent_manager), NULL)));
	}
#line 294 "project-manager.vala"
	gtk_object_destroy (GTK_OBJECT (dialog));
	(dialog == NULL ? NULL : (dialog = (g_object_unref (dialog), NULL)));
}


#line 297 "project-manager.vala"
void valide_project_manager_close (ValideProjectManager* self, ValideProject* sender) {
#line 297 "project-manager.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_MANAGER (self));
#line 297 "project-manager.vala"
	g_return_if_fail (VALIDE_IS_PROJECT (sender));
#line 299 "project-manager.vala"
	self->priv->projects = g_list_remove (self->priv->projects, sender);
#line 300 "project-manager.vala"
	valide_project_manager_set_current (self, NULL);
#line 301 "project-manager.vala"
	valide_project_manager_refresh (self);
}


#line 304 "project-manager.vala"
static void valide_project_manager_refresh (ValideProjectManager* self) {
#line 304 "project-manager.vala"
	g_return_if_fail (VALIDE_IS_PROJECT_MANAGER (self));
#line 306 "project-manager.vala"
	gtk_tree_store_clear (self->priv->tree_store);
	{
		GList* p_collection;
		GList* p_it;
#line 307 "project-manager.vala"
		p_collection = self->priv->projects;
		for (p_it = p_collection; p_it != NULL; p_it = p_it->next) {
			ValideProject* _tmp3;
			ValideProject* p;
			_tmp3 = NULL;
#line 307 "project-manager.vala"
			p = (_tmp3 = ((ValideProject*) p_it->data), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
			{
				char* title;
				GtkTreeIter root = {0};
				title = NULL;
#line 312 "project-manager.vala"
				gtk_tree_store_append (self->priv->tree_store, &root, NULL);
#line 314 "project-manager.vala"
				if (p == valide_project_manager_get_current (self)) {
					char* _tmp1;
					char* _tmp0;
					_tmp1 = NULL;
					_tmp0 = NULL;
#line 316 "project-manager.vala"
					gtk_tree_store_set (self->priv->tree_store, &root, 0, (_tmp1 = g_strconcat ((_tmp0 = g_strconcat ("<b>", valide_project_get_name (p), NULL)), "</b>", NULL)), -1, -1);
					_tmp1 = (g_free (_tmp1), NULL);
					_tmp0 = (g_free (_tmp0), NULL);
				} else {
#line 320 "project-manager.vala"
					gtk_tree_store_set (self->priv->tree_store, &root, 0, valide_project_get_name (p), -1, -1);
				}
				{
					GList* file_collection;
					GList* file_it;
#line 322 "project-manager.vala"
					file_collection = valide_project_get_files (p);
					for (file_it = file_collection; file_it != NULL; file_it = file_it->next) {
						const char* _tmp2;
						char* file;
						_tmp2 = NULL;
#line 322 "project-manager.vala"
						file = (_tmp2 = ((char*) file_it->data), (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
						{
							GtkTreeIter iter = {0};
#line 326 "project-manager.vala"
							gtk_tree_store_append (self->priv->tree_store, &iter, &root);
#line 327 "project-manager.vala"
							gtk_tree_store_set (self->priv->tree_store, &iter, 0, file, -1, -1);
							file = (g_free (file), NULL);
						}
					}
				}
				(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
				title = (g_free (title), NULL);
			}
		}
	}
#line 330 "project-manager.vala"
	valide_project_manager_setup_ui (self);
}


ValideProject* valide_project_manager_get_current (ValideProjectManager* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT_MANAGER (self), NULL);
#line 77 "project-manager.vala"
	return self->priv->current_;
}


void valide_project_manager_set_current (ValideProjectManager* self, ValideProject* value) {
	g_return_if_fail (VALIDE_IS_PROJECT_MANAGER (self));
#line 81 "project-manager.vala"
	self->priv->current_ = value;
#line 82 "project-manager.vala"
	valide_project_manager_refresh (self);
}


#line 120 "project-manager.vala"
static void _valide_project_manager_file_select_gtk_tree_view_row_activated (GtkTreeView* sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self) {
	valide_project_manager_file_select (self, sender, path, column);
}


#line 109 "project-manager.vala"
static gboolean _valide_project_manager_button_press_gtk_widget_button_press_event (GtkWidget* sender, GdkEvent* event, gpointer self) {
	return valide_project_manager_button_press (self, sender);
}


static GObject * valide_project_manager_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	ValideProjectManagerClass * klass;
	GObjectClass * parent_class;
	ValideProjectManager * self;
	GError * inner_error;
	klass = VALIDE_PROJECT_MANAGER_CLASS (g_type_class_peek (VALIDE_TYPE_PROJECT_MANAGER));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = VALIDE_PROJECT_MANAGER (obj);
	inner_error = NULL;
	{
		GtkTreeStore* _tmp0;
		GtkCellRendererText* render;
		GtkTreeViewColumn* column;
		ValideUIManager* ui_manager;
		char* _tmp1;
		GtkMenu* _tmp3;
		GtkMenu* _tmp2;
		_tmp0 = NULL;
#line 94 "project-manager.vala"
		self->priv->tree_store = (_tmp0 = gtk_tree_store_new (1, G_TYPE_STRING, NULL), (self->priv->tree_store == NULL ? NULL : (self->priv->tree_store = (g_object_unref (self->priv->tree_store), NULL))), _tmp0);
#line 95 "project-manager.vala"
		gtk_tree_view_set_model (GTK_TREE_VIEW (self), GTK_TREE_MODEL (self->priv->tree_store));
		render = g_object_ref_sink (gtk_cell_renderer_text_new ());
		column = g_object_ref_sink (gtk_tree_view_column_new_with_attributes (_ ("Projects"), GTK_CELL_RENDERER (render), "markup", 0, NULL, NULL));
#line 98 "project-manager.vala"
		gtk_tree_view_append_column (GTK_TREE_VIEW (self), column);
#line 99 "project-manager.vala"
		g_signal_connect_object (self, "row-activated", ((GCallback) _valide_project_manager_file_select_gtk_tree_view_row_activated), self, 0);
		/* Add popup */
		ui_manager = valide_ui_manager_get_instance ();
#line 102 "project-manager.vala"
		_tmp1 = NULL;
#line 102 "project-manager.vala"
		gtk_ui_manager_add_ui_from_file (GTK_UI_MANAGER (ui_manager), (_tmp1 = g_build_filename (PACKAGE_DATA_DIR, "valide-ui.xml", NULL)), &inner_error);
		if (inner_error != NULL) {
			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
			g_clear_error (&inner_error);
		}
		_tmp1 = (g_free (_tmp1), NULL);
		_tmp3 = NULL;
#line 103 "project-manager.vala"
		_tmp2 = NULL;
#line 103 "project-manager.vala"
		self->priv->popup = (_tmp3 = (_tmp2 = GTK_MENU (gtk_ui_manager_get_widget (GTK_UI_MANAGER (ui_manager), "/project-popup")), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (self->priv->popup == NULL ? NULL : (self->priv->popup = (g_object_unref (self->priv->popup), NULL))), _tmp3);
#line 104 "project-manager.vala"
		g_signal_connect_object (self, "button-press-event", ((GCallback) _valide_project_manager_button_press_gtk_widget_button_press_event), self, 0);
#line 105 "project-manager.vala"
		valide_project_manager_setup_ui (self);
		(render == NULL ? NULL : (render = (g_object_unref (render), NULL)));
		(column == NULL ? NULL : (column = (g_object_unref (column), NULL)));
		(ui_manager == NULL ? NULL : (ui_manager = (g_object_unref (ui_manager), NULL)));
	}
	return obj;
}


static void valide_project_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValideProjectManager * self;
	self = VALIDE_PROJECT_MANAGER (object);
	switch (property_id) {
		case VALIDE_PROJECT_MANAGER_CURRENT:
		g_value_set_object (value, valide_project_manager_get_current (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_project_manager_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValideProjectManager * self;
	self = VALIDE_PROJECT_MANAGER (object);
	switch (property_id) {
		case VALIDE_PROJECT_MANAGER_CURRENT:
		valide_project_manager_set_current (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_project_manager_class_init (ValideProjectManagerClass * klass) {
	valide_project_manager_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideProjectManagerPrivate));
	G_OBJECT_CLASS (klass)->get_property = valide_project_manager_get_property;
	G_OBJECT_CLASS (klass)->set_property = valide_project_manager_set_property;
	G_OBJECT_CLASS (klass)->constructor = valide_project_manager_constructor;
	G_OBJECT_CLASS (klass)->dispose = valide_project_manager_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_MANAGER_CURRENT, g_param_spec_object ("current", "current", "current", VALIDE_TYPE_PROJECT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void valide_project_manager_init (ValideProjectManager * self) {
	self->priv = VALIDE_PROJECT_MANAGER_GET_PRIVATE (self);
}


static void valide_project_manager_dispose (GObject * obj) {
	ValideProjectManager * self;
	self = VALIDE_PROJECT_MANAGER (obj);
	(self->priv->project == NULL ? NULL : (self->priv->project = (g_object_unref (self->priv->project), NULL)));
	(self->priv->projects == NULL ? NULL : (self->priv->projects = (_g_list_free_g_object_unref (self->priv->projects), NULL)));
	(self->priv->tree_store == NULL ? NULL : (self->priv->tree_store = (g_object_unref (self->priv->tree_store), NULL)));
	(self->priv->popup == NULL ? NULL : (self->priv->popup = (g_object_unref (self->priv->popup), NULL)));
	G_OBJECT_CLASS (valide_project_manager_parent_class)->dispose (obj);
}


GType valide_project_manager_get_type (void) {
	static GType valide_project_manager_type_id = 0;
	if (G_UNLIKELY (valide_project_manager_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideProjectManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_project_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideProjectManager), 0, (GInstanceInitFunc) valide_project_manager_init };
		valide_project_manager_type_id = g_type_register_static (GTK_TYPE_TREE_VIEW, "ValideProjectManager", &g_define_type_info, 0);
	}
	return valide_project_manager_type_id;
}




