/* project.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/project.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <glib/gstdio.h>
#include <libxml/xpath.h>
#include <libxml/tree.h>
#include "src/compiler.h"
#include "src/executable.h"
#include "src/document-manager.h"
#include "src/document.h"
#include "src/third-party/utils.h"
#include "src/project-dialog-remove.h"
#include "src/project-dialog-options.h"
#include "src/third-party/abstract-executable.h"




struct _ValideProjectPrivate {
	char* path_;
	char* filename_;
	char* working_dir;
	ValideCompiler* compiler;
	ValideExecutable* executable;
};

#define VALIDE_PROJECT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_PROJECT, ValideProjectPrivate))
enum  {
	VALIDE_PROJECT_DUMMY_PROPERTY,
	VALIDE_PROJECT_FILENAME,
	VALIDE_PROJECT_PATH,
	VALIDE_PROJECT_FILES,
	VALIDE_PROJECT_PKG,
	VALIDE_PROJECT_VAPI_DIR,
	VALIDE_PROJECT_DEBUG,
	VALIDE_PROJECT_THREAD,
	VALIDE_PROJECT_DISABLE_ASSERT,
	VALIDE_PROJECT_DISABLE_CHECKING,
	VALIDE_PROJECT_DISABLE_NON_NULL,
	VALIDE_PROJECT_SAVE_TEMPS,
	VALIDE_PROJECT_QUIET,
	VALIDE_PROJECT_VERBOSE,
	VALIDE_PROJECT_NAME,
	VALIDE_PROJECT_COMPILER_OPTIONS,
	VALIDE_PROJECT_EXECUTABLE_OPTIONS
};
static gboolean valide_project_exist (ValideProject* self, const char* filename);
static void _g_list_free_g_free (GList* self);
static gpointer valide_project_parent_class = NULL;
static void valide_project_dispose (GObject * obj);
static int _vala_strcmp0 (const char * str1, const char * str2);



#line 39 "project.vala"
static gboolean valide_project_exist (ValideProject* self, const char* filename) {
	gboolean ret;
#line 39 "project.vala"
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), FALSE);
#line 39 "project.vala"
	g_return_val_if_fail (filename != NULL, FALSE);
	ret = FALSE;
	{
		GList* file_collection;
		GList* file_it;
#line 43 "project.vala"
		file_collection = valide_project_get_files (self);
		for (file_it = file_collection; file_it != NULL; file_it = file_it->next) {
			const char* _tmp0;
			char* file;
			_tmp0 = NULL;
#line 43 "project.vala"
			file = (_tmp0 = ((char*) file_it->data), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
			{
#line 45 "project.vala"
				if (_vala_strcmp0 (file, filename) == 0) {
#line 47 "project.vala"
					ret = TRUE;
					file = (g_free (file), NULL);
#line 48 "project.vala"
					break;
				}
				file = (g_free (file), NULL);
			}
		}
	}
#line 51 "project.vala"
	return ret;
}


#line 411 "project.vala"
ValideProject* valide_project_new (const char* filename) {
	ValideProject * self;
#line 411 "project.vala"
	g_return_val_if_fail (filename != NULL, NULL);
	self = g_object_newv (VALIDE_TYPE_PROJECT, 0, NULL);
#line 413 "project.vala"
	valide_project_set_filename (self, filename);
	return self;
}


#line 416 "project.vala"
void valide_project_close (ValideProject* self) {
	ValideDocumentManager* _tmp0;
	gboolean _tmp1;
#line 416 "project.vala"
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 418 "project.vala"
	_tmp0 = NULL;
#line 418 "project.vala"
	if ((_tmp1 = valide_document_manager_close_all ((_tmp0 = valide_document_manager_get_instance ())), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
#line 420 "project.vala"
		g_signal_emit_by_name (G_OBJECT (self), "closed");
	}
}


#line 424 "project.vala"
void valide_project_open_file (ValideProject* self, const char* filename) {
	char* _tmp1;
	ValideDocumentManager* _tmp0;
#line 424 "project.vala"
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 424 "project.vala"
	g_return_if_fail (filename != NULL);
#line 427 "project.vala"
	_tmp1 = NULL;
#line 426 "project.vala"
	_tmp0 = NULL;
#line 426 "project.vala"
	valide_document_manager_create ((_tmp0 = valide_document_manager_get_instance ()), (_tmp1 = g_build_filename (valide_project_get_path (self), filename, NULL, NULL)));
	_tmp1 = (g_free (_tmp1), NULL);
	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
}


#line 430 "project.vala"
void valide_project_add_file (ValideProject* self) {
	GtkFileChooserDialog* dialog;
	GtkFileFilter* _tmp0;
	char* _tmp1;
#line 430 "project.vala"
	g_return_if_fail (VALIDE_IS_PROJECT (self));
	dialog = g_object_ref_sink (gtk_file_chooser_dialog_new (_ ("Add file"), NULL, GTK_FILE_CHOOSER_ACTION_OPEN, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_ADD, GTK_RESPONSE_ACCEPT, NULL));
#line 437 "project.vala"
	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), valide_project_get_path (self));
	/* Add filter */
#line 440 "project.vala"
	_tmp0 = NULL;
#line 440 "project.vala"
	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), (_tmp0 = g_object_ref_sink (gtk_file_filter_new ())));
	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
#line 441 "project.vala"
	gtk_file_filter_set_name (gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog)), _ ("Vala source file"));
	_tmp1 = NULL;
#line 442 "project.vala"
	gtk_file_filter_add_pattern (gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog)), (_tmp1 = g_strconcat ("*", VALIDE_DOCUMENT_FILE_EXT, NULL)));
	_tmp1 = (g_free (_tmp1), NULL);
#line 444 "project.vala"
	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (dialog), TRUE);
#line 446 "project.vala"
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
		GSList* files;
		files = gtk_file_chooser_get_uris (GTK_FILE_CHOOSER (dialog));
		{
			GSList* file_collection;
			GSList* file_it;
#line 450 "project.vala"
			file_collection = files;
			for (file_it = file_collection; file_it != NULL; file_it = file_it->next) {
				const char* _tmp4;
				char* file;
				_tmp4 = NULL;
#line 450 "project.vala"
				file = (_tmp4 = ((char*) file_it->data), (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
				{
					char* _tmp2;
					char* _tmp3;
					char* filename;
					_tmp2 = NULL;
#line 452 "project.vala"
					_tmp3 = NULL;
					filename = (_tmp3 = valide_path_get_relative_path (file, (_tmp2 = g_strconcat ("file://", valide_project_get_path (self), NULL))), (_tmp2 = (g_free (_tmp2), NULL)), _tmp3);
#line 454 "project.vala"
					if (!valide_project_exist (self, filename)) {
#line 456 "project.vala"
						valide_markup_add_child (valide_project_get_filename (self), "/project/files", "file", filename);
#line 457 "project.vala"
						g_signal_emit_by_name (G_OBJECT (self), "added-file");
					} else {
#line 461 "project.vala"
						g_message (_ ("File already '%s' added!"), filename);
					}
					file = (g_free (file), NULL);
					filename = (g_free (filename), NULL);
				}
			}
		}
	}
#line 465 "project.vala"
	gtk_object_destroy (GTK_OBJECT (dialog));
	(dialog == NULL ? NULL : (dialog = (g_object_unref (dialog), NULL)));
}


#line 468 "project.vala"
void valide_project_remove_file (ValideProject* self) {
	ValideProjectDialogRemove* dialog;
#line 468 "project.vala"
	g_return_if_fail (VALIDE_IS_PROJECT (self));
	dialog = g_object_ref_sink (valide_project_dialog_remove_new (self));
#line 471 "project.vala"
	gtk_widget_show_all (GTK_WIDGET (dialog));
#line 472 "project.vala"
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
		{
			GList* file_collection;
			GList* file_it;
#line 474 "project.vala"
			file_collection = valide_project_dialog_remove_get_selected_files (dialog);
			for (file_it = file_collection; file_it != NULL; file_it = file_it->next) {
				const char* _tmp4;
				char* file;
				_tmp4 = NULL;
#line 474 "project.vala"
				file = (_tmp4 = ((char*) file_it->data), (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
				{
					char* _tmp0;
					char* _tmp1;
					char* filename;
					char* _tmp3;
					char* _tmp2;
					_tmp0 = NULL;
#line 476 "project.vala"
					_tmp1 = NULL;
					filename = (_tmp1 = valide_path_get_relative_path (file, (_tmp0 = g_strconcat ("file://", valide_project_get_path (self), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
					_tmp3 = NULL;
					_tmp2 = NULL;
#line 478 "project.vala"
					valide_markup_remove (valide_project_get_filename (self), (_tmp3 = g_strconcat ((_tmp2 = g_strconcat ("/project/files/file[.='", filename, NULL)), "']", NULL)));
					_tmp3 = (g_free (_tmp3), NULL);
					_tmp2 = (g_free (_tmp2), NULL);
					file = (g_free (file), NULL);
					filename = (g_free (filename), NULL);
				}
			}
		}
#line 480 "project.vala"
		g_signal_emit_by_name (G_OBJECT (self), "removed-file");
	}
#line 482 "project.vala"
	gtk_object_destroy (GTK_OBJECT (dialog));
	(dialog == NULL ? NULL : (dialog = (g_object_unref (dialog), NULL)));
}


#line 485 "project.vala"
gboolean valide_project_is_compiled (ValideProject* self) {
	char* _tmp0;
	gboolean _tmp1;
#line 485 "project.vala"
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), FALSE);
#line 487 "project.vala"
	_tmp0 = NULL;
#line 487 "project.vala"
	return (_tmp1 = g_file_test ((_tmp0 = g_build_filename (valide_project_get_path (self), valide_project_get_name (self), NULL, NULL)), G_FILE_TEST_EXISTS), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
}


#line 491 "project.vala"
void valide_project_options (ValideProject* self) {
	ValideProjectDialogOptions* dialog;
#line 491 "project.vala"
	g_return_if_fail (VALIDE_IS_PROJECT (self));
	dialog = g_object_ref_sink (valide_project_dialog_options_new (self));
#line 495 "project.vala"
	gtk_widget_show_all (GTK_WIDGET (dialog));
#line 496 "project.vala"
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
#line 498 "project.vala"
		valide_project_set_pkg (self, valide_project_dialog_options_get_pkg (dialog));
#line 499 "project.vala"
		valide_project_set_vapi_dir (self, valide_project_dialog_options_get_vapi_dir (dialog));
#line 500 "project.vala"
		valide_project_set_debug (self, valide_project_dialog_options_get_debug (dialog));
#line 501 "project.vala"
		valide_project_set_thread (self, valide_project_dialog_options_get_thread (dialog));
#line 502 "project.vala"
		valide_project_set_disable_assert (self, valide_project_dialog_options_get_disable_assert (dialog));
#line 503 "project.vala"
		valide_project_set_disable_checking (self, valide_project_dialog_options_get_disable_checking (dialog));
#line 504 "project.vala"
		valide_project_set_save_temps (self, valide_project_dialog_options_get_save_temps (dialog));
#line 505 "project.vala"
		valide_project_set_quiet (self, valide_project_dialog_options_get_quiet (dialog));
#line 506 "project.vala"
		valide_project_set_verbose (self, valide_project_dialog_options_get_verbose (dialog));
	}
#line 508 "project.vala"
	gtk_object_destroy (GTK_OBJECT (dialog));
	(dialog == NULL ? NULL : (dialog = (g_object_unref (dialog), NULL)));
}


#line 511 "project.vala"
void valide_project_compile (ValideProject* self) {
	GError * inner_error;
#line 511 "project.vala"
	g_return_if_fail (VALIDE_IS_PROJECT (self));
	inner_error = NULL;
#line 513 "project.vala"
	if (self->priv->compiler == NULL) {
		ValideCompiler* _tmp0;
		_tmp0 = NULL;
#line 515 "project.vala"
		self->priv->compiler = (_tmp0 = valide_compiler_new (), (self->priv->compiler == NULL ? NULL : (self->priv->compiler = (g_object_unref (self->priv->compiler), NULL))), _tmp0);
	}
#line 517 "project.vala"
	valide_abstract_executable_run (VALIDE_ABSTRACT_EXECUTABLE (self->priv->compiler), valide_project_get_compiler_options (self), valide_project_get_path (self), &inner_error);
	if (inner_error != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
		g_clear_error (&inner_error);
	}
}


#line 520 "project.vala"
void valide_project_execute (ValideProject* self) {
	GError * inner_error;
#line 520 "project.vala"
	g_return_if_fail (VALIDE_IS_PROJECT (self));
	inner_error = NULL;
#line 522 "project.vala"
	if (!valide_project_is_compiled (self)) {
#line 524 "project.vala"
		valide_project_compile (self);
	}
#line 526 "project.vala"
	if (valide_project_is_compiled (self)) {
		char* _tmp1;
#line 528 "project.vala"
		if (self->priv->executable == NULL) {
			ValideExecutable* _tmp0;
			_tmp0 = NULL;
#line 530 "project.vala"
			self->priv->executable = (_tmp0 = valide_executable_new (), (self->priv->executable == NULL ? NULL : (self->priv->executable = (g_object_unref (self->priv->executable), NULL))), _tmp0);
		}
#line 532 "project.vala"
		_tmp1 = NULL;
#line 532 "project.vala"
		valide_executable_set_executable (self->priv->executable, (_tmp1 = g_build_filename (valide_project_get_path (self), valide_project_get_name (self), NULL)));
		_tmp1 = (g_free (_tmp1), NULL);
#line 533 "project.vala"
		valide_abstract_executable_run (VALIDE_ABSTRACT_EXECUTABLE (self->priv->executable), valide_project_get_executable_options (self), self->priv->working_dir, &inner_error);
		if (inner_error != NULL) {
			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
			g_clear_error (&inner_error);
		}
	}
}


const char* valide_project_get_filename (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), NULL);
#line 58 "project.vala"
	return self->priv->filename_;
}


void valide_project_set_filename (ValideProject* self, const char* value) {
	GError * inner_error;
	g_return_if_fail (VALIDE_IS_PROJECT (self));
	inner_error = NULL;
	{
		char* _tmp2;
		const char* _tmp1;
		char* _tmp3;
		char* _tmp5;
		const char* _tmp4;
		_tmp2 = NULL;
#line 64 "project.vala"
		_tmp1 = NULL;
#line 64 "project.vala"
		self->priv->filename_ = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->filename_ = (g_free (self->priv->filename_), NULL)), _tmp2);
		_tmp3 = NULL;
#line 66 "project.vala"
		self->priv->path_ = (_tmp3 = g_path_get_dirname (valide_project_get_filename (self)), (self->priv->path_ = (g_free (self->priv->path_), NULL)), _tmp3);
		_tmp5 = NULL;
#line 67 "project.vala"
		_tmp4 = NULL;
#line 67 "project.vala"
		self->priv->working_dir = (_tmp5 = (_tmp4 = valide_project_get_path (self), (_tmp4 == NULL ? NULL : g_strdup (_tmp4))), (self->priv->working_dir = (g_free (self->priv->working_dir), NULL)), _tmp5);
	}
	goto __finally4;
	__catch4_g_error:
	{
		GError * e;
		e = inner_error;
		inner_error = NULL;
		{
#line 71 "project.vala"
			g_warning (e->message);
		}
	}
	__finally4:
	;
}


const char* valide_project_get_path (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), NULL);
#line 80 "project.vala"
	return self->priv->path_;
}


static void _g_list_free_g_free (GList* self) {
	g_list_foreach (self, ((GFunc) g_free), NULL);
	g_list_free (self);
}


GList* valide_project_get_files (ValideProject* self) {
	GList* files_;
	xmlNodeSet* nodes;
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), NULL);
	files_ = NULL;
	nodes = valide_markup_get_nodes (valide_project_get_filename (self), "/project/files/file/text ()");
	{
		gint i;
		i = 0;
#line 92 "project.vala"
		for (; i < xmlXPathNodeSetGetLength (nodes); i++) {
			const char* _tmp0;
#line 94 "project.vala"
			_tmp0 = NULL;
#line 94 "project.vala"
			files_ = g_list_append (files_, (_tmp0 = xmlXPathNodeSetItem (nodes, i)->content, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))));
		}
	}
#line 96 "project.vala"
	return files_;
}


GList* valide_project_get_pkg (ValideProject* self) {
	GList* pkg_;
	xmlNodeSet* nodes;
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), NULL);
	pkg_ = NULL;
	nodes = valide_markup_get_nodes (valide_project_get_filename (self), "/project/compiler/pkg/text ()");
	{
		gint i;
		i = 0;
#line 108 "project.vala"
		for (; i < xmlXPathNodeSetGetLength (nodes); i++) {
			const char* _tmp0;
#line 110 "project.vala"
			_tmp0 = NULL;
#line 110 "project.vala"
			pkg_ = g_list_append (pkg_, (_tmp0 = xmlXPathNodeSetItem (nodes, i)->content, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))));
		}
	}
#line 112 "project.vala"
	return pkg_;
}


void valide_project_set_pkg (ValideProject* self, GList* value) {
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 116 "project.vala"
	valide_markup_remove (valide_project_get_filename (self), "/project/compiler/pkg");
	{
		GList* p_collection;
		GList* p_it;
#line 118 "project.vala"
		p_collection = value;
		for (p_it = p_collection; p_it != NULL; p_it = p_it->next) {
			const char* _tmp2;
			char* p;
			_tmp2 = NULL;
#line 118 "project.vala"
			p = (_tmp2 = ((char*) p_it->data), (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
			{
#line 120 "project.vala"
				valide_markup_add_child (valide_project_get_filename (self), "/project/compiler", "pkg", p);
				p = (g_free (p), NULL);
			}
		}
	}
}


GList* valide_project_get_vapi_dir (ValideProject* self) {
	GList* vapi_;
	xmlNodeSet* nodes;
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), NULL);
	vapi_ = NULL;
	nodes = valide_markup_get_nodes (valide_project_get_filename (self), "/project/compiler/vapi/text ()");
	{
		gint i;
		i = 0;
#line 133 "project.vala"
		for (; i < xmlXPathNodeSetGetLength (nodes); i++) {
			const char* _tmp0;
#line 135 "project.vala"
			_tmp0 = NULL;
#line 135 "project.vala"
			vapi_ = g_list_append (vapi_, (_tmp0 = xmlXPathNodeSetItem (nodes, i)->content, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))));
		}
	}
#line 137 "project.vala"
	return vapi_;
}


void valide_project_set_vapi_dir (ValideProject* self, GList* value) {
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 141 "project.vala"
	valide_markup_remove (valide_project_get_filename (self), "/project/compiler/vapi");
	{
		GList* p_collection;
		GList* p_it;
#line 143 "project.vala"
		p_collection = value;
		for (p_it = p_collection; p_it != NULL; p_it = p_it->next) {
			const char* _tmp2;
			char* p;
			_tmp2 = NULL;
#line 143 "project.vala"
			p = (_tmp2 = ((char*) p_it->data), (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
			{
#line 145 "project.vala"
				valide_markup_add_child (valide_project_get_filename (self), "/project/compiler", "vapi", p);
				p = (g_free (p), NULL);
			}
		}
	}
}


gboolean valide_project_get_debug (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), FALSE);
#line 154 "project.vala"
	return valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/debug");
}


void valide_project_set_debug (ValideProject* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 158 "project.vala"
	if (value) {
#line 160 "project.vala"
		if (!valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/debug")) {
#line 162 "project.vala"
			valide_markup_add_child (valide_project_get_filename (self), "/project/compiler/options", "debug", NULL);
		}
	} else {
#line 167 "project.vala"
		valide_markup_remove (valide_project_get_filename (self), "/project/compiler/options/debug");
	}
}


gboolean valide_project_get_thread (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), FALSE);
#line 176 "project.vala"
	return valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/thread");
}


void valide_project_set_thread (ValideProject* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 180 "project.vala"
	if (value) {
#line 182 "project.vala"
		if (!valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/thread")) {
#line 184 "project.vala"
			valide_markup_add_child (valide_project_get_filename (self), "/project/compiler/options", "thread", NULL);
		}
	} else {
#line 189 "project.vala"
		valide_markup_remove (valide_project_get_filename (self), "/project/compiler/options/thread");
	}
}


gboolean valide_project_get_disable_assert (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), FALSE);
#line 198 "project.vala"
	return valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/disable_assert");
}


void valide_project_set_disable_assert (ValideProject* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 202 "project.vala"
	if (value) {
#line 204 "project.vala"
		if (!valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/disable_assert")) {
#line 206 "project.vala"
			valide_markup_add_child (valide_project_get_filename (self), "/project/compiler/options", "disable_assert", NULL);
		}
	} else {
#line 211 "project.vala"
		valide_markup_remove (valide_project_get_filename (self), "/project/compiler/options/disable_assert");
	}
}


gboolean valide_project_get_disable_checking (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), FALSE);
#line 220 "project.vala"
	return valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/disable_checking");
}


void valide_project_set_disable_checking (ValideProject* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 224 "project.vala"
	if (value) {
#line 226 "project.vala"
		if (!valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/disable_checking")) {
#line 228 "project.vala"
			valide_markup_add_child (valide_project_get_filename (self), "/project/compiler/options", "disable_checking", NULL);
		}
	} else {
#line 233 "project.vala"
		valide_markup_remove (valide_project_get_filename (self), "/project/compiler/options/disable_checking");
	}
}


gboolean valide_project_get_disable_non_null (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), FALSE);
#line 242 "project.vala"
	return valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/disable_non_null");
}


void valide_project_set_disable_non_null (ValideProject* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 246 "project.vala"
	if (value) {
#line 248 "project.vala"
		if (!valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/disable_non_null")) {
#line 250 "project.vala"
			valide_markup_add_child (valide_project_get_filename (self), "/project/compiler/options", "disable_non_null", NULL);
		}
	} else {
#line 255 "project.vala"
		valide_markup_remove (valide_project_get_filename (self), "/project/compiler/options/disable_non_null");
	}
}


gboolean valide_project_get_save_temps (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), FALSE);
#line 264 "project.vala"
	return valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/save_temps");
}


void valide_project_set_save_temps (ValideProject* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 268 "project.vala"
	if (value) {
#line 270 "project.vala"
		if (!valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/save_temps")) {
#line 272 "project.vala"
			valide_markup_add_child (valide_project_get_filename (self), "/project/compiler/options", "save_temps", NULL);
		}
	} else {
#line 277 "project.vala"
		valide_markup_remove (valide_project_get_filename (self), "/project/compiler/options/save_temps");
	}
}


gboolean valide_project_get_quiet (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), FALSE);
#line 286 "project.vala"
	return valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/quiet");
}


void valide_project_set_quiet (ValideProject* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 290 "project.vala"
	if (value) {
#line 292 "project.vala"
		if (!valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/quiet")) {
#line 294 "project.vala"
			valide_markup_add_child (valide_project_get_filename (self), "/project/compiler/options", "quiet", NULL);
		}
	} else {
#line 299 "project.vala"
		valide_markup_remove (valide_project_get_filename (self), "/project/compiler/options/quiet");
	}
}


gboolean valide_project_get_verbose (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), FALSE);
#line 308 "project.vala"
	return valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/verbose");
}


void valide_project_set_verbose (ValideProject* self, gboolean value) {
	g_return_if_fail (VALIDE_IS_PROJECT (self));
#line 312 "project.vala"
	if (value) {
#line 314 "project.vala"
		if (!valide_markup_exist (valide_project_get_filename (self), "/project/compiler/options/verbose")) {
#line 316 "project.vala"
			valide_markup_add_child (valide_project_get_filename (self), "/project/compiler/options", "verbose", NULL);
		}
	} else {
#line 321 "project.vala"
		valide_markup_remove (valide_project_get_filename (self), "/project/compiler/options/verbose");
	}
}


char* valide_project_get_name (ValideProject* self) {
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), NULL);
#line 330 "project.vala"
	return valide_markup_get_content (valide_project_get_filename (self), "/project/name/text ()");
}


char* valide_project_get_compiler_options (ValideProject* self) {
	char* opt;
	char* _tmp1;
	char* _tmp0;
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), NULL);
	opt = g_strdup ("");
	_tmp1 = NULL;
	_tmp0 = NULL;
#line 340 "project.vala"
	opt = (_tmp1 = g_strconcat (opt, (_tmp0 = (g_strconcat ("-o ", valide_project_get_name (self), NULL))), NULL), (opt = (g_free (opt), NULL)), _tmp1);
	_tmp0 = (g_free (_tmp0), NULL);
	{
		GList* p_collection;
		GList* p_it;
#line 342 "project.vala"
		p_collection = valide_project_get_pkg (self);
		for (p_it = p_collection; p_it != NULL; p_it = p_it->next) {
			const char* _tmp4;
			char* p;
			_tmp4 = NULL;
#line 342 "project.vala"
			p = (_tmp4 = ((char*) p_it->data), (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
			{
				char* _tmp3;
				char* _tmp2;
				_tmp3 = NULL;
				_tmp2 = NULL;
#line 344 "project.vala"
				opt = (_tmp3 = g_strconcat (opt, (_tmp2 = (g_strconcat (" --pkg=", p, NULL))), NULL), (opt = (g_free (opt), NULL)), _tmp3);
				_tmp2 = (g_free (_tmp2), NULL);
				p = (g_free (p), NULL);
			}
		}
	}
	{
		GList* p_collection;
		GList* p_it;
#line 347 "project.vala"
		p_collection = valide_project_get_vapi_dir (self);
		for (p_it = p_collection; p_it != NULL; p_it = p_it->next) {
			const char* _tmp8;
			char* p;
			_tmp8 = NULL;
#line 347 "project.vala"
			p = (_tmp8 = ((char*) p_it->data), (_tmp8 == NULL ? NULL : g_strdup (_tmp8)));
			{
				char* _tmp7;
				char* _tmp6;
				char* _tmp5;
				_tmp7 = NULL;
				_tmp6 = NULL;
				_tmp5 = NULL;
#line 349 "project.vala"
				opt = (_tmp7 = g_strconcat (opt, (_tmp6 = (g_strconcat ((_tmp5 = g_strconcat (" --vapidir=\"", p, NULL)), "\"", NULL))), NULL), (opt = (g_free (opt), NULL)), _tmp7);
				_tmp6 = (g_free (_tmp6), NULL);
				_tmp5 = (g_free (_tmp5), NULL);
				p = (g_free (p), NULL);
			}
		}
	}
#line 352 "project.vala"
	if (valide_project_get_debug (self)) {
		char* _tmp9;
		_tmp9 = NULL;
#line 354 "project.vala"
		opt = (_tmp9 = g_strconcat (opt, (" -g"), NULL), (opt = (g_free (opt), NULL)), _tmp9);
	}
#line 357 "project.vala"
	if (valide_project_get_thread (self)) {
		char* _tmp10;
		_tmp10 = NULL;
#line 359 "project.vala"
		opt = (_tmp10 = g_strconcat (opt, (" --thread"), NULL), (opt = (g_free (opt), NULL)), _tmp10);
	}
#line 362 "project.vala"
	if (valide_project_get_disable_assert (self)) {
		char* _tmp11;
		_tmp11 = NULL;
#line 364 "project.vala"
		opt = (_tmp11 = g_strconcat (opt, (" --disable-assert"), NULL), (opt = (g_free (opt), NULL)), _tmp11);
	}
#line 367 "project.vala"
	if (valide_project_get_disable_checking (self)) {
		char* _tmp12;
		_tmp12 = NULL;
#line 369 "project.vala"
		opt = (_tmp12 = g_strconcat (opt, (" --disable-checking"), NULL), (opt = (g_free (opt), NULL)), _tmp12);
	}
#line 372 "project.vala"
	if (valide_project_get_disable_non_null (self)) {
		char* _tmp13;
		_tmp13 = NULL;
#line 374 "project.vala"
		opt = (_tmp13 = g_strconcat (opt, (" --disable-non-null"), NULL), (opt = (g_free (opt), NULL)), _tmp13);
	}
#line 377 "project.vala"
	if (valide_project_get_save_temps (self)) {
		char* _tmp14;
		_tmp14 = NULL;
#line 379 "project.vala"
		opt = (_tmp14 = g_strconcat (opt, (" --save-temps"), NULL), (opt = (g_free (opt), NULL)), _tmp14);
	}
#line 382 "project.vala"
	if (valide_project_get_quiet (self)) {
		char* _tmp15;
		_tmp15 = NULL;
#line 384 "project.vala"
		opt = (_tmp15 = g_strconcat (opt, (" -q"), NULL), (opt = (g_free (opt), NULL)), _tmp15);
	}
#line 387 "project.vala"
	if (valide_project_get_verbose (self)) {
		char* _tmp16;
		_tmp16 = NULL;
#line 389 "project.vala"
		opt = (_tmp16 = g_strconcat (opt, (" -v"), NULL), (opt = (g_free (opt), NULL)), _tmp16);
	}
	{
		GList* file_collection;
		GList* file_it;
#line 392 "project.vala"
		file_collection = valide_project_get_files (self);
		for (file_it = file_collection; file_it != NULL; file_it = file_it->next) {
			const char* _tmp19;
			char* file;
			_tmp19 = NULL;
#line 392 "project.vala"
			file = (_tmp19 = ((char*) file_it->data), (_tmp19 == NULL ? NULL : g_strdup (_tmp19)));
			{
				char* _tmp18;
				char* _tmp17;
				_tmp18 = NULL;
				_tmp17 = NULL;
#line 394 "project.vala"
				opt = (_tmp18 = g_strconcat (opt, (_tmp17 = (g_strconcat (" ", file, NULL))), NULL), (opt = (g_free (opt), NULL)), _tmp18);
				_tmp17 = (g_free (_tmp17), NULL);
				file = (g_free (file), NULL);
			}
		}
	}
#line 397 "project.vala"
	return opt;
}


char* valide_project_get_executable_options (ValideProject* self) {
	char* opt;
	g_return_val_if_fail (VALIDE_IS_PROJECT (self), NULL);
	opt = g_strdup ("");
#line 407 "project.vala"
	return opt;
}


static void valide_project_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValideProject * self;
	self = VALIDE_PROJECT (object);
	switch (property_id) {
		case VALIDE_PROJECT_FILENAME:
		g_value_set_string (value, valide_project_get_filename (self));
		break;
		case VALIDE_PROJECT_PATH:
		g_value_set_string (value, valide_project_get_path (self));
		break;
		case VALIDE_PROJECT_FILES:
		g_value_set_pointer (value, valide_project_get_files (self));
		break;
		case VALIDE_PROJECT_PKG:
		g_value_set_pointer (value, valide_project_get_pkg (self));
		break;
		case VALIDE_PROJECT_VAPI_DIR:
		g_value_set_pointer (value, valide_project_get_vapi_dir (self));
		break;
		case VALIDE_PROJECT_DEBUG:
		g_value_set_boolean (value, valide_project_get_debug (self));
		break;
		case VALIDE_PROJECT_THREAD:
		g_value_set_boolean (value, valide_project_get_thread (self));
		break;
		case VALIDE_PROJECT_DISABLE_ASSERT:
		g_value_set_boolean (value, valide_project_get_disable_assert (self));
		break;
		case VALIDE_PROJECT_DISABLE_CHECKING:
		g_value_set_boolean (value, valide_project_get_disable_checking (self));
		break;
		case VALIDE_PROJECT_DISABLE_NON_NULL:
		g_value_set_boolean (value, valide_project_get_disable_non_null (self));
		break;
		case VALIDE_PROJECT_SAVE_TEMPS:
		g_value_set_boolean (value, valide_project_get_save_temps (self));
		break;
		case VALIDE_PROJECT_QUIET:
		g_value_set_boolean (value, valide_project_get_quiet (self));
		break;
		case VALIDE_PROJECT_VERBOSE:
		g_value_set_boolean (value, valide_project_get_verbose (self));
		break;
		case VALIDE_PROJECT_NAME:
		g_value_set_string (value, valide_project_get_name (self));
		break;
		case VALIDE_PROJECT_COMPILER_OPTIONS:
		g_value_set_string (value, valide_project_get_compiler_options (self));
		break;
		case VALIDE_PROJECT_EXECUTABLE_OPTIONS:
		g_value_set_string (value, valide_project_get_executable_options (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_project_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValideProject * self;
	self = VALIDE_PROJECT (object);
	switch (property_id) {
		case VALIDE_PROJECT_FILENAME:
		valide_project_set_filename (self, g_value_get_string (value));
		break;
		case VALIDE_PROJECT_PKG:
		valide_project_set_pkg (self, g_value_get_pointer (value));
		break;
		case VALIDE_PROJECT_VAPI_DIR:
		valide_project_set_vapi_dir (self, g_value_get_pointer (value));
		break;
		case VALIDE_PROJECT_DEBUG:
		valide_project_set_debug (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_THREAD:
		valide_project_set_thread (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DISABLE_ASSERT:
		valide_project_set_disable_assert (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DISABLE_CHECKING:
		valide_project_set_disable_checking (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_DISABLE_NON_NULL:
		valide_project_set_disable_non_null (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_SAVE_TEMPS:
		valide_project_set_save_temps (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_QUIET:
		valide_project_set_quiet (self, g_value_get_boolean (value));
		break;
		case VALIDE_PROJECT_VERBOSE:
		valide_project_set_verbose (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_project_class_init (ValideProjectClass * klass) {
	valide_project_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideProjectPrivate));
	G_OBJECT_CLASS (klass)->get_property = valide_project_get_property;
	G_OBJECT_CLASS (klass)->set_property = valide_project_set_property;
	G_OBJECT_CLASS (klass)->dispose = valide_project_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_FILENAME, g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_PATH, g_param_spec_string ("path", "path", "path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_FILES, g_param_spec_pointer ("files", "files", "files", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_PKG, g_param_spec_pointer ("pkg", "pkg", "pkg", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_VAPI_DIR, g_param_spec_pointer ("vapi-dir", "vapi-dir", "vapi-dir", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DEBUG, g_param_spec_boolean ("debug", "debug", "debug", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_THREAD, g_param_spec_boolean ("thread", "thread", "thread", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DISABLE_ASSERT, g_param_spec_boolean ("disable-assert", "disable-assert", "disable-assert", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DISABLE_CHECKING, g_param_spec_boolean ("disable-checking", "disable-checking", "disable-checking", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_DISABLE_NON_NULL, g_param_spec_boolean ("disable-non-null", "disable-non-null", "disable-non-null", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_SAVE_TEMPS, g_param_spec_boolean ("save-temps", "save-temps", "save-temps", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_QUIET, g_param_spec_boolean ("quiet", "quiet", "quiet", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_VERBOSE, g_param_spec_boolean ("verbose", "verbose", "verbose", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_COMPILER_OPTIONS, g_param_spec_string ("compiler-options", "compiler-options", "compiler-options", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PROJECT_EXECUTABLE_OPTIONS, g_param_spec_string ("executable-options", "executable-options", "executable-options", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_signal_new ("closed", VALIDE_TYPE_PROJECT, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	g_signal_new ("removed_file", VALIDE_TYPE_PROJECT, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	g_signal_new ("added_file", VALIDE_TYPE_PROJECT, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}


static void valide_project_init (ValideProject * self) {
	self->priv = VALIDE_PROJECT_GET_PRIVATE (self);
}


static void valide_project_dispose (GObject * obj) {
	ValideProject * self;
	self = VALIDE_PROJECT (obj);
	self->priv->path_ = (g_free (self->priv->path_), NULL);
	self->priv->filename_ = (g_free (self->priv->filename_), NULL);
	self->priv->working_dir = (g_free (self->priv->working_dir), NULL);
	(self->priv->compiler == NULL ? NULL : (self->priv->compiler = (g_object_unref (self->priv->compiler), NULL)));
	(self->priv->executable == NULL ? NULL : (self->priv->executable = (g_object_unref (self->priv->executable), NULL)));
	G_OBJECT_CLASS (valide_project_parent_class)->dispose (obj);
}


GType valide_project_get_type (void) {
	static GType valide_project_type_id = 0;
	if (G_UNLIKELY (valide_project_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideProjectClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_project_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideProject), 0, (GInstanceInitFunc) valide_project_init };
		valide_project_type_id = g_type_register_static (G_TYPE_OBJECT, "ValideProject", &g_define_type_info, 0);
	}
	return valide_project_type_id;
}


static int _vala_strcmp0 (const char * str1, const char * str2) {
	if (str1 == NULL) {
		return -(str1 != str2);
	}
	if (str2 == NULL) {
		return (str1 != str2);
	}
	return strcmp (str1, str2);
}




