/* project.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

using GLib;

public class Valide.Project : GLib.Object
{
  public const string FILE_EXT = ".vide";

  private string path_;
  private string filename_;
  private string working_dir;
  private Compiler compiler;
  private Executable executable;

  public signal void closed ();
  public signal void removed_file ();
  public signal void added_file ();

  private bool exist (string filename)
  {
    bool ret = false;

    foreach (string file in this.files)
    {
      if (file == filename)
      {
        ret = true;
        break;
      }
    }
    return ret;
  }

  public string filename
  {
    get
    {
      return this.filename_;
    }
    set
    {
      try
      {
        this.filename_ = value;

        this.path_ = GLib.Path.get_dirname (this.filename);
        this.working_dir = this.path;
      }
      catch (GLib.Error e)
      {
        GLib.warning (e.message);
      }
    }
  }

  public string path
  {
    get
    {
      return this.path_;
    }
  }

  public GLib.List<string># files
  {
    get
    {
      GLib.List<string> files_ = null;

      Xml.NodeSet* nodes = Markup.get_nodes (this.filename,
                                             "/project/files/file/text ()");
      for (int i = 0; i < nodes->length (); i++)
      {
        files_.append (nodes->item (i)->content);
      }
      return files_;
    }
  }

  public GLib.List<string># pkg
  {
    get
    {
      GLib.List<string> pkg_ = null;

      Xml.NodeSet* nodes = Markup.get_nodes (this.filename,
                                             "/project/compiler/pkg/text ()");
      for (int i = 0; i < nodes->length (); i++)
      {
        pkg_.append (nodes->item (i)->content);
      }
      return pkg_;
    }
    set
    {
      Markup.remove (this.filename, "/project/compiler/pkg");

      foreach (string p in value)
      {
        Markup.add_child (this.filename, "/project/compiler", "pkg", p);
      }
    }
  }

  public GLib.List<string># vapi_dir
  {
    get
    {
      GLib.List<string> vapi_ = null;

      Xml.NodeSet* nodes = Markup.get_nodes (this.filename,
                                             "/project/compiler/vapi/text ()");
      for (int i = 0; i < nodes->length (); i++)
      {
        vapi_.append (nodes->item (i)->content);
      }
      return vapi_;
    }
    set
    {
      Markup.remove (this.filename, "/project/compiler/vapi");

      foreach (string p in value)
      {
        Markup.add_child (this.filename, "/project/compiler", "vapi", p);
      }
    }
  }

  public bool debug
  {
    get
    {
      return Markup.exist (this.filename, "/project/compiler/options/debug");
    }
    set
    {
      if (value)
      {
        if (!Markup.exist (this.filename, "/project/compiler/options/debug"))
        {
          Markup.add_child (this.filename, "/project/compiler/options", "debug");
        }
      }
      else
      {
        Markup.remove (this.filename, "/project/compiler/options/debug");
      }
    }
  }

  public bool thread
  {
    get
    {
      return Markup.exist (this.filename, "/project/compiler/options/thread");
    }
    set
    {
      if (value)
      {
        if (!Markup.exist (this.filename, "/project/compiler/options/thread"))
        {
          Markup.add_child (this.filename, "/project/compiler/options", "thread");
        }
      }
      else
      {
        Markup.remove (this.filename, "/project/compiler/options/thread");
      }
    }
  }

  public bool disable_assert
  {
    get
    {
      return Markup.exist (this.filename, "/project/compiler/options/disable_assert");
    }
    set
    {
      if (value)
      {
        if (!Markup.exist (this.filename, "/project/compiler/options/disable_assert"))
        {
          Markup.add_child (this.filename, "/project/compiler/options", "disable_assert");
        }
      }
      else
      {
        Markup.remove (this.filename, "/project/compiler/options/disable_assert");
      }
    }
  }

  public bool disable_checking
  {
    get
    {
      return Markup.exist (this.filename, "/project/compiler/options/disable_checking");
    }
    set
    {
      if (value)
      {
        if (!Markup.exist (this.filename, "/project/compiler/options/disable_checking"))
        {
          Markup.add_child (this.filename, "/project/compiler/options", "disable_checking");
        }
      }
      else
      {
        Markup.remove (this.filename, "/project/compiler/options/disable_checking");
      }
    }
  }

  public bool disable_non_null
  {
    get
    {
      return Markup.exist (this.filename, "/project/compiler/options/disable_non_null");
    }
    set
    {
      if (value)
      {
        if (!Markup.exist (this.filename, "/project/compiler/options/disable_non_null"))
        {
          Markup.add_child (this.filename, "/project/compiler/options", "disable_non_null");
        }
      }
      else
      {
        Markup.remove (this.filename, "/project/compiler/options/disable_non_null");
      }
    }
  }

  public bool save_temps
  {
    get
    {
      return Markup.exist (this.filename, "/project/compiler/options/save_temps");
    }
    set
    {
      if (value)
      {
        if (!Markup.exist (this.filename, "/project/compiler/options/save_temps"))
        {
          Markup.add_child (this.filename, "/project/compiler/options", "save_temps");
        }
      }
      else
      {
        Markup.remove (this.filename, "/project/compiler/options/save_temps");
      }
    }
  }

  public bool quiet
  {
    get
    {
      return Markup.exist (this.filename, "/project/compiler/options/quiet");
    }
    set
    {
      if (value)
      {
        if (!Markup.exist (this.filename, "/project/compiler/options/quiet"))
        {
          Markup.add_child (this.filename, "/project/compiler/options", "quiet");
        }
      }
      else
      {
        Markup.remove (this.filename, "/project/compiler/options/quiet");
      }
    }
  }

  public bool verbose
  {
    get
    {
      return Markup.exist (this.filename, "/project/compiler/options/verbose");
    }
    set
    {
      if (value)
      {
        if (!Markup.exist (this.filename, "/project/compiler/options/verbose"))
        {
          Markup.add_child (this.filename, "/project/compiler/options", "verbose");
        }
      }
      else
      {
        Markup.remove (this.filename, "/project/compiler/options/verbose");
      }
    }
  }

  public string# name
  {
    get
    {
      return Markup.get_content (this.filename, "/project/name/text ()");
    }
  }

  public string# compiler_options
  {
    get
    {
      string opt = "";

      opt += "-o " + this.name;

      foreach (string p in this.pkg)
      {
        opt += " --pkg=" + p;
      }

      foreach (string p in this.vapi_dir)
      {
        opt += " --vapidir=\"" + p + "\"";
      }

      if (this.debug)
      {
        opt += " -g";
      }

      if (this.thread)
      {
        opt += " --thread";
      }

      if (this.disable_assert)
      {
        opt += " --disable-assert";
      }

      if (this.disable_checking)
      {
        opt += " --disable-checking";
      }

      if (this.disable_non_null)
      {
        opt += " --disable-non-null";
      }

      if (this.save_temps)
      {
        opt += " --save-temps";
      }

      if (this.quiet)
      {
        opt += " -q";
      }

      if (this.verbose)
      {
        opt += " -v";
      }

      foreach (string file in this.files)
      {
        opt += " " + file;
      }

      return opt;
    }
  }

  public string# executable_options
  {
    get
    {
      string opt =  "";

      return opt;
    }
  }

  public Project (string filename)
  {
    this.filename = filename;
  }

  public void close ()
  {
    if (DocumentManager.get_instance ().close_all ())
    {
      this.closed ();
    }
  }

  public void open_file (string filename)
  {
    DocumentManager.get_instance ()
      .create (GLib.Path.build_filename (this.path, filename, null));
  }

  public void add_file ()
  {
    Gtk.FileChooserDialog dialog = new Gtk.FileChooserDialog (_("Add file"), null,
                                                          Gtk.FileChooserAction.OPEN,
                                                          Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
                                                          Gtk.STOCK_ADD, Gtk.ResponseType.ACCEPT);

    dialog.set_current_folder (this.path);

    /* Add filter */
    dialog.filter = new Gtk.FileFilter ();
    dialog.filter.set_name (_("Vala source file"));
    dialog.filter.add_pattern ("*" + Document.FILE_EXT);

    dialog.select_multiple = true;

    if (dialog.run () == Gtk.ResponseType.ACCEPT)
    {
      weak GLib.SList<string> files = dialog.get_uris ();
      
      foreach (string file in files)
      {
        string filename = Path.get_relative_path (file, "file://" + this.path);

        if (!this.exist (filename))
        {
          Markup.add_child (this.filename, "/project/files", "file", filename);
          this.added_file ();
        }
        else
        {
          GLib.message (_("File already '%s' added!"), filename);
        }
      }
    }
    dialog.destroy ();
  }

  public void remove_file ()
  {
    ProjectDialogRemove dialog = new ProjectDialogRemove (this);
    dialog.show_all ();
    if (dialog.run () == Gtk.ResponseType.ACCEPT)
    {
      foreach (string file in dialog.selected_files)
      {
        string filename = Path.get_relative_path (file, "file://" + this.path);

        Markup.remove (this.filename, "/project/files/file[.='" + filename + "']");
      }
      this.removed_file ();
    }
    dialog.destroy ();
  }

  public bool is_compiled ()
  {
    return GLib.FileUtils.test (GLib.Path.build_filename (this.path, this.name, null),
                                GLib.FileTest.EXISTS);
  }

  public void options ()
  {
    ProjectDialogOptions dialog = new ProjectDialogOptions (this);

    dialog.show_all ();
    if (dialog.run () == Gtk.ResponseType.ACCEPT)
    {
      this.pkg = dialog.pkg;
      this.vapi_dir = dialog.vapi_dir;
      this.debug = dialog.debug;
      this.thread = dialog.thread;
      this.disable_assert = dialog.disable_assert;
      this.disable_checking = dialog.disable_checking;
      this.save_temps = dialog.save_temps;
      this.quiet = dialog.quiet;
      this.verbose = dialog.verbose;
    }
    dialog.destroy ();
  }

  public void compile ()
  {
    if (this.compiler == null)
    {
      this.compiler = new Compiler ();
    }
    this.compiler.run (this.compiler_options, this.path);
  }

  public void execute ()
  {
    if (!this.is_compiled ())
    {
      this.compile ();
    }
    if (this.is_compiled ())
    {
      if (this.executable == null)
      {
        this.executable = new Executable ();
      }
      this.executable.executable = GLib.Path.build_filename (this.path, this.name);
      this.executable.run (this.executable_options, this.working_dir);
    }
  }
}

