/* recent-manager-ui.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/recent-manager-ui.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include "src/project.h"
#include "src/project-manager.h"
#include "src/document-manager.h"
#include "src/document.h"
#include <string.h>




struct _ValideRecentManagerUIPrivate {
	gint max_recents;
	guint id_file;
	guint id_project;
	GtkActionGroup* recents_action_group;
};

#define VALIDE_RECENT_MANAGER_UI_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_RECENT_MANAGER_UI, ValideRecentManagerUIPrivate))
enum  {
	VALIDE_RECENT_MANAGER_UI_DUMMY_PROPERTY
};
static ValideRecentManagerUI* valide_recent_manager_ui_instance = NULL;
static void valide_recent_manager_ui_recents_menu_activate (ValideRecentManagerUI* self, GtkAction* sender);
static ValideRecentManagerUI* valide_recent_manager_ui_new (void);
static void valide_recent_manager_ui_add (ValideRecentManagerUI* self, const char* uri, const char* mime_type);
static void _valide_recent_manager_ui_recents_menu_activate_gtk_action_activate (GtkAction* sender, gpointer self);
static void _g_list_free_gtk_recent_info_unref (GList* self);
static void valide_recent_manager_ui_update (ValideRecentManagerUI* self, ValideUIManager* ui_manager, const char* file_ext, const char* ui_path, guint* id);
static gpointer valide_recent_manager_ui_parent_class = NULL;
static void valide_recent_manager_ui_dispose (GObject * obj);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);



#line 33 "recent-manager-ui.vala"
static void valide_recent_manager_ui_recents_menu_activate (ValideRecentManagerUI* self, GtkAction* sender) {
	GError * inner_error;
	GtkRecentInfo* info;
	char* uri;
	GtkRecentInfo* _tmp1;
	GtkRecentInfo* _tmp0;
	char* _tmp3;
	const char* _tmp2;
#line 33 "recent-manager-ui.vala"
	g_return_if_fail (VALIDE_IS_RECENT_MANAGER_UI (self));
#line 33 "recent-manager-ui.vala"
	g_return_if_fail (GTK_IS_ACTION (sender));
	inner_error = NULL;
	info = NULL;
	uri = NULL;
	_tmp1 = NULL;
#line 38 "recent-manager-ui.vala"
	_tmp0 = NULL;
#line 38 "recent-manager-ui.vala"
	info = (_tmp1 = (_tmp0 = ((GtkRecentInfo*) g_object_get_data (G_OBJECT (sender), "gtk-recent-info")), (_tmp0 == NULL ? NULL : gtk_recent_info_ref (_tmp0))), (info == NULL ? NULL : (info = (gtk_recent_info_unref (info), NULL))), _tmp1);
	_tmp3 = NULL;
#line 39 "recent-manager-ui.vala"
	_tmp2 = NULL;
#line 39 "recent-manager-ui.vala"
	uri = (_tmp3 = (_tmp2 = gtk_recent_info_get_uri (info), (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (uri = (g_free (uri), NULL)), _tmp3);
#line 41 "recent-manager-ui.vala"
	if (g_str_has_suffix (uri, VALIDE_PROJECT_FILE_EXT)) {
		ValideProjectManager* _tmp4;
#line 43 "recent-manager-ui.vala"
		_tmp4 = NULL;
#line 43 "recent-manager-ui.vala"
		valide_project_manager_create ((_tmp4 = valide_project_manager_get_instance ()), uri, &inner_error);
		if (inner_error != NULL) {
			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
			g_clear_error (&inner_error);
		}
		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
	} else {
		ValideDocumentManager* _tmp5;
#line 47 "recent-manager-ui.vala"
		_tmp5 = NULL;
#line 47 "recent-manager-ui.vala"
		valide_document_manager_create ((_tmp5 = valide_document_manager_get_instance ()), uri);
		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
	}
	(info == NULL ? NULL : (info = (gtk_recent_info_unref (info), NULL)));
	uri = (g_free (uri), NULL);
}


#line 51 "recent-manager-ui.vala"
static ValideRecentManagerUI* valide_recent_manager_ui_new (void) {
	ValideRecentManagerUI * self;
	self = g_object_newv (VALIDE_TYPE_RECENT_MANAGER_UI, 0, NULL);
	return self;
}


#line 55 "recent-manager-ui.vala"
ValideRecentManagerUI* valide_recent_manager_ui_get_instance (void) {
	ValideRecentManagerUI* _tmp1;
#line 57 "recent-manager-ui.vala"
	if (valide_recent_manager_ui_instance == NULL) {
		ValideRecentManagerUI* _tmp0;
		_tmp0 = NULL;
#line 59 "recent-manager-ui.vala"
		valide_recent_manager_ui_instance = (_tmp0 = valide_recent_manager_ui_new (), (valide_recent_manager_ui_instance == NULL ? NULL : (valide_recent_manager_ui_instance = (g_object_unref (valide_recent_manager_ui_instance), NULL))), _tmp0);
	}
#line 61 "recent-manager-ui.vala"
	_tmp1 = NULL;
#line 61 "recent-manager-ui.vala"
	return (_tmp1 = valide_recent_manager_ui_instance, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
}


#line 64 "recent-manager-ui.vala"
void valide_recent_manager_ui_add_file (ValideRecentManagerUI* self, const char* uri) {
	ValideUIManager* _tmp0;
#line 64 "recent-manager-ui.vala"
	g_return_if_fail (VALIDE_IS_RECENT_MANAGER_UI (self));
#line 64 "recent-manager-ui.vala"
	g_return_if_fail (uri != NULL);
#line 66 "recent-manager-ui.vala"
	valide_recent_manager_ui_add (self, uri, "vala");
#line 67 "recent-manager-ui.vala"
	_tmp0 = NULL;
#line 67 "recent-manager-ui.vala"
	valide_recent_manager_ui_update_file (self, (_tmp0 = valide_ui_manager_get_instance ()));
	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
}


#line 70 "recent-manager-ui.vala"
void valide_recent_manager_ui_add_project (ValideRecentManagerUI* self, const char* uri) {
	ValideUIManager* _tmp0;
#line 70 "recent-manager-ui.vala"
	g_return_if_fail (VALIDE_IS_RECENT_MANAGER_UI (self));
#line 70 "recent-manager-ui.vala"
	g_return_if_fail (uri != NULL);
#line 72 "recent-manager-ui.vala"
	valide_recent_manager_ui_add (self, uri, "vide");
#line 73 "recent-manager-ui.vala"
	_tmp0 = NULL;
#line 73 "recent-manager-ui.vala"
	valide_recent_manager_ui_update_project (self, (_tmp0 = valide_ui_manager_get_instance ()));
	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
}


#line 76 "recent-manager-ui.vala"
void valide_recent_manager_ui_update_file (ValideRecentManagerUI* self, ValideUIManager* ui_manager) {
#line 76 "recent-manager-ui.vala"
	g_return_if_fail (VALIDE_IS_RECENT_MANAGER_UI (self));
#line 76 "recent-manager-ui.vala"
	g_return_if_fail (VALIDE_IS_UI_MANAGER (ui_manager));
#line 78 "recent-manager-ui.vala"
	valide_recent_manager_ui_update (self, ui_manager, VALIDE_DOCUMENT_FILE_EXT, "/menubar/file/file-recents-placeholder", &self->priv->id_file);
}


#line 82 "recent-manager-ui.vala"
void valide_recent_manager_ui_update_project (ValideRecentManagerUI* self, ValideUIManager* ui_manager) {
#line 82 "recent-manager-ui.vala"
	g_return_if_fail (VALIDE_IS_RECENT_MANAGER_UI (self));
#line 82 "recent-manager-ui.vala"
	g_return_if_fail (VALIDE_IS_UI_MANAGER (ui_manager));
#line 84 "recent-manager-ui.vala"
	valide_recent_manager_ui_update (self, ui_manager, VALIDE_PROJECT_FILE_EXT, "/menubar/project/project-recents-placeholder", &self->priv->id_project);
}


#line 88 "recent-manager-ui.vala"
static void valide_recent_manager_ui_add (ValideRecentManagerUI* self, const char* uri, const char* mime_type) {
	GtkRecentData _tmp0 = {0};
	GtkRecentData data;
	char* _tmp2;
	const char* _tmp1;
	char* _tmp4;
	const char* _tmp3;
	char* _tmp6;
	const char* _tmp5;
	char* _tmp7;
	char* _tmp8;
	char** _tmp9;
	char* _tmp10;
	char* _tmp11;
#line 88 "recent-manager-ui.vala"
	g_return_if_fail (VALIDE_IS_RECENT_MANAGER_UI (self));
#line 88 "recent-manager-ui.vala"
	g_return_if_fail (uri != NULL);
#line 88 "recent-manager-ui.vala"
	g_return_if_fail (mime_type != NULL);
	data = (memset (&_tmp0, 0, sizeof (GtkRecentData)), _tmp0);
	_tmp2 = NULL;
#line 91 "recent-manager-ui.vala"
	_tmp1 = NULL;
#line 91 "recent-manager-ui.vala"
	data.display_name = (_tmp2 = (_tmp1 = uri, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (data.display_name = (g_free (data.display_name), NULL)), _tmp2);
	_tmp4 = NULL;
#line 92 "recent-manager-ui.vala"
	_tmp3 = NULL;
#line 92 "recent-manager-ui.vala"
	data.description = (_tmp4 = (_tmp3 = mime_type, (_tmp3 == NULL ? NULL : g_strdup (_tmp3))), (data.description = (g_free (data.description), NULL)), _tmp4);
	_tmp6 = NULL;
#line 93 "recent-manager-ui.vala"
	_tmp5 = NULL;
#line 93 "recent-manager-ui.vala"
	data.mime_type = (_tmp6 = (_tmp5 = mime_type, (_tmp5 == NULL ? NULL : g_strdup (_tmp5))), (data.mime_type = (g_free (data.mime_type), NULL)), _tmp6);
	_tmp7 = NULL;
#line 94 "recent-manager-ui.vala"
	data.app_name = (_tmp7 = g_strdup ("Val(a)IDE"), (data.app_name = (g_free (data.app_name), NULL)), _tmp7);
	_tmp8 = NULL;
#line 95 "recent-manager-ui.vala"
	data.app_exec = (_tmp8 = g_strdup ("valide"), (data.app_exec = (g_free (data.app_exec), NULL)), _tmp8);
	_tmp9 = NULL;
#line 96 "recent-manager-ui.vala"
	data.groups = (_tmp9 = g_new0 (char*, 2 + 1), (data.groups = (_vala_array_free (data.groups, -1, ((GDestroyNotify) g_free)), NULL)), _tmp9);
	_tmp10 = NULL;
#line 97 "recent-manager-ui.vala"
	data.groups[0] = (_tmp10 = g_strdup ("valide"), (data.groups[0] = (g_free (data.groups[0]), NULL)), _tmp10);
	_tmp11 = NULL;
#line 98 "recent-manager-ui.vala"
	data.groups[1] = (_tmp11 = NULL, (data.groups[1] = (g_free (data.groups[1]), NULL)), _tmp11);
#line 99 "recent-manager-ui.vala"
	gtk_recent_manager_add_full (gtk_recent_manager_get_default (), uri, &data);
}


#line 33 "recent-manager-ui.vala"
static void _valide_recent_manager_ui_recents_menu_activate_gtk_action_activate (GtkAction* sender, gpointer self) {
	valide_recent_manager_ui_recents_menu_activate (self, sender);
}


static void _g_list_free_gtk_recent_info_unref (GList* self) {
	g_list_foreach (self, ((GFunc) gtk_recent_info_unref), NULL);
	g_list_free (self);
}


#line 102 "recent-manager-ui.vala"
static void valide_recent_manager_ui_update (ValideRecentManagerUI* self, ValideUIManager* ui_manager, const char* file_ext, const char* ui_path, guint* id) {
	GtkActionGroup* _tmp0;
	GList* actions;
	GtkRecentManager* _tmp3;
	GtkRecentManager* recent_manager;
	GList* items;
	GList* filtered_items;
	gint i;
#line 102 "recent-manager-ui.vala"
	g_return_if_fail (VALIDE_IS_RECENT_MANAGER_UI (self));
#line 102 "recent-manager-ui.vala"
	g_return_if_fail (VALIDE_IS_UI_MANAGER (ui_manager));
#line 102 "recent-manager-ui.vala"
	g_return_if_fail (file_ext != NULL);
#line 102 "recent-manager-ui.vala"
	g_return_if_fail (ui_path != NULL);
#line 105 "recent-manager-ui.vala"
	if ((*id) != 0) {
#line 107 "recent-manager-ui.vala"
		gtk_ui_manager_remove_ui (GTK_UI_MANAGER (ui_manager), (*id));
	}
	_tmp0 = NULL;
#line 110 "recent-manager-ui.vala"
	self->priv->recents_action_group = (_tmp0 = gtk_action_group_new ("RecentActions"), (self->priv->recents_action_group == NULL ? NULL : (self->priv->recents_action_group = (g_object_unref (self->priv->recents_action_group), NULL))), _tmp0);
#line 111 "recent-manager-ui.vala"
	gtk_ui_manager_insert_action_group (GTK_UI_MANAGER (ui_manager), self->priv->recents_action_group, 0);
	actions = gtk_action_group_list_actions (self->priv->recents_action_group);
	{
		GList* l_collection;
		GList* l_it;
#line 114 "recent-manager-ui.vala"
		l_collection = actions;
		for (l_it = l_collection; l_it != NULL; l_it = l_it->next) {
			GtkAction* _tmp2;
			GtkAction* l;
			_tmp2 = NULL;
#line 114 "recent-manager-ui.vala"
			l = (_tmp2 = ((GtkAction*) l_it->data), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
			{
				guint _tmp1;
#line 116 "recent-manager-ui.vala"
				g_signal_handlers_disconnect_matched (l, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, (g_signal_parse_name ("activate", GTK_TYPE_ACTION, &_tmp1, NULL, FALSE), _tmp1), 0, NULL, ((GCallback) _valide_recent_manager_ui_recents_menu_activate_gtk_action_activate), self);
#line 117 "recent-manager-ui.vala"
				gtk_action_group_remove_action (self->priv->recents_action_group, l);
				(l == NULL ? NULL : (l = (g_object_unref (l), NULL)));
			}
		}
	}
#line 120 "recent-manager-ui.vala"
	(*id) = gtk_ui_manager_new_merge_id (GTK_UI_MANAGER (ui_manager));
#line 122 "recent-manager-ui.vala"
	_tmp3 = NULL;
	recent_manager = (_tmp3 = gtk_recent_manager_get_default (), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
	items = gtk_recent_manager_get_items (recent_manager);
	filtered_items = NULL;
	/* filter */
	{
		GList* l_collection;
		GList* l_it;
#line 127 "recent-manager-ui.vala"
		l_collection = items;
		for (l_it = l_collection; l_it != NULL; l_it = l_it->next) {
			GtkRecentInfo* _tmp5;
			GtkRecentInfo* l;
			_tmp5 = NULL;
#line 127 "recent-manager-ui.vala"
			l = (_tmp5 = ((GtkRecentInfo*) l_it->data), (_tmp5 == NULL ? NULL : gtk_recent_info_ref (_tmp5)));
			{
#line 129 "recent-manager-ui.vala"
				if (gtk_recent_info_has_group (l, "valide") && g_str_has_suffix (gtk_recent_info_get_uri (l), file_ext)) {
					GtkRecentInfo* _tmp4;
#line 131 "recent-manager-ui.vala"
					_tmp4 = NULL;
#line 131 "recent-manager-ui.vala"
					filtered_items = g_list_prepend (filtered_items, (_tmp4 = l, (_tmp4 == NULL ? NULL : gtk_recent_info_ref (_tmp4))));
				}
				(l == NULL ? NULL : (l = (gtk_recent_info_unref (l), NULL)));
			}
		}
	}
	/* sort 
	
	  filtered_items = g_list_sort (filtered_items,
	        (GCompareFunc) sort_recents_mru);
	*/
	i = 0;
	{
		GList* info_collection;
		GList* info_it;
#line 140 "recent-manager-ui.vala"
		info_collection = filtered_items;
		for (info_it = info_collection; info_it != NULL; info_it = info_it->next) {
			GtkRecentInfo* _tmp12;
			GtkRecentInfo* info;
			_tmp12 = NULL;
#line 140 "recent-manager-ui.vala"
			info = (_tmp12 = ((GtkRecentInfo*) info_it->data), (_tmp12 == NULL ? NULL : gtk_recent_info_ref (_tmp12)));
			{
				char* _tmp7;
				char* _tmp6;
				char* _tmp8;
				char* action_name;
				char* escaped;
				char* label;
				const char* _tmp11;
				char* uri;
				char* tip;
				GtkAction* action;
				/* clamp */
#line 143 "recent-manager-ui.vala"
				if (i >= self->priv->max_recents) {
					(info == NULL ? NULL : (info = (gtk_recent_info_unref (info), NULL)));
#line 145 "recent-manager-ui.vala"
					break;
				}
#line 147 "recent-manager-ui.vala"
				i++;
#line 149 "recent-manager-ui.vala"
				_tmp7 = NULL;
				_tmp6 = NULL;
				_tmp8 = NULL;
				action_name = (_tmp8 = g_strconcat ((_tmp6 = g_strconcat ("recent", file_ext, NULL)), (_tmp7 = g_strdup_printf ("-%d", i)), NULL), (_tmp7 = (g_free (_tmp7), NULL)), (_tmp6 = (g_free (_tmp6), NULL)), _tmp8);
				escaped = g_path_get_basename (gtk_recent_info_get_display_name (info));
				label = NULL;
#line 154 "recent-manager-ui.vala"
				if (i >= 10) {
					char* _tmp9;
					_tmp9 = NULL;
#line 156 "recent-manager-ui.vala"
					label = (_tmp9 = g_strdup_printf ("%d.  %s", i, escaped), (label = (g_free (label), NULL)), _tmp9);
				} else {
					char* _tmp10;
					_tmp10 = NULL;
#line 160 "recent-manager-ui.vala"
					label = (_tmp10 = g_strdup_printf ("_%d.  %s", i, escaped), (label = (g_free (label), NULL)), _tmp10);
				}
#line 163 "recent-manager-ui.vala"
				_tmp11 = NULL;
				uri = (_tmp11 = gtk_recent_info_get_uri_display (info), (_tmp11 == NULL ? NULL : g_strdup (_tmp11)));
				/* Translators: %s is a URI */
				tip = g_strdup_printf (_ ("Open '%s'"), uri);
				action = gtk_action_new (action_name, label, tip, NULL);
#line 169 "recent-manager-ui.vala"
				g_object_set_data_full (G_OBJECT (action), "gtk-recent-info", info, NULL);
#line 171 "recent-manager-ui.vala"
				g_signal_connect_object (action, "activate", ((GCallback) _valide_recent_manager_ui_recents_menu_activate_gtk_action_activate), self, 0);
#line 172 "recent-manager-ui.vala"
				gtk_action_group_add_action (self->priv->recents_action_group, action);
#line 174 "recent-manager-ui.vala"
				gtk_ui_manager_add_ui (GTK_UI_MANAGER (ui_manager), (*id), ui_path, action_name, action_name, GTK_UI_MANAGER_MENUITEM, FALSE);
				(info == NULL ? NULL : (info = (gtk_recent_info_unref (info), NULL)));
				action_name = (g_free (action_name), NULL);
				escaped = (g_free (escaped), NULL);
				label = (g_free (label), NULL);
				uri = (g_free (uri), NULL);
				tip = (g_free (tip), NULL);
				(action == NULL ? NULL : (action = (g_object_unref (action), NULL)));
			}
		}
	}
	(recent_manager == NULL ? NULL : (recent_manager = (g_object_unref (recent_manager), NULL)));
	(filtered_items == NULL ? NULL : (filtered_items = (_g_list_free_gtk_recent_info_unref (filtered_items), NULL)));
}


static void valide_recent_manager_ui_class_init (ValideRecentManagerUIClass * klass) {
	valide_recent_manager_ui_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideRecentManagerUIPrivate));
	G_OBJECT_CLASS (klass)->dispose = valide_recent_manager_ui_dispose;
}


static void valide_recent_manager_ui_init (ValideRecentManagerUI * self) {
	self->priv = VALIDE_RECENT_MANAGER_UI_GET_PRIVATE (self);
	self->priv->max_recents = 5;
	self->priv->id_file = ((guint) 0);
	self->priv->id_project = ((guint) 0);
}


static void valide_recent_manager_ui_dispose (GObject * obj) {
	ValideRecentManagerUI * self;
	self = VALIDE_RECENT_MANAGER_UI (obj);
	(self->priv->recents_action_group == NULL ? NULL : (self->priv->recents_action_group = (g_object_unref (self->priv->recents_action_group), NULL)));
	G_OBJECT_CLASS (valide_recent_manager_ui_parent_class)->dispose (obj);
}


GType valide_recent_manager_ui_get_type (void) {
	static GType valide_recent_manager_ui_type_id = 0;
	if (G_UNLIKELY (valide_recent_manager_ui_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideRecentManagerUIClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_recent_manager_ui_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideRecentManagerUI), 0, (GInstanceInitFunc) valide_recent_manager_ui_init };
		valide_recent_manager_ui_type_id = g_type_register_static (G_TYPE_OBJECT, "ValideRecentManagerUI", &g_define_type_info, 0);
	}
	return valide_recent_manager_ui_type_id;
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if (array != NULL && destroy_func != NULL) {
		int i;
		if (array_length >= 0)
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL)
			destroy_func (((gpointer*) array)[i]);
		}
		else
		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
			destroy_func (((gpointer*) array)[i]);
		}
	}
	g_free (array);
}




