/* recent-manager-ui.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

using GLib;

public class Valide.RecentManagerUI : GLib.Object
{
  private int max_recents = 5;
  private uint id_file = 0;
  private uint id_project = 0;
  private Gtk.ActionGroup recents_action_group;
  private static RecentManagerUI instance = null;

  private void recents_menu_activate (Gtk.Action sender)
  {
    Gtk.RecentInfo info;
    string uri;

    info = (Gtk.RecentInfo)sender.get_data ("gtk-recent-info");
    uri = info.get_uri ();

    if (uri.has_suffix (Project.FILE_EXT))
    {
      ProjectManager.get_instance ().create (uri);
    }
    else
    {
      DocumentManager.get_instance ().create (uri);
    }
  }

  private RecentManagerUI ()
  {
  }  

  public static RecentManagerUI get_instance ()
  {
    if (instance == null)
    {
      instance = new RecentManagerUI ();
    }
    return instance;
  }

  public void add_file (string uri)
  {
    this.add (uri, "vala");
    this.update_file (UIManager.get_instance ());
  }

  public void add_project (string uri)
  {
    this.add (uri, "vide");
    this.update_project (UIManager.get_instance ());
  }

  public void update_file (UIManager ui_manager)
  {
    this.update (ui_manager, Document.FILE_EXT, "/menubar/file/file-recents-placeholder",
                 ref this.id_file);
  }

  public void update_project (UIManager ui_manager)
  {
    this.update (ui_manager, Project.FILE_EXT, "/menubar/project/project-recents-placeholder",
                 ref this.id_project);
  }

  private void add (string uri, string mime_type)
  {
      Gtk.RecentData data = Gtk.RecentData ();
      data.display_name = uri;
      data.description = mime_type;
      data.mime_type = mime_type;
      data.app_name = "Val(a)IDE";
      data.app_exec = "valide";
      data.groups = new string[2];
      data.groups[0] = "valide";
      data.groups[1] = null;
      Gtk.RecentManager.get_default ().add_full (uri, data);
  }

  private void update (UIManager ui_manager, string file_ext, string ui_path,
                       ref uint id)
  {
	  if (id != 0)
	  {
		  ui_manager.remove_ui (id);
		}

  	this.recents_action_group = new Gtk.ActionGroup ("RecentActions");
  	ui_manager.insert_action_group (this.recents_action_group, 0);

	  weak GLib.List<Gtk.Action> actions = recents_action_group.list_actions ();
	  foreach (Gtk.Action l in actions)
	  {
		  l.activate -= this.recents_menu_activate;
   		recents_action_group.remove_action (l);
	  }

	  id = ui_manager.new_merge_id ();

	  Gtk.RecentManager recent_manager = Gtk.RecentManager.get_default ();
	  weak GLib.List<Gtk.RecentInfo> items = recent_manager.get_items ();
    GLib.List<Gtk.RecentInfo> filtered_items;

	  /* filter */
	  foreach (Gtk.RecentInfo l in items)
	  {
		  if (l.has_group ("valide") && l.get_uri ().has_suffix (file_ext))
		  {
  		  filtered_items.prepend (l);
			}
	  }
	  /* sort */
/*
	  filtered_items = g_list_sort (filtered_items,
				        (GCompareFunc) sort_recents_mru);
*/
	  int i = 0;
	  foreach (Gtk.RecentInfo info in filtered_items)
	  {
		  /* clamp */
		  if (i >= max_recents)
		  {
			  break;
			}
		  i++;

		  string action_name = "recent" + file_ext + "-%d".printf (i);

		  string escaped = GLib.Path.get_basename (info.get_display_name ());

		  string label;
		  if (i >= 10)
		  {
			  label = "%d.  %s".printf (i, escaped);
			}
		  else
		  {
			  label = "_%d.  %s".printf (i, escaped);
			}

		  string uri = info.get_uri_display ();

		  /* Translators: %s is a URI */
		  string tip = _("Open '%s'").printf (uri);

		  Gtk.Action action = new Gtk.Action (action_name, label, tip, null);
		  action.set_data_full ("gtk-recent-info", info, null);

		  action.activate += recents_menu_activate;
		  this.recents_action_group.add_action (action);

		  ui_manager.add_ui (id, ui_path, action_name, action_name,
                         Gtk.UIManagerItemType.MENUITEM, false);
	  }
  }
}

