/* template-manager.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

public class Valide.TemplateManager : GLib.Object
{
  private static TemplateManager instance = null;
  protected const string directory = GLib.Path.build_filename (Config.PACKAGE_DATA_DIR,
                                                               "template");

  private string get_path (string name)
  {
    return GLib.Path.build_filename (TemplateManager.directory, name,
                                     "template.xml");
  }

  private TemplateManager ()
  {
  }

  public static TemplateManager get_instance ()
  {
    if (TemplateManager.instance == null)
    {
      TemplateManager.instance = new TemplateManager ();
    }
    return TemplateManager.instance;
  }

  public GLib.List<string> get_list ()
  {
    GLib.List<string> list = new GLib.List<string> ();

    try
    {
      GLib.Dir dir = GLib.Dir.open (TemplateManager.directory);

      do
      {
        string filename = dir.read_name ();
        if (filename != null)
        {
          string file = this.get_path (filename);
          if (GLib.FileUtils.test (file, GLib.FileTest.EXISTS))
          {
            list.append (file);
          }
        }
        else
        {
          break;
        }
      } while (true);
      list.first ();
    }
    catch (GLib.Error e)
    {
      GLib.critical (e.message);
    }
    return list;
  }
}

