/* template.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/template.h>
#include <libxml/parser.h>
#include <libxml/tree.h>
#include <libxml/xpath.h>




struct _ValideTemplatePrivate {
	GList* files_;
	char* name_;
	char* desc_;
	char* path_;
	GdkPixbuf* icon_;
};

#define VALIDE_TEMPLATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_TEMPLATE, ValideTemplatePrivate))
enum  {
	VALIDE_TEMPLATE_DUMMY_PROPERTY,
	VALIDE_TEMPLATE_FILENAME,
	VALIDE_TEMPLATE_ICON,
	VALIDE_TEMPLATE_NAME,
	VALIDE_TEMPLATE_DESC,
	VALIDE_TEMPLATE_FILES,
	VALIDE_TEMPLATE_PATH
};
static void _g_list_free_g_free (GList* self);
static gpointer valide_template_parent_class = NULL;
static void valide_template_dispose (GObject * obj);



static void _g_list_free_g_free (GList* self) {
	g_list_foreach (self, ((GFunc) g_free), NULL);
	g_list_free (self);
}


#line 112 "template.vala"
ValideTemplate* valide_template_new (const char* filename) {
	ValideTemplate * self;
#line 112 "template.vala"
	g_return_val_if_fail (filename != NULL, NULL);
	self = g_object_newv (VALIDE_TYPE_TEMPLATE, 0, NULL);
#line 114 "template.vala"
	valide_template_set_filename (self, filename);
	return self;
}


char* valide_template_get_filename (ValideTemplate* self) {
	g_return_val_if_fail (VALIDE_IS_TEMPLATE (self), NULL);
#line 35 "template.vala"
	return g_build_filename (valide_template_get_path (self), "template.xml", NULL);
}


void valide_template_set_filename (ValideTemplate* self, char* value) {
	GError * inner_error;
	g_return_if_fail (VALIDE_IS_TEMPLATE (self));
	inner_error = NULL;
	{
		char* _tmp1;
		xmlDoc* xml;
		_tmp1 = NULL;
#line 41 "template.vala"
		self->priv->path_ = (_tmp1 = g_path_get_dirname (value), (self->priv->path_ = (g_free (self->priv->path_), NULL)), _tmp1);
		xml = xmlParseFile (value);
#line 44 "template.vala"
		if (xml != NULL) {
			xmlXPathContext* xpath;
			xmlXPathObject* xpath_obj;
			char* _tmp3;
			const char* _tmp2;
			char* _tmp5;
			const char* _tmp4;
			GdkPixbuf* _tmp8;
			char* _tmp7;
			char* _tmp6;
			xpath = xmlXPathNewContext (xml);
			xpath_obj = xmlXPathEval ("/template/files/file/text ()", xpath);
			{
				gint i;
				i = 0;
#line 48 "template.vala"
				for (; i < xmlXPathNodeSetGetLength (xpath_obj->nodesetval); i++) {
#line 50 "template.vala"
					self->priv->files_ = g_list_append (self->priv->files_, g_build_filename (valide_template_get_path (self), xmlXPathNodeSetItem (xpath_obj->nodesetval, i)->content, NULL, NULL));
				}
			}
#line 55 "template.vala"
			xpath_obj = xmlXPathEval ("/template/name/text ()", xpath);
			_tmp3 = NULL;
#line 56 "template.vala"
			_tmp2 = NULL;
#line 56 "template.vala"
			self->priv->name_ = (_tmp3 = (_tmp2 = xmlXPathNodeSetItem (xpath_obj->nodesetval, 0)->content, (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (self->priv->name_ = (g_free (self->priv->name_), NULL)), _tmp3);
#line 58 "template.vala"
			xpath_obj = xmlXPathEval ("/template/description/text ()", xpath);
			_tmp5 = NULL;
#line 59 "template.vala"
			_tmp4 = NULL;
#line 59 "template.vala"
			self->priv->desc_ = (_tmp5 = (_tmp4 = xmlXPathNodeSetItem (xpath_obj->nodesetval, 0)->content, (_tmp4 == NULL ? NULL : g_strdup (_tmp4))), (self->priv->desc_ = (g_free (self->priv->desc_), NULL)), _tmp5);
			_tmp8 = NULL;
			_tmp7 = NULL;
#line 61 "template.vala"
			_tmp6 = NULL;
#line 61 "template.vala"
			self->priv->icon_ = (_tmp8 = gdk_pixbuf_new_from_file ((_tmp7 = g_strconcat ((_tmp6 = g_path_get_dirname (value)), "/icon.png", NULL)), &inner_error), (self->priv->icon_ == NULL ? NULL : (self->priv->icon_ = (g_object_unref (self->priv->icon_), NULL))), _tmp8);
			if (inner_error != NULL) {
				goto __catch8_g_error;
			}
			_tmp7 = (g_free (_tmp7), NULL);
			_tmp6 = (g_free (_tmp6), NULL);
			(xpath == NULL ? NULL : (xpath = (xmlXPathFreeContext (xpath), NULL)));
		}
	}
	goto __finally8;
	__catch8_g_error:
	{
		GError * e;
		e = inner_error;
		inner_error = NULL;
		{
#line 67 "template.vala"
			g_warning (e->message);
		}
	}
	__finally8:
	;
}


GdkPixbuf* valide_template_get_icon (ValideTemplate* self) {
	g_return_val_if_fail (VALIDE_IS_TEMPLATE (self), NULL);
#line 76 "template.vala"
	return self->priv->icon_;
}


const char* valide_template_get_name (ValideTemplate* self) {
	g_return_val_if_fail (VALIDE_IS_TEMPLATE (self), NULL);
#line 84 "template.vala"
	return self->priv->name_;
}


const char* valide_template_get_desc (ValideTemplate* self) {
	g_return_val_if_fail (VALIDE_IS_TEMPLATE (self), NULL);
#line 92 "template.vala"
	return self->priv->desc_;
}


GList* valide_template_get_files (ValideTemplate* self) {
	g_return_val_if_fail (VALIDE_IS_TEMPLATE (self), NULL);
#line 100 "template.vala"
	return g_list_first (self->priv->files_);
}


const char* valide_template_get_path (ValideTemplate* self) {
	g_return_val_if_fail (VALIDE_IS_TEMPLATE (self), NULL);
#line 108 "template.vala"
	return self->priv->path_;
}


static void valide_template_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValideTemplate * self;
	self = VALIDE_TEMPLATE (object);
	switch (property_id) {
		case VALIDE_TEMPLATE_FILENAME:
		g_value_set_string (value, valide_template_get_filename (self));
		break;
		case VALIDE_TEMPLATE_ICON:
		g_value_set_object (value, valide_template_get_icon (self));
		break;
		case VALIDE_TEMPLATE_NAME:
		g_value_set_string (value, valide_template_get_name (self));
		break;
		case VALIDE_TEMPLATE_DESC:
		g_value_set_string (value, valide_template_get_desc (self));
		break;
		case VALIDE_TEMPLATE_FILES:
		g_value_set_pointer (value, valide_template_get_files (self));
		break;
		case VALIDE_TEMPLATE_PATH:
		g_value_set_string (value, valide_template_get_path (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_template_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValideTemplate * self;
	self = VALIDE_TEMPLATE (object);
	switch (property_id) {
		case VALIDE_TEMPLATE_FILENAME:
		valide_template_set_filename (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_template_class_init (ValideTemplateClass * klass) {
	valide_template_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideTemplatePrivate));
	G_OBJECT_CLASS (klass)->get_property = valide_template_get_property;
	G_OBJECT_CLASS (klass)->set_property = valide_template_set_property;
	G_OBJECT_CLASS (klass)->dispose = valide_template_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_TEMPLATE_FILENAME, g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_TEMPLATE_ICON, g_param_spec_object ("icon", "icon", "icon", GDK_TYPE_PIXBUF, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_TEMPLATE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_TEMPLATE_DESC, g_param_spec_string ("desc", "desc", "desc", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_TEMPLATE_FILES, g_param_spec_pointer ("files", "files", "files", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_TEMPLATE_PATH, g_param_spec_string ("path", "path", "path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void valide_template_init (ValideTemplate * self) {
	self->priv = VALIDE_TEMPLATE_GET_PRIVATE (self);
}


static void valide_template_dispose (GObject * obj) {
	ValideTemplate * self;
	self = VALIDE_TEMPLATE (obj);
	(self->priv->files_ == NULL ? NULL : (self->priv->files_ = (_g_list_free_g_free (self->priv->files_), NULL)));
	self->priv->name_ = (g_free (self->priv->name_), NULL);
	self->priv->desc_ = (g_free (self->priv->desc_), NULL);
	self->priv->path_ = (g_free (self->priv->path_), NULL);
	(self->priv->icon_ == NULL ? NULL : (self->priv->icon_ = (g_object_unref (self->priv->icon_), NULL)));
	G_OBJECT_CLASS (valide_template_parent_class)->dispose (obj);
}


GType valide_template_get_type (void) {
	static GType valide_template_type_id = 0;
	if (G_UNLIKELY (valide_template_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideTemplateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_template_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideTemplate), 0, (GInstanceInitFunc) valide_template_init };
		valide_template_type_id = g_type_register_static (G_TYPE_OBJECT, "ValideTemplate", &g_define_type_info, 0);
	}
	return valide_template_type_id;
}




