/* template.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

public class Valide.Template : GLib.Object
{
  private GLib.List<string> files_;
  private string name_;
  private string desc_;
  private string path_;
  private Gdk.Pixbuf icon_;

  public string# filename  
  {
    get
    {
      return GLib.Path.build_filename (this.path, "template.xml");
    }
    set
    {
      try
      {
        this.path_ = GLib.Path.get_dirname (value);

        Xml.Doc* xml = Xml.Parser.parse_file (value);
        if (xml != null)
        {
          Xml.XPathContext xpath = new Xml.XPathContext (xml);
          Xml.XPathObject* xpath_obj = xpath.eval ("/template/files/file/text ()");
          for (int i = 0; i < xpath_obj->nodesetval->length (); i++)
          {
            this.files_.append (GLib.Path.build_filename (this.path,
                                                          xpath_obj->nodesetval->item (i)->content,
                                                          null));
          }

          xpath_obj = xpath.eval ("/template/name/text ()");
          this.name_ = xpath_obj->nodesetval->item (0)->content;

          xpath_obj = xpath.eval ("/template/description/text ()");
          this.desc_ = xpath_obj->nodesetval->item (0)->content;

          this.icon_ = new Gdk.Pixbuf.from_file (GLib.Path.get_dirname (value)
                                                 + "/icon.png");
        }
      }
      catch (GLib.Error e)
      {
        GLib.warning (e.message);
      }
    }
  }

  public Gdk.Pixbuf icon
  {
    get
    {
      return this.icon_;
    }
  }

  public string name
  {
    get
    {
      return this.name_;
    }
  }

  public string desc
  {
    get
    {
      return this.desc_;
    }
  }

  public GLib.List<string> files
  {
    get
    {
      return this.files_.first ();
    }
  }

  public string path
  {
    get
    {
      return this.path_;
    }
  }

  public Template (string filename)
  {
    this.filename = filename;
  }
}

