/* executable.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/third-party/abstract-executable.h>




struct _ValideAbstractExecutablePrivate {
	gboolean running;
};

#define VALIDE_ABSTRACT_EXECUTABLE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_ABSTRACT_EXECUTABLE, ValideAbstractExecutablePrivate))
enum  {
	VALIDE_ABSTRACT_EXECUTABLE_DUMMY_PROPERTY,
	VALIDE_ABSTRACT_EXECUTABLE_WORKING_DIRECTORY,
	VALIDE_ABSTRACT_EXECUTABLE_START_MSG,
	VALIDE_ABSTRACT_EXECUTABLE_END_MSG,
	VALIDE_ABSTRACT_EXECUTABLE_EXECUTABLE
};
static void valide_abstract_executable_real_parsing (ValideAbstractExecutable* self, ValideExecutableManager* sender, char** line);
static void valide_abstract_executable_cmd_start (ValideAbstractExecutable* self, ValideExecutableManager* sender, const char* cmd);
static void _valide_abstract_executable_cmd_start_valide_executable_manager_cmd_start (ValideExecutableManager* sender, const char* cmd, gpointer self);
static void _valide_abstract_executable_cmd_end_valide_executable_manager_cmd_end (ValideExecutableManager* sender, gint status, gpointer self);
static void valide_abstract_executable_cmd_end (ValideAbstractExecutable* self, ValideExecutableManager* sender, gint status);
static void _valide_abstract_executable_parsing_valide_executable_manager_parsing (ValideExecutableManager* sender, char** line, gpointer self);
static void valide_abstract_executable_real_run (ValideAbstractExecutable* self, const char* options, const char* dir, GError** error);
static gpointer valide_abstract_executable_parent_class = NULL;
static void valide_abstract_executable_dispose (GObject * obj);



#line 53 "abstract-executable.vala"
static void valide_abstract_executable_real_parsing (ValideAbstractExecutable* self, ValideExecutableManager* sender, char** line) {
#line 53 "abstract-executable.vala"
	g_return_if_fail (VALIDE_IS_ABSTRACT_EXECUTABLE (self));
#line 53 "abstract-executable.vala"
	g_return_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (sender));
#line 53 "abstract-executable.vala"
	g_return_if_fail (line != NULL);
}


#line 53 "abstract-executable.vala"
void valide_abstract_executable_parsing (ValideAbstractExecutable* self, ValideExecutableManager* sender, char** line) {
#line 53 "abstract-executable.vala"
	VALIDE_ABSTRACT_EXECUTABLE_GET_CLASS (self)->parsing (self, sender, line);
}


#line 57 "abstract-executable.vala"
static void valide_abstract_executable_cmd_start (ValideAbstractExecutable* self, ValideExecutableManager* sender, const char* cmd) {
	GError * inner_error;
#line 57 "abstract-executable.vala"
	g_return_if_fail (VALIDE_IS_ABSTRACT_EXECUTABLE (self));
#line 57 "abstract-executable.vala"
	g_return_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (sender));
#line 57 "abstract-executable.vala"
	g_return_if_fail (cmd != NULL);
	inner_error = NULL;
	{
		GRegex* regex;
		char* msg;
		regex = g_regex_new ("\\{\\$cmd\\}", G_REGEX_OPTIMIZE, G_REGEX_MATCH_NOTEMPTY, &inner_error);
		if (inner_error != NULL) {
			goto __catch12_g_error;
		}
		msg = g_regex_replace (regex, valide_abstract_executable_get_start_msg (self), ((glong) -1), 0, cmd, G_REGEX_MATCH_NOTEMPTY, &inner_error);
		if (inner_error != NULL) {
			goto __catch12_g_error;
		}
#line 66 "abstract-executable.vala"
		valide_executable_manager_add_line (sender, msg);
		(regex == NULL ? NULL : (regex = (g_regex_unref (regex), NULL)));
		msg = (g_free (msg), NULL);
	}
	goto __finally12;
	__catch12_g_error:
	{
		GError * e;
		e = inner_error;
		inner_error = NULL;
		{
#line 70 "abstract-executable.vala"
			g_critical (e->message);
		}
	}
	__finally12:
	;
}


#line 57 "abstract-executable.vala"
static void _valide_abstract_executable_cmd_start_valide_executable_manager_cmd_start (ValideExecutableManager* sender, const char* cmd, gpointer self) {
	valide_abstract_executable_cmd_start (self, sender, cmd);
}


#line 74 "abstract-executable.vala"
static void _valide_abstract_executable_cmd_end_valide_executable_manager_cmd_end (ValideExecutableManager* sender, gint status, gpointer self) {
	valide_abstract_executable_cmd_end (self, sender, status);
}


#line 74 "abstract-executable.vala"
static void valide_abstract_executable_cmd_end (ValideAbstractExecutable* self, ValideExecutableManager* sender, gint status) {
	guint _tmp0;
	guint _tmp1;
#line 74 "abstract-executable.vala"
	g_return_if_fail (VALIDE_IS_ABSTRACT_EXECUTABLE (self));
#line 74 "abstract-executable.vala"
	g_return_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (sender));
#line 76 "abstract-executable.vala"
	g_signal_handlers_disconnect_matched (sender, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, (g_signal_parse_name ("cmd-start", VALIDE_TYPE_EXECUTABLE_MANAGER, &_tmp0, NULL, FALSE), _tmp0), 0, NULL, ((GCallback) _valide_abstract_executable_cmd_start_valide_executable_manager_cmd_start), self);
#line 77 "abstract-executable.vala"
	g_signal_handlers_disconnect_matched (sender, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, (g_signal_parse_name ("cmd-end", VALIDE_TYPE_EXECUTABLE_MANAGER, &_tmp1, NULL, FALSE), _tmp1), 0, NULL, ((GCallback) _valide_abstract_executable_cmd_end_valide_executable_manager_cmd_end), self);
#line 78 "abstract-executable.vala"
	self->priv->running = FALSE;
#line 79 "abstract-executable.vala"
	valide_executable_manager_add_line (sender, valide_abstract_executable_get_end_msg (self));
}


#line 53 "abstract-executable.vala"
static void _valide_abstract_executable_parsing_valide_executable_manager_parsing (ValideExecutableManager* sender, char** line, gpointer self) {
	valide_abstract_executable_parsing (self, sender, line);
}


#line 82 "abstract-executable.vala"
static void valide_abstract_executable_real_run (ValideAbstractExecutable* self, const char* options, const char* dir, GError** error) {
#line 82 "abstract-executable.vala"
	g_return_if_fail (VALIDE_IS_ABSTRACT_EXECUTABLE (self));
#line 82 "abstract-executable.vala"
	g_return_if_fail (options != NULL);
#line 84 "abstract-executable.vala"
	if (self->priv->running == FALSE) {
		ValideExecutableManager* exec;
		char* directory;
		char* _tmp5;
		char* _tmp4;
#line 86 "abstract-executable.vala"
		self->priv->running = TRUE;
		exec = valide_executable_manager_get_instance ();
		directory = NULL;
#line 90 "abstract-executable.vala"
		if (dir != NULL) {
			char* _tmp1;
			const char* _tmp0;
			_tmp1 = NULL;
#line 92 "abstract-executable.vala"
			_tmp0 = NULL;
#line 92 "abstract-executable.vala"
			directory = (_tmp1 = (_tmp0 = dir, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (directory = (g_free (directory), NULL)), _tmp1);
		} else {
			char* _tmp3;
			const char* _tmp2;
			_tmp3 = NULL;
#line 96 "abstract-executable.vala"
			_tmp2 = NULL;
#line 96 "abstract-executable.vala"
			directory = (_tmp3 = (_tmp2 = valide_abstract_executable_get_working_directory (self), (_tmp2 == NULL ? NULL : g_strdup (_tmp2))), (directory = (g_free (directory), NULL)), _tmp3);
		}
#line 98 "abstract-executable.vala"
		g_signal_connect_object (exec, "cmd-start", ((GCallback) _valide_abstract_executable_cmd_start_valide_executable_manager_cmd_start), self, 0);
#line 99 "abstract-executable.vala"
		g_signal_connect_object (exec, "cmd-end", ((GCallback) _valide_abstract_executable_cmd_end_valide_executable_manager_cmd_end), self, 0);
#line 100 "abstract-executable.vala"
		g_signal_connect_object (exec, "parsing", ((GCallback) _valide_abstract_executable_parsing_valide_executable_manager_parsing), self, 0);
		_tmp5 = NULL;
		_tmp4 = NULL;
#line 101 "abstract-executable.vala"
		valide_executable_manager_run (exec, directory, (_tmp5 = g_strconcat ((_tmp4 = g_strconcat (valide_abstract_executable_get_executable (self), " ", NULL)), options, NULL)));
		_tmp5 = (g_free (_tmp5), NULL);
		_tmp4 = (g_free (_tmp4), NULL);
		(exec == NULL ? NULL : (exec = (g_object_unref (exec), NULL)));
		directory = (g_free (directory), NULL);
	} else {
#line 105 "abstract-executable.vala"
		g_warning ("abstract-executable.vala:105: Already running!");
	}
}


#line 82 "abstract-executable.vala"
void valide_abstract_executable_run (ValideAbstractExecutable* self, const char* options, const char* dir, GError** error) {
#line 82 "abstract-executable.vala"
	VALIDE_ABSTRACT_EXECUTABLE_GET_CLASS (self)->run (self, options, dir, error);
}


#line 25 "abstract-executable.vala"
ValideAbstractExecutable* valide_abstract_executable_new (void) {
	ValideAbstractExecutable * self;
	self = g_object_newv (VALIDE_TYPE_ABSTRACT_EXECUTABLE, 0, NULL);
	return self;
}


char* valide_abstract_executable_get_working_directory (ValideAbstractExecutable* self) {
	char* value;
	g_object_get (G_OBJECT (self), "working-directory", &value, NULL);
	return value;
}


void valide_abstract_executable_set_working_directory (ValideAbstractExecutable* self, char* value) {
	g_object_set (G_OBJECT (self), "working-directory", value, NULL);
}


char* valide_abstract_executable_get_start_msg (ValideAbstractExecutable* self) {
	char* value;
	g_object_get (G_OBJECT (self), "start-msg", &value, NULL);
	return value;
}


void valide_abstract_executable_set_start_msg (ValideAbstractExecutable* self, char* value) {
	g_object_set (G_OBJECT (self), "start-msg", value, NULL);
}


char* valide_abstract_executable_get_end_msg (ValideAbstractExecutable* self) {
	char* value;
	g_object_get (G_OBJECT (self), "end-msg", &value, NULL);
	return value;
}


void valide_abstract_executable_set_end_msg (ValideAbstractExecutable* self, char* value) {
	g_object_set (G_OBJECT (self), "end-msg", value, NULL);
}


char* valide_abstract_executable_get_executable (ValideAbstractExecutable* self) {
	char* value;
	g_object_get (G_OBJECT (self), "executable", &value, NULL);
	return value;
}


void valide_abstract_executable_set_executable (ValideAbstractExecutable* self, char* value) {
	g_object_set (G_OBJECT (self), "executable", value, NULL);
}


static void valide_abstract_executable_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValideAbstractExecutable * self;
	self = VALIDE_ABSTRACT_EXECUTABLE (object);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_abstract_executable_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValideAbstractExecutable * self;
	self = VALIDE_ABSTRACT_EXECUTABLE (object);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_abstract_executable_class_init (ValideAbstractExecutableClass * klass) {
	valide_abstract_executable_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideAbstractExecutablePrivate));
	G_OBJECT_CLASS (klass)->get_property = valide_abstract_executable_get_property;
	G_OBJECT_CLASS (klass)->set_property = valide_abstract_executable_set_property;
	G_OBJECT_CLASS (klass)->dispose = valide_abstract_executable_dispose;
	VALIDE_ABSTRACT_EXECUTABLE_CLASS (klass)->parsing = valide_abstract_executable_real_parsing;
	VALIDE_ABSTRACT_EXECUTABLE_CLASS (klass)->run = valide_abstract_executable_real_run;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_ABSTRACT_EXECUTABLE_WORKING_DIRECTORY, g_param_spec_string ("working-directory", "working-directory", "working-directory", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_ABSTRACT_EXECUTABLE_START_MSG, g_param_spec_string ("start-msg", "start-msg", "start-msg", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_ABSTRACT_EXECUTABLE_END_MSG, g_param_spec_string ("end-msg", "end-msg", "end-msg", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_ABSTRACT_EXECUTABLE_EXECUTABLE, g_param_spec_string ("executable", "executable", "executable", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void valide_abstract_executable_init (ValideAbstractExecutable * self) {
	self->priv = VALIDE_ABSTRACT_EXECUTABLE_GET_PRIVATE (self);
	self->priv->running = FALSE;
}


static void valide_abstract_executable_dispose (GObject * obj) {
	ValideAbstractExecutable * self;
	self = VALIDE_ABSTRACT_EXECUTABLE (obj);
	G_OBJECT_CLASS (valide_abstract_executable_parent_class)->dispose (obj);
}


GType valide_abstract_executable_get_type (void) {
	static GType valide_abstract_executable_type_id = 0;
	if (G_UNLIKELY (valide_abstract_executable_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideAbstractExecutableClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_abstract_executable_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideAbstractExecutable), 0, (GInstanceInitFunc) valide_abstract_executable_init };
		valide_abstract_executable_type_id = g_type_register_static (G_TYPE_OBJECT, "ValideAbstractExecutable", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	}
	return valide_abstract_executable_type_id;
}




