/* executable.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#ifndef __SRC_THIRD_PARTY_ABSTRACT_EXECUTABLE_H__
#define __SRC_THIRD_PARTY_ABSTRACT_EXECUTABLE_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include "src/third-party/executable-manager.h"

G_BEGIN_DECLS


#define VALIDE_TYPE_ABSTRACT_EXECUTABLE (valide_abstract_executable_get_type ())
#define VALIDE_ABSTRACT_EXECUTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALIDE_TYPE_ABSTRACT_EXECUTABLE, ValideAbstractExecutable))
#define VALIDE_ABSTRACT_EXECUTABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALIDE_TYPE_ABSTRACT_EXECUTABLE, ValideAbstractExecutableClass))
#define VALIDE_IS_ABSTRACT_EXECUTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALIDE_TYPE_ABSTRACT_EXECUTABLE))
#define VALIDE_IS_ABSTRACT_EXECUTABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALIDE_TYPE_ABSTRACT_EXECUTABLE))
#define VALIDE_ABSTRACT_EXECUTABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALIDE_TYPE_ABSTRACT_EXECUTABLE, ValideAbstractExecutableClass))

typedef struct _ValideAbstractExecutable ValideAbstractExecutable;
typedef struct _ValideAbstractExecutableClass ValideAbstractExecutableClass;
typedef struct _ValideAbstractExecutablePrivate ValideAbstractExecutablePrivate;

struct _ValideAbstractExecutable {
	GObject parent_instance;
	ValideAbstractExecutablePrivate * priv;
};

struct _ValideAbstractExecutableClass {
	GObjectClass parent_class;
	void (*parsing) (ValideAbstractExecutable* self, ValideExecutableManager* sender, char** line);
	void (*run) (ValideAbstractExecutable* self, const char* options, const char* dir, GError** error);
};


void valide_abstract_executable_parsing (ValideAbstractExecutable* self, ValideExecutableManager* sender, char** line);
void valide_abstract_executable_run (ValideAbstractExecutable* self, const char* options, const char* dir, GError** error);
ValideAbstractExecutable* valide_abstract_executable_new (void);
char* valide_abstract_executable_get_working_directory (ValideAbstractExecutable* self);
void valide_abstract_executable_set_working_directory (ValideAbstractExecutable* self, char* value);
char* valide_abstract_executable_get_start_msg (ValideAbstractExecutable* self);
void valide_abstract_executable_set_start_msg (ValideAbstractExecutable* self, char* value);
char* valide_abstract_executable_get_end_msg (ValideAbstractExecutable* self);
void valide_abstract_executable_set_end_msg (ValideAbstractExecutable* self, char* value);
char* valide_abstract_executable_get_executable (ValideAbstractExecutable* self);
void valide_abstract_executable_set_executable (ValideAbstractExecutable* self, char* value);
GType valide_abstract_executable_get_type (void);


G_END_DECLS

#endif
