/* executable.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

using GLib;

public abstract class Valide.AbstractExecutable : GLib.Object
{
  private bool running = false;

  protected abstract string# working_directory
  {
    get;
    set;
  }

  protected abstract string# start_msg
  {
    get;
    set;
  }

  protected abstract string# end_msg
  {
    get;
    set;
  }

  protected abstract string# executable
  {
    get;
    set;
  }

  protected virtual void parsing (ExecutableManager sender, ref string line)
  {
  }

  private void cmd_start (ExecutableManager sender, string cmd)
  {
    try
    {
      GLib.Regex regex = new GLib.Regex ("\\{\\$cmd\\}",
                                         GLib.RegexCompileFlags.OPTIMIZE,
                                         GLib.RegexMatchFlags.NOTEMPTY);
      string msg = regex.replace (this.start_msg, -1, 0, cmd,
                                  GLib.RegexMatchFlags.NOTEMPTY);
      sender.add_line (msg);
    }
    catch (GLib.Error e)
    {
      GLib.critical (e.message);
    }
  }

  private void cmd_end (ExecutableManager sender, int status)
  {
    sender.cmd_start -= this.cmd_start;
    sender.cmd_end -= this.cmd_end;
    this.running = false;
    sender.add_line (this.end_msg);
  }

  public virtual void run (string options = "", string? dir = null) throws GLib.Error
  {
    if (this.running == false)
    {
      this.running = true;
      ExecutableManager exec = ExecutableManager.get_instance ();

      string directory;
      if (dir != null)
      {
        directory = dir;
      }
      else
      {
        directory = this.working_directory;
      }
      exec.cmd_start += this.cmd_start;
      exec.cmd_end += this.cmd_end;
      exec.parsing += this.parsing;
      exec.run (directory, this.executable + " " + options);
    }
    else
    {
      GLib.warning ("Already running!");
    }
  }
}

