/* executable-manager.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/third-party/executable-manager.h>
#include <gdk/gdk.h>
#include <float.h>
#include <math.h>
#include <config.h>
#include "src/third-party/utils.h"




struct _ValideExecutableManagerPrivate {
	GtkListStore* list_store;
	GtkTreeView* tree_view;
};

#define VALIDE_EXECUTABLE_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_EXECUTABLE_MANAGER, ValideExecutableManagerPrivate))
enum  {
	VALIDE_EXECUTABLE_MANAGER_DUMMY_PROPERTY
};
static ValideExecutableManager* valide_executable_manager_instance = NULL;
static ValideExecutableManager* valide_executable_manager_new (void);
static void valide_executable_manager_clear (ValideExecutableManager* self, GtkButton* sender);
static void valide_executable_manager_copy (ValideExecutableManager* self, GtkButton* sender);
static void valide_executable_manager_copy_bbcode (ValideExecutableManager* self, GtkButton* sender);
static gboolean valide_executable_manager_build_iofunc (ValideExecutableManager* self, GIOChannel* ioc, GIOCondition cond);
static void valide_executable_manager_cmd_watch (ValideExecutableManager* self, GPid pid, gint status);
static gboolean _valide_executable_manager_build_iofunc_gio_func (GIOChannel* source, GIOCondition condition, gpointer self);
static void _valide_executable_manager_cmd_watch_gchild_watch_func (GPid pid, gint status, gpointer self);
static char* valide_executable_manager_get_text (ValideExecutableManager* self);
static void _valide_executable_manager_clear_gtk_button_clicked (GtkButton* sender, gpointer self);
static void _valide_executable_manager_copy_gtk_button_clicked (GtkButton* sender, gpointer self);
static void _valide_executable_manager_copy_bbcode_gtk_button_clicked (GtkButton* sender, gpointer self);
static GObject * valide_executable_manager_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer valide_executable_manager_parent_class = NULL;
static void valide_executable_manager_dispose (GObject * obj);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static int _vala_strcmp0 (const char * str1, const char * str2);



#line 56 "executable-manager.vala"
static ValideExecutableManager* valide_executable_manager_new (void) {
	ValideExecutableManager * self;
	self = g_object_newv (VALIDE_TYPE_EXECUTABLE_MANAGER, 0, NULL);
	return self;
}


#line 61 "executable-manager.vala"
static void valide_executable_manager_clear (ValideExecutableManager* self, GtkButton* sender) {
#line 61 "executable-manager.vala"
	g_return_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (self));
#line 61 "executable-manager.vala"
	g_return_if_fail (GTK_IS_BUTTON (sender));
#line 63 "executable-manager.vala"
	gtk_list_store_clear (self->priv->list_store);
}


#line 67 "executable-manager.vala"
static void valide_executable_manager_copy (ValideExecutableManager* self, GtkButton* sender) {
	GtkClipboard* clipboard;
	const char* _tmp0;
	char* str;
#line 67 "executable-manager.vala"
	g_return_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (self));
#line 67 "executable-manager.vala"
	g_return_if_fail (GTK_IS_BUTTON (sender));
	clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
#line 70 "executable-manager.vala"
	_tmp0 = NULL;
	str = (_tmp0 = valide_executable_manager_get_text (self), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
#line 72 "executable-manager.vala"
	if (_vala_strcmp0 (str, "") != 0) {
#line 74 "executable-manager.vala"
		gtk_clipboard_set_text (clipboard, str, -1);
	} else {
#line 78 "executable-manager.vala"
		g_warning ("executable-manager.vala:78: Nothing to copy!");
	}
	str = (g_free (str), NULL);
}


#line 83 "executable-manager.vala"
static void valide_executable_manager_copy_bbcode (ValideExecutableManager* self, GtkButton* sender) {
	GError * inner_error;
	GtkClipboard* clipboard;
	const char* _tmp0;
	char* str;
#line 83 "executable-manager.vala"
	g_return_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (self));
#line 83 "executable-manager.vala"
	g_return_if_fail (GTK_IS_BUTTON (sender));
	inner_error = NULL;
	clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
#line 86 "executable-manager.vala"
	_tmp0 = NULL;
	str = (_tmp0 = valide_executable_manager_get_text (self), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
#line 88 "executable-manager.vala"
	if (_vala_strcmp0 (str, "") != 0) {
		GHashTable* pattern;
		pattern = g_hash_table_new (g_str_hash, g_str_equal);
#line 91 "executable-manager.vala"
		g_hash_table_insert (pattern, g_strdup ("<i>(.*)</i>"), g_strdup ("[i]\1[/i]"));
#line 92 "executable-manager.vala"
		g_hash_table_insert (pattern, g_strdup ("<b>(.*)</b>"), g_strdup ("[b]\1[/b]"));
#line 93 "executable-manager.vala"
		g_hash_table_insert (pattern, g_strdup ("<span background=\"(.*)\">(.*)</span>"), g_strdup ("[color=\"\1\"]\2[/color]"));
#line 94 "executable-manager.vala"
		g_hash_table_insert (pattern, g_strdup ("<span foreground=\"(.*)\">(.*)</span>"), g_strdup ("[color=\"\1\"]\2[/color]"));
		{
			GList* key_collection;
			GList* key_it;
#line 96 "executable-manager.vala"
			key_collection = g_hash_table_get_keys (pattern);
			for (key_it = key_collection; key_it != NULL; key_it = key_it->next) {
				const char* _tmp2;
				char* key;
				_tmp2 = NULL;
#line 96 "executable-manager.vala"
				key = (_tmp2 = ((char*) key_it->data), (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
				{
					GRegex* regex;
					char* _tmp1;
					regex = g_regex_new (key, G_REGEX_OPTIMIZE, G_REGEX_MATCH_NOTEMPTY, &inner_error);
					if (inner_error != NULL) {
						g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
						g_clear_error (&inner_error);
					}
					_tmp1 = NULL;
#line 101 "executable-manager.vala"
					str = (_tmp1 = g_regex_replace (regex, str, ((glong) -1), 0, ((const char*) g_hash_table_lookup (pattern, key)), G_REGEX_MATCH_NOTEMPTY, &inner_error), (str = (g_free (str), NULL)), _tmp1);
					if (inner_error != NULL) {
						g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
						g_clear_error (&inner_error);
					}
					key = (g_free (key), NULL);
					(regex == NULL ? NULL : (regex = (g_regex_unref (regex), NULL)));
				}
			}
#line 96 "executable-manager.vala"
			(key_collection == NULL ? NULL : (key_collection = (g_list_free (key_collection), NULL)));
		}
#line 105 "executable-manager.vala"
		gtk_clipboard_set_text (clipboard, str, -1);
		(pattern == NULL ? NULL : (pattern = (g_hash_table_unref (pattern), NULL)));
	} else {
#line 109 "executable-manager.vala"
		g_warning ("executable-manager.vala:109: Nothing to copy!");
	}
	str = (g_free (str), NULL);
}


#line 150 "executable-manager.vala"
ValideExecutableManager* valide_executable_manager_get_instance (void) {
	ValideExecutableManager* _tmp1;
#line 152 "executable-manager.vala"
	if (valide_executable_manager_instance == NULL) {
		ValideExecutableManager* _tmp0;
		_tmp0 = NULL;
#line 154 "executable-manager.vala"
		valide_executable_manager_instance = (_tmp0 = g_object_ref_sink (valide_executable_manager_new ()), (valide_executable_manager_instance == NULL ? NULL : (valide_executable_manager_instance = (g_object_unref (valide_executable_manager_instance), NULL))), _tmp0);
	}
#line 156 "executable-manager.vala"
	_tmp1 = NULL;
#line 156 "executable-manager.vala"
	return (_tmp1 = valide_executable_manager_instance, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
}


#line 159 "executable-manager.vala"
static gboolean valide_executable_manager_build_iofunc (ValideExecutableManager* self, GIOChannel* ioc, GIOCondition cond) {
	GError * inner_error;
	gboolean ret;
#line 159 "executable-manager.vala"
	g_return_val_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (self), FALSE);
#line 159 "executable-manager.vala"
	g_return_val_if_fail (ioc != NULL, FALSE);
	inner_error = NULL;
	ret = FALSE;
#line 163 "executable-manager.vala"
	if ((cond & (G_IO_IN | G_IO_PRI)) != 0) {
		char* msg;
		GIOStatus rv;
		GIOStatus _tmp1;
		char* _tmp0;
		msg = NULL;
		rv = 0;
		_tmp0 = NULL;
#line 168 "executable-manager.vala"
		rv = (_tmp1 = g_io_channel_read_line (ioc, &_tmp0, NULL, NULL, &inner_error), (msg = (g_free (msg), NULL)), msg = _tmp0, _tmp1);
		if (inner_error != NULL) {
			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
			g_clear_error (&inner_error);
		}
#line 169 "executable-manager.vala"
		if (msg != NULL) {
#line 171 "executable-manager.vala"
			valide_executable_manager_add_line (self, msg);
		}
#line 173 "executable-manager.vala"
		if (rv == G_IO_STATUS_NORMAL || rv == G_IO_STATUS_AGAIN) {
#line 175 "executable-manager.vala"
			ret = TRUE;
		}
		msg = (g_free (msg), NULL);
	}
#line 178 "executable-manager.vala"
	return ret;
}


#line 181 "executable-manager.vala"
static void valide_executable_manager_cmd_watch (ValideExecutableManager* self, GPid pid, gint status) {
#line 181 "executable-manager.vala"
	g_return_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (self));
#line 183 "executable-manager.vala"
	g_signal_emit_by_name (G_OBJECT (self), "cmd-end", status);
}


#line 159 "executable-manager.vala"
static gboolean _valide_executable_manager_build_iofunc_gio_func (GIOChannel* source, GIOCondition condition, gpointer self) {
	return valide_executable_manager_build_iofunc (self, source, condition);
}


#line 181 "executable-manager.vala"
static void _valide_executable_manager_cmd_watch_gchild_watch_func (GPid pid, gint status, gpointer self) {
	valide_executable_manager_cmd_watch (self, pid, status);
}


#line 186 "executable-manager.vala"
void valide_executable_manager_run (ValideExecutableManager* self, const char* dir, const char* cmd) {
	GError * inner_error;
	char* cmd2;
	char** _tmp1;
	gint args_length1;
	char** args;
	gint std_out;
	gint std_err;
	GPid pid;
	GIOCondition cond;
#line 186 "executable-manager.vala"
	g_return_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (self));
#line 186 "executable-manager.vala"
	g_return_if_fail (cmd != NULL);
	inner_error = NULL;
	cmd2 = NULL;
	{
		GRegex* regex;
		char* _tmp0;
		regex = g_regex_new ("[ ]{2,}", G_REGEX_OPTIMIZE, G_REGEX_MATCH_NOTEMPTY, &inner_error);
		if (inner_error != NULL) {
			goto __catch13_g_error;
		}
		_tmp0 = NULL;
#line 194 "executable-manager.vala"
		cmd2 = (_tmp0 = g_regex_replace (regex, cmd, ((glong) -1), 0, " ", G_REGEX_MATCH_NOTEMPTY, &inner_error), (cmd2 = (g_free (cmd2), NULL)), _tmp0);
		if (inner_error != NULL) {
			goto __catch13_g_error;
		}
		(regex == NULL ? NULL : (regex = (g_regex_unref (regex), NULL)));
	}
	goto __finally13;
	__catch13_g_error:
	{
		GError * e;
		e = inner_error;
		inner_error = NULL;
		{
#line 198 "executable-manager.vala"
			g_warning (e->message);
		}
	}
	__finally13:
	;
#line 201 "executable-manager.vala"
	_tmp1 = NULL;
	args = (_tmp1 = g_strsplit (cmd2, " ", 0), args_length1 = -1, _tmp1);
	std_out = 0;
	std_err = 0;
	pid = 0;
#line 204 "executable-manager.vala"
	g_signal_emit_by_name (G_OBJECT (self), "cmd-start", cmd2);
#line 205 "executable-manager.vala"
	g_spawn_async_with_pipes (dir, args, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, &pid, NULL, &std_out, &std_err, &inner_error);
	if (inner_error != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
		g_clear_error (&inner_error);
	}
	cond = G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP | G_IO_NVAL;
#line 212 "executable-manager.vala"
	valide_utils_set_up_io_channel (std_out, cond, TRUE, _valide_executable_manager_build_iofunc_gio_func, self);
#line 213 "executable-manager.vala"
	valide_utils_set_up_io_channel (std_err, cond, TRUE, _valide_executable_manager_build_iofunc_gio_func, self);
#line 214 "executable-manager.vala"
	g_child_watch_add (pid, _valide_executable_manager_cmd_watch_gchild_watch_func, self);
	cmd2 = (g_free (cmd2), NULL);
	args = (_vala_array_free (args, args_length1, ((GDestroyNotify) g_free)), NULL);
}


#line 217 "executable-manager.vala"
void valide_executable_manager_add_line (ValideExecutableManager* self, const char* line) {
	GError * inner_error;
	GRegex* regex;
	char* line2;
#line 217 "executable-manager.vala"
	g_return_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (self));
#line 217 "executable-manager.vala"
	g_return_if_fail (line != NULL);
	inner_error = NULL;
	regex = g_regex_new ("[\n\r]*$", G_REGEX_OPTIMIZE, G_REGEX_MATCH_NOTEMPTY, &inner_error);
	if (inner_error != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
		g_clear_error (&inner_error);
	}
	line2 = g_regex_replace (regex, line, ((glong) -1), 0, "", G_REGEX_MATCH_NOTEMPTY, &inner_error);
	if (inner_error != NULL) {
		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
		g_clear_error (&inner_error);
	}
#line 225 "executable-manager.vala"
	if (g_utf8_strlen (line2, -1) > 0) {
		char** _tmp0;
		gint lines_length1;
		char** lines;
#line 227 "executable-manager.vala"
		_tmp0 = NULL;
		lines = (_tmp0 = g_strsplit (line2, "\n", 0), lines_length1 = -1, _tmp0);
		{
			char** l_collection;
			int l_it;
#line 229 "executable-manager.vala"
			l_collection = lines;
			for (l_it = 0; (lines_length1 != -1 && l_it < lines_length1) || (lines_length1 == -1 && l_collection[l_it] != NULL); l_it = l_it + 1) {
				const char* _tmp1;
				char* l;
				_tmp1 = NULL;
				l = (_tmp1 = l_collection[l_it], (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
				{
					GtkTreeIter iter = {0};
					GtkTreePath* path;
#line 233 "executable-manager.vala"
					g_signal_emit_by_name (G_OBJECT (self), "parsing", &l);
#line 235 "executable-manager.vala"
					gtk_list_store_append (self->priv->list_store, &iter);
#line 236 "executable-manager.vala"
					gtk_list_store_set (self->priv->list_store, &iter, 0, l, -1);
					path = gtk_tree_model_get_path (GTK_TREE_MODEL (self->priv->list_store), &iter);
#line 239 "executable-manager.vala"
					gtk_tree_view_scroll_to_cell (self->priv->tree_view, path, NULL, FALSE, ((float) 0), ((float) 0));
					l = (g_free (l), NULL);
					(path == NULL ? NULL : (path = (gtk_tree_path_free (path), NULL)));
				}
			}
		}
		lines = (_vala_array_free (lines, lines_length1, ((GDestroyNotify) g_free)), NULL);
	}
	(regex == NULL ? NULL : (regex = (g_regex_unref (regex), NULL)));
	line2 = (g_free (line2), NULL);
}


static char* valide_executable_manager_get_text (ValideExecutableManager* self) {
	char* str;
	GtkTreeIter iter = {0};
	g_return_val_if_fail (VALIDE_IS_EXECUTABLE_MANAGER (self), NULL);
	str = g_strdup ("");
#line 42 "executable-manager.vala"
	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (self->priv->list_store), &iter) == TRUE) {
		char* val;
		val = NULL;
#line 46 "executable-manager.vala"
		do {
			char* _tmp1;
			char* _tmp0;
#line 48 "executable-manager.vala"
			gtk_tree_model_get (GTK_TREE_MODEL (self->priv->list_store), &iter, 0, &val, -1, -1);
			_tmp1 = NULL;
			_tmp0 = NULL;
#line 49 "executable-manager.vala"
			str = (_tmp1 = g_strconcat (str, (_tmp0 = (g_strconcat (val, "\n", NULL))), NULL), (str = (g_free (str), NULL)), _tmp1);
			_tmp0 = (g_free (_tmp0), NULL);
		} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (self->priv->list_store), &iter));
		val = (g_free (val), NULL);
	}
#line 52 "executable-manager.vala"
	return str;
}


#line 61 "executable-manager.vala"
static void _valide_executable_manager_clear_gtk_button_clicked (GtkButton* sender, gpointer self) {
	valide_executable_manager_clear (self, sender);
}


#line 67 "executable-manager.vala"
static void _valide_executable_manager_copy_gtk_button_clicked (GtkButton* sender, gpointer self) {
	valide_executable_manager_copy (self, sender);
}


#line 83 "executable-manager.vala"
static void _valide_executable_manager_copy_bbcode_gtk_button_clicked (GtkButton* sender, gpointer self) {
	valide_executable_manager_copy_bbcode (self, sender);
}


static GObject * valide_executable_manager_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	ValideExecutableManagerClass * klass;
	GObjectClass * parent_class;
	ValideExecutableManager * self;
	klass = VALIDE_EXECUTABLE_MANAGER_CLASS (g_type_class_peek (VALIDE_TYPE_EXECUTABLE_MANAGER));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = VALIDE_EXECUTABLE_MANAGER (obj);
	{
		GtkVBox* vbox;
		GtkButton* button;
		GtkImage* _tmp0;
		GtkButton* _tmp1;
		GtkImage* _tmp2;
		GtkButton* _tmp3;
		GtkImage* _tmp5;
		char* _tmp4;
		GtkScrolledWindow* scrolled_window;
		GtkListStore* _tmp6;
		GtkTreeView* _tmp7;
		GtkCellRendererText* render;
		GtkTreeViewColumn* column;
		vbox = g_object_ref_sink (gtk_vbox_new (FALSE, 0));
#line 116 "executable-manager.vala"
		gtk_box_pack_start (GTK_BOX (self), GTK_WIDGET (vbox), FALSE, FALSE, ((guint) 0));
		button = g_object_ref_sink (gtk_button_new ());
#line 119 "executable-manager.vala"
		gtk_button_set_relief (button, GTK_RELIEF_NONE);
#line 120 "executable-manager.vala"
		_tmp0 = NULL;
#line 120 "executable-manager.vala"
		gtk_button_set_image (button, GTK_WIDGET ((_tmp0 = g_object_ref_sink (gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_SMALL_TOOLBAR)))));
		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
#line 121 "executable-manager.vala"
		g_signal_connect_object (button, "clicked", ((GCallback) _valide_executable_manager_clear_gtk_button_clicked), self, 0);
#line 122 "executable-manager.vala"
		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (button), FALSE, FALSE, ((guint) 0));
		_tmp1 = NULL;
#line 124 "executable-manager.vala"
		button = (_tmp1 = g_object_ref_sink (gtk_button_new ()), (button == NULL ? NULL : (button = (g_object_unref (button), NULL))), _tmp1);
#line 125 "executable-manager.vala"
		gtk_button_set_relief (button, GTK_RELIEF_NONE);
#line 126 "executable-manager.vala"
		_tmp2 = NULL;
#line 126 "executable-manager.vala"
		gtk_button_set_image (button, GTK_WIDGET ((_tmp2 = g_object_ref_sink (gtk_image_new_from_stock (GTK_STOCK_COPY, GTK_ICON_SIZE_SMALL_TOOLBAR)))));
		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
#line 127 "executable-manager.vala"
		g_signal_connect_object (button, "clicked", ((GCallback) _valide_executable_manager_copy_gtk_button_clicked), self, 0);
#line 128 "executable-manager.vala"
		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (button), FALSE, FALSE, ((guint) 0));
		_tmp3 = NULL;
#line 130 "executable-manager.vala"
		button = (_tmp3 = g_object_ref_sink (gtk_button_new ()), (button == NULL ? NULL : (button = (g_object_unref (button), NULL))), _tmp3);
#line 131 "executable-manager.vala"
		gtk_button_set_relief (button, GTK_RELIEF_NONE);
#line 132 "executable-manager.vala"
		_tmp5 = NULL;
#line 132 "executable-manager.vala"
		_tmp4 = NULL;
#line 132 "executable-manager.vala"
		gtk_button_set_image (button, GTK_WIDGET ((_tmp5 = g_object_ref_sink (gtk_image_new_from_file ((_tmp4 = g_build_filename (PACKAGE_PIXMAPS_DIR, "bbcode.png", NULL)))))));
		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
		_tmp4 = (g_free (_tmp4), NULL);
#line 133 "executable-manager.vala"
		g_signal_connect_object (button, "clicked", ((GCallback) _valide_executable_manager_copy_bbcode_gtk_button_clicked), self, 0);
#line 134 "executable-manager.vala"
		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (button), FALSE, FALSE, ((guint) 0));
#line 135 "executable-manager.vala"
		gtk_widget_set_sensitive (GTK_WIDGET (button), FALSE);
		scrolled_window = g_object_ref_sink (gtk_scrolled_window_new (NULL, NULL));
		_tmp6 = NULL;
#line 138 "executable-manager.vala"
		self->priv->list_store = (_tmp6 = gtk_list_store_new (1, G_TYPE_STRING, NULL), (self->priv->list_store == NULL ? NULL : (self->priv->list_store = (g_object_unref (self->priv->list_store), NULL))), _tmp6);
		_tmp7 = NULL;
#line 139 "executable-manager.vala"
		self->priv->tree_view = (_tmp7 = g_object_ref_sink (gtk_tree_view_new_with_model (GTK_TREE_MODEL (self->priv->list_store))), (self->priv->tree_view == NULL ? NULL : (self->priv->tree_view = (g_object_unref (self->priv->tree_view), NULL))), _tmp7);
		render = g_object_ref_sink (gtk_cell_renderer_text_new ());
		column = g_object_ref_sink (gtk_tree_view_column_new_with_attributes ("Message", GTK_CELL_RENDERER (render), "markup", 0, NULL, NULL));
#line 142 "executable-manager.vala"
		gtk_tree_view_append_column (self->priv->tree_view, column);
#line 143 "executable-manager.vala"
		gtk_tree_view_set_headers_visible (self->priv->tree_view, FALSE);
#line 145 "executable-manager.vala"
		gtk_scrolled_window_set_policy (scrolled_window, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
#line 146 "executable-manager.vala"
		gtk_container_add (GTK_CONTAINER (scrolled_window), GTK_WIDGET (self->priv->tree_view));
#line 147 "executable-manager.vala"
		gtk_box_pack_start (GTK_BOX (self), GTK_WIDGET (scrolled_window), TRUE, TRUE, ((guint) 0));
		(vbox == NULL ? NULL : (vbox = (g_object_unref (vbox), NULL)));
		(button == NULL ? NULL : (button = (g_object_unref (button), NULL)));
		(scrolled_window == NULL ? NULL : (scrolled_window = (g_object_unref (scrolled_window), NULL)));
		(render == NULL ? NULL : (render = (g_object_unref (render), NULL)));
		(column == NULL ? NULL : (column = (g_object_unref (column), NULL)));
	}
	return obj;
}


static void valide_executable_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValideExecutableManager * self;
	self = VALIDE_EXECUTABLE_MANAGER (object);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_executable_manager_class_init (ValideExecutableManagerClass * klass) {
	valide_executable_manager_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideExecutableManagerPrivate));
	G_OBJECT_CLASS (klass)->get_property = valide_executable_manager_get_property;
	G_OBJECT_CLASS (klass)->constructor = valide_executable_manager_constructor;
	G_OBJECT_CLASS (klass)->dispose = valide_executable_manager_dispose;
	g_signal_new ("cmd_start", VALIDE_TYPE_EXECUTABLE_MANAGER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	g_signal_new ("cmd_end", VALIDE_TYPE_EXECUTABLE_MANAGER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
	g_signal_new ("parsing", VALIDE_TYPE_EXECUTABLE_MANAGER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE, 1, G_TYPE_POINTER);
}


static void valide_executable_manager_init (ValideExecutableManager * self) {
	self->priv = VALIDE_EXECUTABLE_MANAGER_GET_PRIVATE (self);
}


static void valide_executable_manager_dispose (GObject * obj) {
	ValideExecutableManager * self;
	self = VALIDE_EXECUTABLE_MANAGER (obj);
	(self->priv->list_store == NULL ? NULL : (self->priv->list_store = (g_object_unref (self->priv->list_store), NULL)));
	(self->priv->tree_view == NULL ? NULL : (self->priv->tree_view = (g_object_unref (self->priv->tree_view), NULL)));
	G_OBJECT_CLASS (valide_executable_manager_parent_class)->dispose (obj);
}


GType valide_executable_manager_get_type (void) {
	static GType valide_executable_manager_type_id = 0;
	if (G_UNLIKELY (valide_executable_manager_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideExecutableManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_executable_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideExecutableManager), 0, (GInstanceInitFunc) valide_executable_manager_init };
		valide_executable_manager_type_id = g_type_register_static (GTK_TYPE_HBOX, "ValideExecutableManager", &g_define_type_info, 0);
	}
	return valide_executable_manager_type_id;
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if (array != NULL && destroy_func != NULL) {
		int i;
		if (array_length >= 0)
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL)
			destroy_func (((gpointer*) array)[i]);
		}
		else
		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
			destroy_func (((gpointer*) array)[i]);
		}
	}
	g_free (array);
}


static int _vala_strcmp0 (const char * str1, const char * str2) {
	if (str1 == NULL) {
		return -(str1 != str2);
	}
	if (str2 == NULL) {
		return (str1 != str2);
	}
	return strcmp (str1, str2);
}




