/* panel.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/third-party/panel.h>
#include <gdk/gdk.h>
#include <gdk-pixbuf/gdk-pixdata.h>
#include <float.h>
#include <math.h>
#include <pango/pango.h>


#define VALIDE_TYPE_PANEL_ITEM (valide_panel_item_get_type ())
#define VALIDE_PANEL_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALIDE_TYPE_PANEL_ITEM, ValidePanelItem))
#define VALIDE_PANEL_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALIDE_TYPE_PANEL_ITEM, ValidePanelItemClass))
#define VALIDE_IS_PANEL_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALIDE_TYPE_PANEL_ITEM))
#define VALIDE_IS_PANEL_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALIDE_TYPE_PANEL_ITEM))
#define VALIDE_PANEL_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALIDE_TYPE_PANEL_ITEM, ValidePanelItemClass))

typedef struct _ValidePanelItem ValidePanelItem;
typedef struct _ValidePanelItemClass ValidePanelItemClass;
typedef struct _ValidePanelItemPrivate ValidePanelItemPrivate;

struct _ValidePanelItem {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ValidePanelItemPrivate * priv;
	char* name;
	GtkImage* icon;
};

struct _ValidePanelItemClass {
	GTypeClass parent_class;
	void (*finalize) (ValidePanelItem *self);
};



enum  {
	VALIDE_PANEL_ITEM_DUMMY_PROPERTY
};
static ValidePanelItem* valide_panel_item_new (GType type);
static gpointer valide_panel_item_parent_class = NULL;
static GType valide_panel_item_get_type (void);
static gpointer valide_panel_item_ref (gpointer instance);
static void valide_panel_item_unref (gpointer instance);
struct _ValidePanelPrivate {
	GtkOrientation orientation_;
	GtkNotebook* notebook;
	GtkImage* title_image;
	GtkLabel* title_label;
};

#define VALIDE_PANEL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_PANEL, ValidePanelPrivate))
enum  {
	VALIDE_PANEL_DUMMY_PROPERTY,
	VALIDE_PANEL_ORIENTATION
};
static void valide_panel_panel_show (ValidePanel* self);
static void valide_panel_notebook_page_changed (ValidePanel* self, GtkNotebook* sender, GtkNotebookPage* page, gint page_num);
static void valide_panel_button_style_set_cb (ValidePanel* self, GtkButton* sender);
static void valide_panel_close_button_clicked_cb (ValidePanel* self);
static void valide_panel_set_gtk_image_from_gtk_image (ValidePanel* self, GtkImage* image, GtkImage* source);
static void valide_panel_sync_title (ValidePanel* self, ValidePanelItem* item);
static void _valide_panel_notebook_page_changed_gtk_notebook_switch_page (GtkNotebook* sender, void* page, guint page_num, gpointer self);
static void valide_panel_build_notebook (ValidePanel* self);
static void _valide_panel_close_button_clicked_cb_gtk_button_clicked (GtkButton* sender, gpointer self);
static void valide_panel_build_horizontal_panel (ValidePanel* self);
static void valide_panel_build_vertical_panel (ValidePanel* self);
static void _valide_panel_button_style_set_cb_gtk_widget_style_set (GtkWidget* sender, GtkStyle* previous_style, gpointer self);
static GtkButton* valide_panel_create_small_button (ValidePanel* self, GtkImage* image);
static GtkWidget* valide_panel_build_tab_label (ValidePanel* self, GtkWidget* item, const char* name, GtkImage* icon);
static void _valide_panel_panel_show_gtk_widget_show (GtkWidget* sender, gpointer self);
static GObject * valide_panel_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer valide_panel_parent_class = NULL;
static void valide_panel_dispose (GObject * obj);

static const char* VALIDE_PANEL_ITEM_KEY = "ValidePanelItemKey";


#line 25 "panel.vala"
static ValidePanelItem* valide_panel_item_new (GType type) {
	ValidePanelItem* self;
	self = ((ValidePanelItem*) g_type_create_instance (type));
	return self;
}


static void valide_panel_item_class_init (ValidePanelItemClass * klass) {
	valide_panel_item_parent_class = g_type_class_peek_parent (klass);
}


static void valide_panel_item_init (ValidePanelItem * self) {
	self->ref_count = 1;
}


static GType valide_panel_item_get_type (void) {
	static GType valide_panel_item_type_id = 0;
	if (G_UNLIKELY (valide_panel_item_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValidePanelItemClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_panel_item_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValidePanelItem), 0, (GInstanceInitFunc) valide_panel_item_init };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		valide_panel_item_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValidePanelItem", &g_define_type_info, &g_define_type_fundamental_info, 0);
	}
	return valide_panel_item_type_id;
}


static gpointer valide_panel_item_ref (gpointer instance) {
	ValidePanelItem* self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}


static void valide_panel_item_unref (gpointer instance) {
	ValidePanelItem* self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		g_type_free_instance (((GTypeInstance *) self));
	}
}


#line 65 "panel.vala"
static void valide_panel_panel_show (ValidePanel* self) {
	gint page;
#line 65 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
	page = gtk_notebook_get_current_page (self->priv->notebook);
#line 69 "panel.vala"
	if (page != -1) {
	}
}


/*      this.notebook_page_changed (this.notebook, null, page);*/
#line 76 "panel.vala"
static void valide_panel_notebook_page_changed (ValidePanel* self, GtkNotebook* sender, GtkNotebookPage* page, gint page_num) {
	GtkWidget* _tmp0;
	GtkWidget* item;
	ValidePanelItem* data;
#line 76 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
#line 76 "panel.vala"
	g_return_if_fail (GTK_IS_NOTEBOOK (sender));
#line 80 "panel.vala"
	_tmp0 = NULL;
	item = (_tmp0 = gtk_notebook_get_nth_page (sender, page_num), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
#line 81 "panel.vala"
	g_return_if_fail (item != NULL);
	data = VALIDE_PANEL_ITEM (g_object_get_data (G_OBJECT (item), VALIDE_PANEL_ITEM_KEY));
#line 84 "panel.vala"
	g_return_if_fail (data != NULL);
#line 86 "panel.vala"
	valide_panel_sync_title (self, data);
	(item == NULL ? NULL : (item = (g_object_unref (item), NULL)));
}


#line 90 "panel.vala"
static void valide_panel_button_style_set_cb (ValidePanel* self, GtkButton* sender) {
	gint h;
	gint w;
#line 90 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
#line 90 "panel.vala"
	g_return_if_fail (GTK_IS_BUTTON (sender));
	h = 0;
	w = 0;
#line 94 "panel.vala"
	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (GTK_WIDGET (sender)), GTK_ICON_SIZE_MENU, &w, &h);
#line 96 "panel.vala"
	gtk_widget_set_size_request (GTK_WIDGET (sender), w + 2, h + 2);
}


#line 100 "panel.vala"
static void valide_panel_close_button_clicked_cb (ValidePanel* self) {
#line 100 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
#line 102 "panel.vala"
	gtk_widget_hide (GTK_WIDGET (self));
}


/* This is ugly, since it supports only known
   * storage types of GtkImage, otherwise fall back
   * to the empty icon.
   * See http://bugzilla.gnome.org/show_bug.cgi?id=317520.
   */
#line 110 "panel.vala"
static void valide_panel_set_gtk_image_from_gtk_image (ValidePanel* self, GtkImage* image, GtkImage* source) {
	GtkImageType _tmp4;
#line 110 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
#line 110 "panel.vala"
	g_return_if_fail (GTK_IS_IMAGE (image));
#line 110 "panel.vala"
	g_return_if_fail (GTK_IS_IMAGE (source));
	_tmp4 = gtk_image_get_storage_type (source);
	if (_tmp4 == GTK_IMAGE_EMPTY)
	do {
#line 115 "panel.vala"
		gtk_image_clear (image);
#line 116 "panel.vala"
		break;
	} while (0); else if (_tmp4 == GTK_IMAGE_PIXMAP)
	do {
		{
			GdkPixmap* pm;
			GdkBitmap* bm;
			pm = NULL;
			bm = NULL;
#line 122 "panel.vala"
			gtk_image_get_pixmap (source, &pm, &bm);
#line 123 "panel.vala"
			gtk_image_set_from_pixmap (image, pm, bm);
			(pm == NULL ? NULL : (pm = (g_object_unref (pm), NULL)));
			(bm == NULL ? NULL : (bm = (gdk_bitmap_unref (bm), NULL)));
		}
#line 125 "panel.vala"
		break;
	} while (0); else if (_tmp4 == GTK_IMAGE_IMAGE)
	do {
		{
			GdkImage* i;
			GdkBitmap* bm;
			i = NULL;
			bm = NULL;
#line 131 "panel.vala"
			gtk_image_get_image (source, &i, &bm);
#line 132 "panel.vala"
			gtk_image_set_from_image (image, i, bm);
			(i == NULL ? NULL : (i = (g_object_unref (i), NULL)));
			(bm == NULL ? NULL : (bm = (gdk_bitmap_unref (bm), NULL)));
		}
#line 134 "panel.vala"
		break;
	} while (0); else if (_tmp4 == GTK_IMAGE_PIXBUF)
	do {
		{
			GdkPixbuf* pb;
			GdkPixbuf* _tmp1;
			GdkPixbuf* _tmp0;
			pb = NULL;
			_tmp1 = NULL;
#line 139 "panel.vala"
			_tmp0 = NULL;
#line 139 "panel.vala"
			pb = (_tmp1 = (_tmp0 = gtk_image_get_pixbuf (source), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (pb == NULL ? NULL : (pb = (g_object_unref (pb), NULL))), _tmp1);
#line 140 "panel.vala"
			gtk_image_set_from_pixbuf (image, pb);
			(pb == NULL ? NULL : (pb = (g_object_unref (pb), NULL)));
		}
#line 142 "panel.vala"
		break;
	} while (0); else if (_tmp4 == GTK_IMAGE_STOCK)
	do {
		{
			char* s_id;
			GtkIconSize s;
			s_id = NULL;
			s = 0;
#line 148 "panel.vala"
			gtk_image_get_stock (source, &s_id, &s);
#line 149 "panel.vala"
			gtk_image_set_from_stock (image, s_id, s);
			s_id = (g_free (s_id), NULL);
		}
#line 151 "panel.vala"
		break;
	} while (0); else if (_tmp4 == GTK_IMAGE_ICON_SET)
	do {
		{
			GtkIconSet* i;
			GtkIconSize s;
			i = NULL;
			s = 0;
#line 157 "panel.vala"
			gtk_image_get_icon_set (source, &i, &s);
#line 158 "panel.vala"
			gtk_image_set_from_icon_set (image, i, s);
			(i == NULL ? NULL : (i = (gtk_icon_set_unref (i), NULL)));
		}
#line 160 "panel.vala"
		break;
	} while (0); else if (_tmp4 == GTK_IMAGE_ANIMATION)
	do {
		{
			GdkPixbufAnimation* a;
			GdkPixbufAnimation* _tmp3;
			GdkPixbufAnimation* _tmp2;
			a = NULL;
			_tmp3 = NULL;
#line 165 "panel.vala"
			_tmp2 = NULL;
#line 165 "panel.vala"
			a = (_tmp3 = (_tmp2 = gtk_image_get_animation (source), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (a == NULL ? NULL : (a = (g_object_unref (a), NULL))), _tmp3);
#line 166 "panel.vala"
			gtk_image_set_from_animation (image, a);
			(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
		}
#line 168 "panel.vala"
		break;
	} while (0); else if (_tmp4 == GTK_IMAGE_ICON_NAME)
	do {
		{
			char* n;
			GtkIconSize s;
			n = NULL;
			s = 0;
#line 174 "panel.vala"
			gtk_image_get_icon_name (source, &n, &s);
#line 175 "panel.vala"
			gtk_image_set_from_icon_name (image, n, s);
			n = (g_free (n), NULL);
		}
#line 177 "panel.vala"
		break;
	} while (0); else
	do {
#line 179 "panel.vala"
		gtk_image_set_from_stock (image, GTK_STOCK_FILE, GTK_ICON_SIZE_MENU);
#line 180 "panel.vala"
		break;
	} while (0);
}


#line 184 "panel.vala"
static void valide_panel_sync_title (ValidePanel* self, ValidePanelItem* item) {
#line 184 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
#line 186 "panel.vala"
	if (valide_panel_get_orientation (self) == GTK_ORIENTATION_HORIZONTAL && self->priv->title_label != NULL) {
#line 189 "panel.vala"
		if (item == NULL) {
#line 191 "panel.vala"
			gtk_label_set_text (self->priv->title_label, item->name);
#line 192 "panel.vala"
			valide_panel_set_gtk_image_from_gtk_image (self, self->priv->title_image, item->icon);
		} else {
#line 196 "panel.vala"
			gtk_label_set_text (self->priv->title_label, "Empty");
#line 197 "panel.vala"
			gtk_image_set_from_stock (self->priv->title_image, GTK_STOCK_FILE, GTK_ICON_SIZE_MENU);
		}
	}
}


#line 76 "panel.vala"
static void _valide_panel_notebook_page_changed_gtk_notebook_switch_page (GtkNotebook* sender, void* page, guint page_num, gpointer self) {
	valide_panel_notebook_page_changed (self, sender, page, page_num);
}


#line 202 "panel.vala"
static void valide_panel_build_notebook (ValidePanel* self) {
	GtkNotebook* _tmp0;
#line 202 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
	/* Create the panel notebook */
	_tmp0 = NULL;
#line 205 "panel.vala"
	self->priv->notebook = (_tmp0 = g_object_ref_sink (gtk_notebook_new ()), (self->priv->notebook == NULL ? NULL : (self->priv->notebook = (g_object_unref (self->priv->notebook), NULL))), _tmp0);
#line 207 "panel.vala"
	gtk_notebook_set_tab_pos (self->priv->notebook, GTK_POS_BOTTOM);
#line 208 "panel.vala"
	gtk_notebook_set_scrollable (self->priv->notebook, TRUE);
#line 209 "panel.vala"
	gtk_notebook_popup_enable (self->priv->notebook);
#line 210 "panel.vala"
	gtk_widget_show (GTK_WIDGET (self->priv->notebook));
#line 211 "panel.vala"
	g_signal_connect_object (self->priv->notebook, "switch-page", ((GCallback) _valide_panel_notebook_page_changed_gtk_notebook_switch_page), self, 0);
}


#line 100 "panel.vala"
static void _valide_panel_close_button_clicked_cb_gtk_button_clicked (GtkButton* sender, gpointer self) {
	valide_panel_close_button_clicked_cb (self);
}


#line 214 "panel.vala"
static void valide_panel_build_horizontal_panel (ValidePanel* self) {
	GtkLabel* _tmp0;
	GtkImage* _tmp1;
	GtkHBox* box;
	GtkVBox* sidebar;
	GtkImage* image;
	GtkButton* close_button;
#line 214 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
	/* Unused widget */
	_tmp0 = NULL;
#line 217 "panel.vala"
	self->priv->title_label = (_tmp0 = g_object_ref_sink (gtk_label_new ("Empty")), (self->priv->title_label == NULL ? NULL : (self->priv->title_label = (g_object_unref (self->priv->title_label), NULL))), _tmp0);
	_tmp1 = NULL;
#line 218 "panel.vala"
	self->priv->title_image = (_tmp1 = g_object_ref_sink (gtk_image_new ()), (self->priv->title_image == NULL ? NULL : (self->priv->title_image = (g_object_unref (self->priv->title_image), NULL))), _tmp1);
	box = g_object_ref_sink (gtk_hbox_new (FALSE, 0));
#line 221 "panel.vala"
	gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (self->priv->notebook), TRUE, TRUE, ((guint) 0));
	/* Toolbar, close button and first separator */
	sidebar = g_object_ref_sink (gtk_vbox_new (FALSE, 6));
#line 225 "panel.vala"
	gtk_container_set_border_width (GTK_CONTAINER (sidebar), ((guint) 4));
#line 227 "panel.vala"
	gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (sidebar), FALSE, FALSE, ((guint) 0));
	image = g_object_ref_sink (gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU));
	close_button = valide_panel_create_small_button (self, image);
#line 231 "panel.vala"
	gtk_box_pack_start (GTK_BOX (sidebar), GTK_WIDGET (close_button), FALSE, FALSE, ((guint) 0));
#line 232 "panel.vala"
	gtk_widget_set_tooltip_text (GTK_WIDGET (close_button), "Hide panel");
#line 233 "panel.vala"
	g_signal_connect_object (close_button, "clicked", ((GCallback) _valide_panel_close_button_clicked_cb_gtk_button_clicked), self, 0);
#line 235 "panel.vala"
	gtk_widget_show_all (GTK_WIDGET (box));
#line 237 "panel.vala"
	gtk_box_pack_start (GTK_BOX (self), GTK_WIDGET (box), TRUE, TRUE, ((guint) 0));
	(box == NULL ? NULL : (box = (g_object_unref (box), NULL)));
	(sidebar == NULL ? NULL : (sidebar = (g_object_unref (sidebar), NULL)));
	(image == NULL ? NULL : (image = (g_object_unref (image), NULL)));
	(close_button == NULL ? NULL : (close_button = (g_object_unref (close_button), NULL)));
}


#line 240 "panel.vala"
static void valide_panel_build_vertical_panel (ValidePanel* self) {
	GtkHBox* title_hbox;
	GtkHBox* icon_name_hbox;
	GtkImage* _tmp0;
	GtkLabel* dummy_label;
	GtkLabel* _tmp1;
	GtkImage* image;
	GtkButton* close_button;
#line 240 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
	/* Create title hbox */
	title_hbox = g_object_ref_sink (gtk_hbox_new (FALSE, 6));
#line 244 "panel.vala"
	gtk_container_set_border_width (GTK_CONTAINER (title_hbox), ((guint) 5));
#line 245 "panel.vala"
	gtk_box_pack_start (GTK_BOX (self), GTK_WIDGET (title_hbox), FALSE, FALSE, ((guint) 0));
	icon_name_hbox = g_object_ref_sink (gtk_hbox_new (FALSE, 0));
#line 248 "panel.vala"
	gtk_box_pack_start (GTK_BOX (title_hbox), GTK_WIDGET (icon_name_hbox), TRUE, TRUE, ((guint) 0));
	_tmp0 = NULL;
#line 250 "panel.vala"
	self->priv->title_image = (_tmp0 = g_object_ref_sink (gtk_image_new_from_stock (GTK_STOCK_FILE, GTK_ICON_SIZE_MENU)), (self->priv->title_image == NULL ? NULL : (self->priv->title_image = (g_object_unref (self->priv->title_image), NULL))), _tmp0);
#line 251 "panel.vala"
	gtk_box_pack_start (GTK_BOX (icon_name_hbox), GTK_WIDGET (self->priv->title_image), FALSE, TRUE, ((guint) 0));
	dummy_label = g_object_ref_sink (gtk_label_new (" "));
#line 254 "panel.vala"
	gtk_box_pack_start (GTK_BOX (icon_name_hbox), GTK_WIDGET (dummy_label), FALSE, FALSE, ((guint) 0));
	_tmp1 = NULL;
#line 256 "panel.vala"
	self->priv->title_label = (_tmp1 = g_object_ref_sink (gtk_label_new ("Empty")), (self->priv->title_label == NULL ? NULL : (self->priv->title_label = (g_object_unref (self->priv->title_label), NULL))), _tmp1);
#line 257 "panel.vala"
	gtk_misc_set_alignment (GTK_MISC (self->priv->title_label), ((float) 0), ((float) 0.5));
#line 258 "panel.vala"
	gtk_label_set_ellipsize (self->priv->title_label, PANGO_ELLIPSIZE_END);
#line 259 "panel.vala"
	gtk_box_pack_start (GTK_BOX (icon_name_hbox), GTK_WIDGET (self->priv->title_label), TRUE, TRUE, ((guint) 0));
	image = g_object_ref_sink (gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU));
	close_button = valide_panel_create_small_button (self, image);
#line 263 "panel.vala"
	gtk_widget_set_tooltip_text (GTK_WIDGET (close_button), "Hide panel");
#line 264 "panel.vala"
	g_signal_connect_object (close_button, "clicked", ((GCallback) _valide_panel_close_button_clicked_cb_gtk_button_clicked), self, 0);
#line 265 "panel.vala"
	gtk_box_pack_start (GTK_BOX (title_hbox), GTK_WIDGET (close_button), FALSE, FALSE, ((guint) 0));
#line 267 "panel.vala"
	gtk_widget_show_all (GTK_WIDGET (title_hbox));
#line 269 "panel.vala"
	gtk_box_pack_start (GTK_BOX (self), GTK_WIDGET (self->priv->notebook), TRUE, TRUE, ((guint) 0));
	(title_hbox == NULL ? NULL : (title_hbox = (g_object_unref (title_hbox), NULL)));
	(icon_name_hbox == NULL ? NULL : (icon_name_hbox = (g_object_unref (icon_name_hbox), NULL)));
	(dummy_label == NULL ? NULL : (dummy_label = (g_object_unref (dummy_label), NULL)));
	(image == NULL ? NULL : (image = (g_object_unref (image), NULL)));
	(close_button == NULL ? NULL : (close_button = (g_object_unref (close_button), NULL)));
}


#line 90 "panel.vala"
static void _valide_panel_button_style_set_cb_gtk_widget_style_set (GtkWidget* sender, GtkStyle* previous_style, gpointer self) {
	valide_panel_button_style_set_cb (self, sender);
}


#line 272 "panel.vala"
static GtkButton* valide_panel_create_small_button (ValidePanel* self, GtkImage* image) {
	GtkButton* button;
	GtkRcStyle* rcstyle;
	GtkButton* _tmp0;
#line 272 "panel.vala"
	g_return_val_if_fail (VALIDE_IS_PANEL (self), NULL);
#line 272 "panel.vala"
	g_return_val_if_fail (GTK_IS_IMAGE (image), NULL);
	button = g_object_ref_sink (gtk_button_new ());
#line 275 "panel.vala"
	gtk_button_set_relief (button, GTK_RELIEF_NONE);
	/* don't allow focus on the close button */
#line 278 "panel.vala"
	gtk_button_set_focus_on_click (button, FALSE);
	/* make it as small as possible */
	rcstyle = gtk_rc_style_new ();
#line 282 "panel.vala"
	rcstyle->xthickness = rcstyle->ythickness = 0;
#line 283 "panel.vala"
	gtk_widget_modify_style (GTK_WIDGET (button), rcstyle);
#line 285 "panel.vala"
	gtk_widget_show (GTK_WIDGET (image));
#line 287 "panel.vala"
	gtk_container_add (GTK_CONTAINER (button), GTK_WIDGET (image));
	/* Set minimal size */
#line 290 "panel.vala"
	g_signal_connect_object (button, "style-set", ((GCallback) _valide_panel_button_style_set_cb_gtk_widget_style_set), self, 0);
#line 292 "panel.vala"
	_tmp0 = NULL;
#line 292 "panel.vala"
	return (_tmp0 = button, (rcstyle == NULL ? NULL : (rcstyle = (g_object_unref (rcstyle), NULL))), _tmp0);
}


#line 295 "panel.vala"
static GtkWidget* valide_panel_build_tab_label (ValidePanel* self, GtkWidget* item, const char* name, GtkImage* icon) {
	GtkHBox* hbox;
	GtkEventBox* label_ebox;
	GtkHBox* label_hbox;
	GtkLabel* label;
	GtkHBox* _tmp0;
#line 295 "panel.vala"
	g_return_val_if_fail (VALIDE_IS_PANEL (self), NULL);
#line 295 "panel.vala"
	g_return_val_if_fail (GTK_IS_WIDGET (item), NULL);
#line 295 "panel.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 295 "panel.vala"
	g_return_val_if_fail (GTK_IS_IMAGE (icon), NULL);
	/* set hbox spacing and label padding (see below) so that there's an
	     * equal amount of space around the label */
	hbox = g_object_ref_sink (gtk_hbox_new (FALSE, 4));
	label_ebox = g_object_ref_sink (gtk_event_box_new ());
#line 303 "panel.vala"
	gtk_event_box_set_visible_window (label_ebox, FALSE);
#line 304 "panel.vala"
	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label_ebox), TRUE, TRUE, ((guint) 0));
	label_hbox = g_object_ref_sink (gtk_hbox_new (FALSE, 4));
#line 307 "panel.vala"
	gtk_container_add (GTK_CONTAINER (label_ebox), GTK_WIDGET (label_hbox));
	/* setup icon */
#line 310 "panel.vala"
	gtk_box_pack_start (GTK_BOX (label_hbox), GTK_WIDGET (icon), FALSE, FALSE, ((guint) 0));
	/* setup label */
	label = g_object_ref_sink (gtk_label_new (name));
#line 314 "panel.vala"
	gtk_misc_set_alignment (GTK_MISC (label), ((float) 0.0), ((float) 0.5));
#line 315 "panel.vala"
	gtk_misc_set_padding (GTK_MISC (label), 0, 0);
#line 316 "panel.vala"
	gtk_box_pack_start (GTK_BOX (label_hbox), GTK_WIDGET (label), TRUE, TRUE, ((guint) 0));
#line 318 "panel.vala"
	gtk_widget_set_tooltip_text (GTK_WIDGET (label_ebox), name);
#line 320 "panel.vala"
	gtk_widget_show_all (GTK_WIDGET (hbox));
#line 322 "panel.vala"
	if (valide_panel_get_orientation (self) == GTK_ORIENTATION_VERTICAL) {
#line 324 "panel.vala"
		gtk_widget_hide (GTK_WIDGET (label));
	}
#line 326 "panel.vala"
	g_object_set_data (G_OBJECT (item), "label", label);
#line 327 "panel.vala"
	g_object_set_data (G_OBJECT (item), "hbox", hbox);
#line 328 "panel.vala"
	g_object_set_data (G_OBJECT (item), "label-ebox", label_ebox);
#line 329 "panel.vala"
	_tmp0 = NULL;
#line 329 "panel.vala"
	return GTK_WIDGET ((_tmp0 = hbox, (label_ebox == NULL ? NULL : (label_ebox = (g_object_unref (label_ebox), NULL))), (label_hbox == NULL ? NULL : (label_hbox = (g_object_unref (label_hbox), NULL))), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp0));
}


#line 332 "panel.vala"
ValidePanel* valide_panel_new (GtkOrientation orientation) {
	ValidePanel * self;
	self = g_object_newv (VALIDE_TYPE_PANEL, 0, NULL);
#line 334 "panel.vala"
	valide_panel_set_orientation (self, orientation);
	return self;
}


#line 343 "panel.vala"
void valide_panel_add_item (ValidePanel* self, GtkWidget* item, const char* name, GtkImage* image) {
	ValidePanelItem* data;
	char* _tmp1;
	const char* _tmp0;
	gint w;
	gint h;
	GtkWidget* tab_label;
	GtkLabel* menu_label;
	gboolean _tmp5;
#line 343 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
#line 343 "panel.vala"
	g_return_if_fail (GTK_IS_WIDGET (item));
#line 343 "panel.vala"
	g_return_if_fail (name != NULL);
#line 343 "panel.vala"
	g_return_if_fail (image == NULL || GTK_IS_IMAGE (image));
	data = valide_panel_item_new (VALIDE_TYPE_PANEL_ITEM);
	_tmp1 = NULL;
#line 346 "panel.vala"
	_tmp0 = NULL;
#line 346 "panel.vala"
	data->name = (_tmp1 = (_tmp0 = name, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (data->name = (g_free (data->name), NULL)), _tmp1);
#line 348 "panel.vala"
	if (image == NULL) {
		GtkImage* _tmp2;
		/* default to empty */
		_tmp2 = NULL;
#line 351 "panel.vala"
		data->icon = (_tmp2 = g_object_ref_sink (gtk_image_new_from_stock (GTK_STOCK_FILE, GTK_ICON_SIZE_MENU)), (data->icon == NULL ? NULL : (data->icon = (g_object_unref (data->icon), NULL))), _tmp2);
	} else {
		GtkImage* _tmp4;
		GtkImage* _tmp3;
		_tmp4 = NULL;
#line 355 "panel.vala"
		_tmp3 = NULL;
#line 355 "panel.vala"
		data->icon = (_tmp4 = (_tmp3 = image, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3))), (data->icon == NULL ? NULL : (data->icon = (g_object_unref (data->icon), NULL))), _tmp4);
	}
	w = 0;
	h = 0;
#line 359 "panel.vala"
	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
#line 360 "panel.vala"
	gtk_widget_set_size_request (GTK_WIDGET (data->icon), w, h);
#line 362 "panel.vala"
	g_object_set_data (G_OBJECT (item), VALIDE_PANEL_ITEM_KEY, data);
	tab_label = valide_panel_build_tab_label (self, item, data->name, data->icon);
	menu_label = g_object_ref_sink (gtk_label_new (name));
#line 367 "panel.vala"
	gtk_misc_set_alignment (GTK_MISC (menu_label), ((float) 0.0), ((float) 0.5));
#line 369 "panel.vala"
	if (!(g_object_get (G_OBJECT (item), "visible", &_tmp5, NULL), _tmp5)) {
#line 371 "panel.vala"
		gtk_widget_show (item);
	}
#line 374 "panel.vala"
	gtk_notebook_append_page_menu (self->priv->notebook, item, tab_label, GTK_WIDGET (menu_label));
#line 375 "panel.vala"
	g_signal_emit_by_name (G_OBJECT (self), "item-added", item);
#line 376 "panel.vala"
	gtk_label_set_text (self->priv->title_label, name);
	(data == NULL ? NULL : (data = (valide_panel_item_unref (data), NULL)));
	(tab_label == NULL ? NULL : (tab_label = (g_object_unref (tab_label), NULL)));
	(menu_label == NULL ? NULL : (menu_label = (g_object_unref (menu_label), NULL)));
}


#line 379 "panel.vala"
void valide_panel_add_item_with_stock_icon (ValidePanel* self, GtkWidget* item, const char* name, const char* stock_id) {
	GtkImage* icon;
#line 379 "panel.vala"
	g_return_if_fail (VALIDE_IS_PANEL (self));
#line 379 "panel.vala"
	g_return_if_fail (GTK_IS_WIDGET (item));
#line 379 "panel.vala"
	g_return_if_fail (name != NULL);
	icon = NULL;
#line 384 "panel.vala"
	if (stock_id != NULL) {
		GtkImage* _tmp0;
		_tmp0 = NULL;
#line 386 "panel.vala"
		icon = (_tmp0 = g_object_ref_sink (gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_MENU)), (icon == NULL ? NULL : (icon = (g_object_unref (icon), NULL))), _tmp0);
	}
#line 388 "panel.vala"
	valide_panel_add_item (self, item, name, icon);
	(icon == NULL ? NULL : (icon = (g_object_unref (icon), NULL)));
}


GtkOrientation valide_panel_get_orientation (ValidePanel* self) {
	g_return_val_if_fail (VALIDE_IS_PANEL (self), 0);
#line 48 "panel.vala"
	return self->priv->orientation_;
}


void valide_panel_set_orientation (ValidePanel* self, GtkOrientation value) {
	g_return_if_fail (VALIDE_IS_PANEL (self));
#line 52 "panel.vala"
	self->priv->orientation_ = value;
#line 53 "panel.vala"
	if (valide_panel_get_orientation (self) == GTK_ORIENTATION_HORIZONTAL) {
#line 55 "panel.vala"
		valide_panel_build_horizontal_panel (self);
	} else {
#line 59 "panel.vala"
		valide_panel_build_vertical_panel (self);
	}
}


#line 65 "panel.vala"
static void _valide_panel_panel_show_gtk_widget_show (GtkWidget* sender, gpointer self) {
	valide_panel_panel_show (self);
}


static GObject * valide_panel_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	ValidePanelClass * klass;
	GObjectClass * parent_class;
	ValidePanel * self;
	klass = VALIDE_PANEL_CLASS (g_type_class_peek (VALIDE_TYPE_PANEL));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = VALIDE_PANEL (obj);
	{
#line 339 "panel.vala"
		valide_panel_build_notebook (self);
#line 340 "panel.vala"
		g_signal_connect_object (self, "show", ((GCallback) _valide_panel_panel_show_gtk_widget_show), self, 0);
	}
	return obj;
}


static void valide_panel_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValidePanel * self;
	self = VALIDE_PANEL (object);
	switch (property_id) {
		case VALIDE_PANEL_ORIENTATION:
		g_value_set_uint (value, valide_panel_get_orientation (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_panel_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValidePanel * self;
	self = VALIDE_PANEL (object);
	switch (property_id) {
		case VALIDE_PANEL_ORIENTATION:
		valide_panel_set_orientation (self, g_value_get_int (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void valide_panel_class_init (ValidePanelClass * klass) {
	valide_panel_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValidePanelPrivate));
	G_OBJECT_CLASS (klass)->get_property = valide_panel_get_property;
	G_OBJECT_CLASS (klass)->set_property = valide_panel_set_property;
	G_OBJECT_CLASS (klass)->constructor = valide_panel_constructor;
	G_OBJECT_CLASS (klass)->dispose = valide_panel_dispose;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALIDE_PANEL_ORIENTATION, g_param_spec_int ("orientation", "orientation", "orientation", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_signal_new ("item_added", VALIDE_TYPE_PANEL, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GTK_TYPE_WIDGET);
	g_signal_new ("item_removed", VALIDE_TYPE_PANEL, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, GTK_TYPE_WIDGET);
	g_signal_new ("close", VALIDE_TYPE_PANEL, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	g_signal_new ("focus_document", VALIDE_TYPE_PANEL, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}


static void valide_panel_init (ValidePanel * self) {
	self->priv = VALIDE_PANEL_GET_PRIVATE (self);
}


static void valide_panel_dispose (GObject * obj) {
	ValidePanel * self;
	self = VALIDE_PANEL (obj);
	(self->priv->notebook == NULL ? NULL : (self->priv->notebook = (g_object_unref (self->priv->notebook), NULL)));
	(self->priv->title_image == NULL ? NULL : (self->priv->title_image = (g_object_unref (self->priv->title_image), NULL)));
	(self->priv->title_label == NULL ? NULL : (self->priv->title_label = (g_object_unref (self->priv->title_label), NULL)));
	G_OBJECT_CLASS (valide_panel_parent_class)->dispose (obj);
}


GType valide_panel_get_type (void) {
	static GType valide_panel_type_id = 0;
	if (G_UNLIKELY (valide_panel_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValidePanelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_panel_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValidePanel), 0, (GInstanceInitFunc) valide_panel_init };
		valide_panel_type_id = g_type_register_static (GTK_TYPE_VBOX, "ValidePanel", &g_define_type_info, 0);
	}
	return valide_panel_type_id;
}




