/* utils.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/third-party/utils.h>
#include <libxml/parser.h>
#include <libxml/tree.h>




enum  {
	VALIDE_PATH_DUMMY_PROPERTY
};
static gpointer valide_path_parent_class = NULL;
enum  {
	VALIDE_UTILS_DUMMY_PROPERTY
};
static gpointer valide_utils_parent_class = NULL;
enum  {
	VALIDE_MARKUP_DUMMY_PROPERTY
};
static gpointer valide_markup_parent_class = NULL;



/**
   * @fixme Work only with path totally include, and is root of filename
   */
#line 28 "utils.vala"
char* valide_path_get_relative_path (const char* filename, const char* path) {
	char* relative;
#line 28 "utils.vala"
	g_return_val_if_fail (filename != NULL, NULL);
#line 28 "utils.vala"
	g_return_val_if_fail (path != NULL, NULL);
	relative = NULL;
#line 32 "utils.vala"
	if (g_str_has_prefix (filename, path)) {
		char* _tmp0;
		_tmp0 = NULL;
#line 34 "utils.vala"
		relative = (_tmp0 = g_build_filename (".", g_utf8_offset_to_pointer (filename, g_utf8_strlen (path, -1)), NULL), (relative = (g_free (relative), NULL)), _tmp0);
		/*
		       * relative path contien only one separator
		       */
#line 38 "utils.vala"
		if (strstr (g_utf8_offset_to_pointer (relative, ((glong) 2)), G_DIR_SEPARATOR_S) == NULL) {
			char* _tmp2;
			const char* _tmp1;
			_tmp2 = NULL;
#line 40 "utils.vala"
			_tmp1 = NULL;
#line 40 "utils.vala"
			relative = (_tmp2 = (_tmp1 = g_utf8_offset_to_pointer (relative, ((glong) 2)), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (relative = (g_free (relative), NULL)), _tmp2);
		}
	} else {
		char* _tmp4;
		const char* _tmp3;
		_tmp4 = NULL;
#line 45 "utils.vala"
		_tmp3 = NULL;
#line 45 "utils.vala"
		relative = (_tmp4 = (_tmp3 = filename, (_tmp3 == NULL ? NULL : g_strdup (_tmp3))), (relative = (g_free (relative), NULL)), _tmp4);
	}
#line 47 "utils.vala"
	return relative;
}


#line 23 "utils.vala"
ValidePath* valide_path_new (GType type) {
	ValidePath* self;
	self = ((ValidePath*) g_type_create_instance (type));
	return self;
}


static void valide_path_class_init (ValidePathClass * klass) {
	valide_path_parent_class = g_type_class_peek_parent (klass);
}


static void valide_path_init (ValidePath * self) {
	self->ref_count = 1;
}


GType valide_path_get_type (void) {
	static GType valide_path_type_id = 0;
	if (G_UNLIKELY (valide_path_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValidePathClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_path_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValidePath), 0, (GInstanceInitFunc) valide_path_init };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		valide_path_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValidePath", &g_define_type_info, &g_define_type_fundamental_info, 0);
	}
	return valide_path_type_id;
}


gpointer valide_path_ref (gpointer instance) {
	ValidePath* self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}


void valide_path_unref (gpointer instance) {
	ValidePath* self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		g_type_free_instance (((GTypeInstance *) self));
	}
}


#line 53 "utils.vala"
void valide_utils_set_up_io_channel (gint fd, GIOCondition cond, gboolean nblock, GIOFunc func, void* func_target) {
	GError * inner_error;
	GIOChannel* ioc;
	GIOChannel* _tmp0;
	inner_error = NULL;
	ioc = NULL;
	_tmp0 = NULL;
#line 58 "utils.vala"
	ioc = (_tmp0 = g_io_channel_unix_new (fd), (ioc == NULL ? NULL : (ioc = (g_io_channel_unref (ioc), NULL))), _tmp0);
#line 59 "utils.vala"
	if (nblock) {
#line 61 "utils.vala"
		g_io_channel_set_flags (ioc, G_IO_FLAG_NONBLOCK, &inner_error);
		if (inner_error != NULL) {
			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
			g_clear_error (&inner_error);
		}
	}
#line 63 "utils.vala"
	g_io_channel_set_close_on_unref (ioc, TRUE);
#line 64 "utils.vala"
	g_io_add_watch (ioc, cond, func, func_target);
	(ioc == NULL ? NULL : (ioc = (g_io_channel_unref (ioc), NULL)));
}


#line 67 "utils.vala"
void valide_utils_chop (char** s) {
#line 67 "utils.vala"
	g_return_if_fail (s != NULL);
#line 69 "utils.vala"
	if (g_str_has_suffix ((*s), "\n")) {
		char* _tmp0;
		_tmp0 = NULL;
#line 71 "utils.vala"
		(*s) = (_tmp0 = g_strndup ((*s), ((gulong) g_utf8_strlen ((*s), -1) - 1)), ((*s) = (g_free ((*s)), NULL)), _tmp0);
	}
}


#line 51 "utils.vala"
ValideUtils* valide_utils_new (GType type) {
	ValideUtils* self;
	self = ((ValideUtils*) g_type_create_instance (type));
	return self;
}


static void valide_utils_class_init (ValideUtilsClass * klass) {
	valide_utils_parent_class = g_type_class_peek_parent (klass);
}


static void valide_utils_init (ValideUtils * self) {
	self->ref_count = 1;
}


GType valide_utils_get_type (void) {
	static GType valide_utils_type_id = 0;
	if (G_UNLIKELY (valide_utils_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideUtilsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_utils_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideUtils), 0, (GInstanceInitFunc) valide_utils_init };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		valide_utils_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValideUtils", &g_define_type_info, &g_define_type_fundamental_info, 0);
	}
	return valide_utils_type_id;
}


gpointer valide_utils_ref (gpointer instance) {
	ValideUtils* self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}


void valide_utils_unref (gpointer instance) {
	ValideUtils* self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		g_type_free_instance (((GTypeInstance *) self));
	}
}


#line 78 "utils.vala"
void valide_markup_remove (const char* filename, const char* xpath) {
	xmlDoc* xml;
	xmlXPathContext* xpath_context;
	xmlXPathObject* xpath_obj;
#line 78 "utils.vala"
	g_return_if_fail (filename != NULL);
#line 78 "utils.vala"
	g_return_if_fail (xpath != NULL);
	xml = xmlParseFile (filename);
	xpath_context = xmlXPathNewContext (xml);
	xpath_obj = xmlXPathEval (xpath, xpath_context);
	{
		gint i;
		i = 0;
#line 83 "utils.vala"
		for (; i < xmlXPathNodeSetGetLength (xpath_obj->nodesetval); i++) {
#line 85 "utils.vala"
			xmlUnlinkNode (xmlXPathNodeSetItem (xpath_obj->nodesetval, i));
		}
	}
#line 87 "utils.vala"
	xmlUnlinkNode (xmlXPathNodeSetItem (xpath_obj->nodesetval, 0));
#line 88 "utils.vala"
	xmlSaveFile (filename, xml);
	(xpath_context == NULL ? NULL : (xpath_context = (xmlXPathFreeContext (xpath_context), NULL)));
}


#line 91 "utils.vala"
void valide_markup_add_child (const char* filename, const char* xpath, const char* name, const char* content) {
	xmlDoc* xml;
	xmlXPathContext* xpath_context;
	xmlXPathObject* xpath_obj;
#line 91 "utils.vala"
	g_return_if_fail (filename != NULL);
#line 91 "utils.vala"
	g_return_if_fail (xpath != NULL);
#line 91 "utils.vala"
	g_return_if_fail (name != NULL);
	xml = xmlParseFile (filename);
	xpath_context = xmlXPathNewContext (xml);
	xpath_obj = xmlXPathEval (xpath, xpath_context);
#line 97 "utils.vala"
	xmlNewTextChild (xmlXPathNodeSetItem (xpath_obj->nodesetval, 0), NULL, name, content);
#line 98 "utils.vala"
	xmlSaveFile (filename, xml);
	(xpath_context == NULL ? NULL : (xpath_context = (xmlXPathFreeContext (xpath_context), NULL)));
}


#line 101 "utils.vala"
gboolean valide_markup_exist (const char* filename, const char* xpath) {
	gboolean ret;
	xmlDoc* xml;
	xmlXPathContext* xpath_context;
	xmlXPathObject* xpath_obj;
	gboolean _tmp0;
#line 101 "utils.vala"
	g_return_val_if_fail (filename != NULL, FALSE);
#line 101 "utils.vala"
	g_return_val_if_fail (xpath != NULL, FALSE);
	ret = FALSE;
	xml = xmlParseFile (filename);
	xpath_context = xmlXPathNewContext (xml);
	xpath_obj = xmlXPathEval (xpath, xpath_context);
#line 108 "utils.vala"
	if (xpath_obj != NULL && xmlXPathNodeSetGetLength (xpath_obj->nodesetval) > 0) {
#line 110 "utils.vala"
		ret = TRUE;
	}
#line 112 "utils.vala"
	return (_tmp0 = ret, (xpath_context == NULL ? NULL : (xpath_context = (xmlXPathFreeContext (xpath_context), NULL))), _tmp0);
}


#line 115 "utils.vala"
char* valide_markup_get_content (const char* filename, const char* xpath) {
	xmlDoc* xml;
	xmlXPathContext* xpath_context;
	xmlXPathObject* xpath_obj;
	const char* _tmp0;
	char* _tmp1;
#line 115 "utils.vala"
	g_return_val_if_fail (filename != NULL, NULL);
#line 115 "utils.vala"
	g_return_val_if_fail (xpath != NULL, NULL);
	xml = xmlParseFile (filename);
	xpath_context = xmlXPathNewContext (xml);
	xpath_obj = xmlXPathEval (xpath, xpath_context);
#line 120 "utils.vala"
	_tmp0 = NULL;
#line 120 "utils.vala"
	_tmp1 = NULL;
#line 120 "utils.vala"
	return (_tmp1 = (_tmp0 = xmlXPathNodeSetItem (xpath_obj->nodesetval, 0)->content, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (xpath_context == NULL ? NULL : (xpath_context = (xmlXPathFreeContext (xpath_context), NULL))), _tmp1);
}


#line 123 "utils.vala"
xmlNodeSet* valide_markup_get_nodes (const char* filename, const char* xpath) {
	xmlDoc* xml;
	xmlXPathContext* xpath_context;
	xmlXPathObject* xpath_obj;
	xmlNodeSet* _tmp0;
#line 123 "utils.vala"
	g_return_val_if_fail (filename != NULL, NULL);
#line 123 "utils.vala"
	g_return_val_if_fail (xpath != NULL, NULL);
	xml = xmlParseFile (filename);
	xpath_context = xmlXPathNewContext (xml);
	xpath_obj = xmlXPathEval (xpath, xpath_context);
#line 128 "utils.vala"
	return (_tmp0 = xpath_obj->nodesetval, (xpath_context == NULL ? NULL : (xpath_context = (xmlXPathFreeContext (xpath_context), NULL))), _tmp0);
}


#line 76 "utils.vala"
ValideMarkup* valide_markup_new (GType type) {
	ValideMarkup* self;
	self = ((ValideMarkup*) g_type_create_instance (type));
	return self;
}


static void valide_markup_class_init (ValideMarkupClass * klass) {
	valide_markup_parent_class = g_type_class_peek_parent (klass);
}


static void valide_markup_init (ValideMarkup * self) {
	self->ref_count = 1;
}


GType valide_markup_get_type (void) {
	static GType valide_markup_type_id = 0;
	if (G_UNLIKELY (valide_markup_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideMarkupClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_markup_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideMarkup), 0, (GInstanceInitFunc) valide_markup_init };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		valide_markup_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ValideMarkup", &g_define_type_info, &g_define_type_fundamental_info, 0);
	}
	return valide_markup_type_id;
}


gpointer valide_markup_ref (gpointer instance) {
	ValideMarkup* self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}


void valide_markup_unref (gpointer instance) {
	ValideMarkup* self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		g_type_free_instance (((GTypeInstance *) self));
	}
}




