/* utils.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#ifndef __SRC_THIRD_PARTY_UTILS_H__
#define __SRC_THIRD_PARTY_UTILS_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <libxml/xpath.h>

G_BEGIN_DECLS


#define VALIDE_TYPE_PATH (valide_path_get_type ())
#define VALIDE_PATH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALIDE_TYPE_PATH, ValidePath))
#define VALIDE_PATH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALIDE_TYPE_PATH, ValidePathClass))
#define VALIDE_IS_PATH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALIDE_TYPE_PATH))
#define VALIDE_IS_PATH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALIDE_TYPE_PATH))
#define VALIDE_PATH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALIDE_TYPE_PATH, ValidePathClass))

typedef struct _ValidePath ValidePath;
typedef struct _ValidePathClass ValidePathClass;
typedef struct _ValidePathPrivate ValidePathPrivate;

#define VALIDE_TYPE_UTILS (valide_utils_get_type ())
#define VALIDE_UTILS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALIDE_TYPE_UTILS, ValideUtils))
#define VALIDE_UTILS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALIDE_TYPE_UTILS, ValideUtilsClass))
#define VALIDE_IS_UTILS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALIDE_TYPE_UTILS))
#define VALIDE_IS_UTILS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALIDE_TYPE_UTILS))
#define VALIDE_UTILS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALIDE_TYPE_UTILS, ValideUtilsClass))

typedef struct _ValideUtils ValideUtils;
typedef struct _ValideUtilsClass ValideUtilsClass;
typedef struct _ValideUtilsPrivate ValideUtilsPrivate;

#define VALIDE_TYPE_MARKUP (valide_markup_get_type ())
#define VALIDE_MARKUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALIDE_TYPE_MARKUP, ValideMarkup))
#define VALIDE_MARKUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALIDE_TYPE_MARKUP, ValideMarkupClass))
#define VALIDE_IS_MARKUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALIDE_TYPE_MARKUP))
#define VALIDE_IS_MARKUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALIDE_TYPE_MARKUP))
#define VALIDE_MARKUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALIDE_TYPE_MARKUP, ValideMarkupClass))

typedef struct _ValideMarkup ValideMarkup;
typedef struct _ValideMarkupClass ValideMarkupClass;
typedef struct _ValideMarkupPrivate ValideMarkupPrivate;

struct _ValidePath {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ValidePathPrivate * priv;
};

struct _ValidePathClass {
	GTypeClass parent_class;
	void (*finalize) (ValidePath *self);
};

struct _ValideUtils {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ValideUtilsPrivate * priv;
};

struct _ValideUtilsClass {
	GTypeClass parent_class;
	void (*finalize) (ValideUtils *self);
};

struct _ValideMarkup {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ValideMarkupPrivate * priv;
};

struct _ValideMarkupClass {
	GTypeClass parent_class;
	void (*finalize) (ValideMarkup *self);
};


char* valide_path_get_relative_path (const char* filename, const char* path);
ValidePath* valide_path_new (GType type);
GType valide_path_get_type (void);
gpointer valide_path_ref (gpointer instance);
void valide_path_unref (gpointer instance);
void valide_utils_set_up_io_channel (gint fd, GIOCondition cond, gboolean nblock, GIOFunc func, void* func_target);
void valide_utils_chop (char** s);
ValideUtils* valide_utils_new (GType type);
GType valide_utils_get_type (void);
gpointer valide_utils_ref (gpointer instance);
void valide_utils_unref (gpointer instance);
void valide_markup_remove (const char* filename, const char* xpath);
void valide_markup_add_child (const char* filename, const char* xpath, const char* name, const char* content);
gboolean valide_markup_exist (const char* filename, const char* xpath);
char* valide_markup_get_content (const char* filename, const char* xpath);
xmlNodeSet* valide_markup_get_nodes (const char* filename, const char* xpath);
ValideMarkup* valide_markup_new (GType type);
GType valide_markup_get_type (void);
gpointer valide_markup_ref (gpointer instance);
void valide_markup_unref (gpointer instance);


G_END_DECLS

#endif
