/* utils.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

public class Valide.Path
{
  /**
   * @fixme Work only with path totally include, and is root of filename
   */
  public static string get_relative_path (string filename, string path)
  {
    string relative = null;

    if (filename.has_prefix (path))
    {
      relative = GLib.Path.build_filename (".", filename.offset (path.len ()));
      /*
       * relative path contien only one separator
       */
      if (relative.offset (2).str (GLib.Path.DIR_SEPARATOR_S) == null)
      {
        relative = relative.offset (2);
      }
    }
    else
    {
      relative = filename;
    }
    return relative;
  }
}

public class Valide.Utils
{
  public static void set_up_io_channel (int fd, GLib.IOCondition cond,
                                        bool nblock, GLib.IOFunc func)
  {
	  GLib.IOChannel ioc;

	  ioc = new GLib.IOChannel.unix_new (fd);
	  if (nblock)
	  {
		  ioc.set_flags(GLib.IOFlags.NONBLOCK);
		}
	  ioc.set_close_on_unref (true);
	  ioc.add_watch (cond, func);
  }

  public static void chop (ref string s)
  {
    if (s.has_suffix ("\n"))
    {
      s = s.ndup (s.len () - 1);
    }
  }
}

public class Valide.Markup
{
  public static void remove (string filename, string xpath)
  {
    Xml.Doc* xml = Xml.Parser.parse_file (filename);
    Xml.XPathContext xpath_context = new Xml.XPathContext (xml);
    Xml.XPathObject* xpath_obj = xpath_context.eval (xpath);
    for (int i = 0; i < xpath_obj->nodesetval->length (); i++)
    {
      xpath_obj->nodesetval->item (i)->unlink ();
    }
    xpath_obj->nodesetval->item (0)->unlink ();
    xml->save_file (filename);
  }

  public static void add_child (string filename, string xpath, string name,
                                string? content=null)
  {
    Xml.Doc* xml = Xml.Parser.parse_file (filename);
    Xml.XPathContext xpath_context = new Xml.XPathContext (xml);
    Xml.XPathObject* xpath_obj = xpath_context.eval (xpath);
    xpath_obj->nodesetval->item (0)->new_text_child (null, name, content);
    xml->save_file (filename);
  }

  public static bool exist (string filename, string xpath)
  {
    bool ret = false;

    Xml.Doc* xml = Xml.Parser.parse_file (filename);
    Xml.XPathContext xpath_context = new Xml.XPathContext (xml);
    Xml.XPathObject* xpath_obj = xpath_context.eval (xpath);
    if (xpath_obj != null && xpath_obj->nodesetval->length () > 0)
    {
      ret = true;
    }
    return ret;
  }

  public static string get_content (string filename, string xpath)
  {
    Xml.Doc* xml = Xml.Parser.parse_file (filename);
    Xml.XPathContext xpath_context = new Xml.XPathContext (xml);
    Xml.XPathObject* xpath_obj = xpath_context.eval (xpath);
    return xpath_obj->nodesetval->item (0)->content;
  }

  public static Xml.NodeSet* get_nodes (string filename, string xpath)
  {
    Xml.Doc* xml = Xml.Parser.parse_file (filename);
    Xml.XPathContext xpath_context = new Xml.XPathContext (xml);
    Xml.XPathObject* xpath_obj = xpath_context.eval (xpath);
    return xpath_obj->nodesetval;
  }
}

