/* uimanager.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

using GLib;

public class Valide.UIManager : Gtk.UIManager
{
  private Gtk.ActionGroup action_group;
  private Gtk.ActionGroup document_action_group;
  private static UIManager instance;

  construct
  {
    Gtk.ToggleAction ta;

    action_group = new Gtk.ActionGroup ("general");
    document_action_group = new Gtk.ActionGroup ("document");

    /* File menu */
    action_group.add_action (new Gtk.Action ("file", _("_File"), null, null));
    action_group.add_action_with_accel (new Gtk.Action ("file-new", null, _("Create new source file"), Gtk.STOCK_NEW), null);
    action_group.add_action_with_accel (new Gtk.Action ("file-open", null, _("Open source file"), Gtk.STOCK_OPEN), null);
    action_group.add_action_with_accel (new Gtk.Action ("file-save", null, _("Save source file"), Gtk.STOCK_SAVE), null);
    action_group.add_action_with_accel (new Gtk.Action ("file-save-as", null, _("Save as source file"), Gtk.STOCK_SAVE_AS), null);
    action_group.add_action_with_accel (new Gtk.Action ("file-close", null, _("Close source file"), Gtk.STOCK_CLOSE), null);
    action_group.add_action_with_accel (new Gtk.Action ("file-close-all", _("C_lose all"), _("Close all sources files"), null), null);
    action_group.add_action_with_accel (new Gtk.Action ("quit", null, _("Quit application"), Gtk.STOCK_QUIT), null);

    /* Edit menu */
    action_group.add_action (new Gtk.Action ("edit", _("_Edit"), null, null));
    action_group.add_action_with_accel (new Gtk.Action ("edit-undo", null, _("Undo last action"), Gtk.STOCK_UNDO), "<ctrl>Z");
    action_group.add_action_with_accel (new Gtk.Action ("edit-redo", null, _("Redo last undo action"), Gtk.STOCK_REDO), "<ctrl><shift>Z");
    action_group.add_action_with_accel (new Gtk.Action ("edit-copy", null, _("Copy text"), Gtk.STOCK_COPY), null);
    action_group.add_action_with_accel (new Gtk.Action ("edit-cut", null, _("Cut text"), Gtk.STOCK_CUT), null);
    action_group.add_action_with_accel (new Gtk.Action ("edit-paste", null, _("Paste text"), Gtk.STOCK_PASTE), null);

    /* View menu */
    action_group.add_action (new Gtk.Action ("view", _("_View"), null, null));
    action_group.add_action_with_accel (new Gtk.ToggleAction ("view-side-panel", _("Side panel"), _("Side panel"), null), "F9");
    action_group.add_action_with_accel (new Gtk.ToggleAction ("view-bottom-panel", _("Bottom panel"), _("Bottom panel"), null), "<ctrl>F9");

    /* Project menu */
    action_group.add_action (new Gtk.Action ("project", _("_Project"), null, null));
    action_group.add_action_with_accel (new Gtk.Action ("project-new", null, _("Create new project"), Gtk.STOCK_NEW), "<ctrl><shift>N");
    action_group.add_action_with_accel (new Gtk.Action ("project-open", null, _("Open project"), Gtk.STOCK_OPEN), "<ctrl><shift>O");
    action_group.add_action_with_accel (new Gtk.Action ("project-add", _("_Add file"), _("Add file to project"), Gtk.STOCK_ADD), null);
    action_group.add_action_with_accel (new Gtk.Action ("project-remove", _("_Remove file"), _("Remove file to project"), Gtk.STOCK_REMOVE), null);
    action_group.add_action_with_accel (new Gtk.Action ("project-options", _("O_ptions"), _("Project options"), Gtk.STOCK_PROPERTIES), null);
    action_group.add_action_with_accel (new Gtk.Action ("project-compile", _("_Compile"), _("Compile project"), Gtk.STOCK_CONVERT), "F11");
    action_group.add_action_with_accel (new Gtk.Action ("project-execute", null, _("Execute project"), Gtk.STOCK_EXECUTE), "F12");
    action_group.add_action_with_accel (new Gtk.Action ("project-close", null, _("Close project"), Gtk.STOCK_CLOSE), "<ctrl><shift>W");

    /* Help menu */
    action_group.add_action (new Gtk.Action ("help", _("_Help"), null, null));
    action_group.add_action (new Gtk.Action ("help-about", null, _("About this application"), Gtk.STOCK_ABOUT));

    /* Project popup */
    action_group.add_action_with_accel (new Gtk.Action ("project-file-new", _("New file"), _("Create new source file"), Gtk.STOCK_NEW), null);
    action_group.add_action_with_accel (new Gtk.Action ("project-file-open", _("Open file"), _("Open source file"), Gtk.STOCK_OPEN), null);
    action_group.add_action_with_accel (new Gtk.Action ("project-file-add", _("Add file"), _("Add source file to project"), Gtk.STOCK_ADD), null);
    action_group.add_action_with_accel (new Gtk.Action ("project-file-remove", _("Remove file"), _("Remove this file to project"), Gtk.STOCK_REMOVE), null);

    insert_action_group (action_group, 0);
    insert_action_group (document_action_group, 0);
  }

  private UIManager ()
  {
  }

  public static UIManager get_instance ()
  {
    if (instance == null)
    {
      instance = new UIManager ();
    }
    return instance;
  }

  public Gtk.Action get_action (string name)
  {
    return this.action_group.get_action (name);
  }
}

