/* window.vala
 *
 * Copyright (C) 2008  Nicolas Joseph
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Nicolas Joseph <gege2061@redaction-developpez.com>
 */

#include <src/window.h>
#include <config.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixdata.h>
#include "src/uimanager.h"
#include "src/document-manager.h"
#include "src/project-manager.h"
#include "src/third-party/executable-manager.h"
#include "src/third-party/panel.h"
#include "src/recent-manager-ui.h"
#include "src/document.h"
#include "src/project.h"
#include "src/aboutdialog.h"




struct _ValideWindowPrivate {
	ValideUIManager* ui_manager;
	ValideDocumentManager* documents;
	ValideProjectManager* projects;
	ValideExecutableManager* executables;
	ValidePanel* side_panel;
	ValidePanel* bottom_panel;
};

#define VALIDE_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALIDE_TYPE_WINDOW, ValideWindowPrivate))
enum  {
	VALIDE_WINDOW_DUMMY_PROPERTY
};
static ValideWindow* valide_window_instance = NULL;
static gboolean valide_window_on_delete_event (ValideWindow* self);
static ValideWindow* valide_window_new (void);
static void _valide_window_on_action_activated_gtk_ui_manager_post_activate (GtkUIManager* sender, GtkAction* action, gpointer self);
static void valide_window_setup_ui_manager (ValideWindow* self);
static void valide_window_real_populate_window (ValideWindow* self);
static void valide_window_populate_window (ValideWindow* self);
static void valide_window_on_action_activated (ValideWindow* self, GtkUIManager* sender, GtkAction* action);
static gboolean _valide_window_on_delete_event_gtk_widget_delete_event (GtkWidget* sender, GdkEvent* event, gpointer self);
static void _gtk_main_quit_gtk_object_destroy (GtkObject* sender, gpointer self);
static void _g_list_free_g_object_unref (GList* self);
static GObject * valide_window_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer valide_window_parent_class = NULL;
static void valide_window_dispose (GObject * obj);



#line 63 "window.vala"
static gboolean valide_window_on_delete_event (ValideWindow* self) {
#line 63 "window.vala"
	g_return_val_if_fail (VALIDE_IS_WINDOW (self), FALSE);
#line 65 "window.vala"
	return !valide_document_manager_close_all (self->priv->documents);
}


#line 68 "window.vala"
static ValideWindow* valide_window_new (void) {
	ValideWindow * self;
	self = g_object_newv (VALIDE_TYPE_WINDOW, 0, NULL);
	return self;
}


#line 120 "window.vala"
static void _valide_window_on_action_activated_gtk_ui_manager_post_activate (GtkUIManager* sender, GtkAction* action, gpointer self) {
	valide_window_on_action_activated (self, sender, action);
}


#line 72 "window.vala"
static void valide_window_setup_ui_manager (ValideWindow* self) {
	GError * inner_error;
	ValideUIManager* _tmp0;
#line 72 "window.vala"
	g_return_if_fail (VALIDE_IS_WINDOW (self));
	inner_error = NULL;
	_tmp0 = NULL;
#line 74 "window.vala"
	self->priv->ui_manager = (_tmp0 = valide_ui_manager_get_instance (), (self->priv->ui_manager == NULL ? NULL : (self->priv->ui_manager = (g_object_unref (self->priv->ui_manager), NULL))), _tmp0);
#line 75 "window.vala"
	g_signal_connect_object (self->priv->ui_manager, "post-activate", ((GCallback) _valide_window_on_action_activated_gtk_ui_manager_post_activate), self, 0);
	{
		char* _tmp1;
#line 78 "window.vala"
		_tmp1 = NULL;
#line 78 "window.vala"
		gtk_ui_manager_add_ui_from_file (GTK_UI_MANAGER (self->priv->ui_manager), (_tmp1 = g_build_filename (PACKAGE_DATA_DIR, "valide-ui.xml", NULL)), &inner_error);
		if (inner_error != NULL) {
			goto __catch10_g_error;
		}
		_tmp1 = (g_free (_tmp1), NULL);
	}
	goto __finally10;
	__catch10_g_error:
	{
		GError * e;
		e = inner_error;
		inner_error = NULL;
		{
#line 83 "window.vala"
			g_warning (e->message);
		}
	}
	__finally10:
	;
#line 85 "window.vala"
	gtk_window_add_accel_group (GTK_WINDOW (self), gtk_ui_manager_get_accel_group (GTK_UI_MANAGER (self->priv->ui_manager)));
}


#line 88 "window.vala"
static void valide_window_real_populate_window (ValideWindow* self) {
	GtkVBox* main_box;
	ValideRecentManagerUI* _tmp0;
	ValideRecentManagerUI* _tmp1;
	GtkVPaned* vpaned;
	ValidePanel* _tmp2;
	GtkHPaned* hpaned;
	ValidePanel* _tmp3;
	GtkStatusbar* _tmp4;
#line 88 "window.vala"
	g_return_if_fail (VALIDE_IS_WINDOW (self));
	main_box = g_object_ref_sink (gtk_vbox_new (FALSE, 0));
#line 91 "window.vala"
	gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (main_box));
#line 93 "window.vala"
	_tmp0 = NULL;
#line 93 "window.vala"
	valide_recent_manager_ui_update_file ((_tmp0 = valide_recent_manager_ui_get_instance ()), self->priv->ui_manager);
	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
#line 94 "window.vala"
	_tmp1 = NULL;
#line 94 "window.vala"
	valide_recent_manager_ui_update_project ((_tmp1 = valide_recent_manager_ui_get_instance ()), self->priv->ui_manager);
	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
#line 96 "window.vala"
	gtk_box_pack_start (GTK_BOX (main_box), gtk_ui_manager_get_widget (GTK_UI_MANAGER (self->priv->ui_manager), "/menubar"), FALSE, TRUE, ((guint) 0));
#line 97 "window.vala"
	gtk_box_pack_start (GTK_BOX (main_box), gtk_ui_manager_get_widget (GTK_UI_MANAGER (self->priv->ui_manager), "/toolbar"), FALSE, TRUE, ((guint) 0));
	vpaned = g_object_ref_sink (gtk_vpaned_new ());
#line 100 "window.vala"
	gtk_box_pack_start (GTK_BOX (main_box), GTK_WIDGET (vpaned), TRUE, TRUE, ((guint) 0));
	_tmp2 = NULL;
#line 102 "window.vala"
	self->priv->bottom_panel = (_tmp2 = g_object_ref_sink (valide_panel_new (GTK_ORIENTATION_HORIZONTAL)), (self->priv->bottom_panel == NULL ? NULL : (self->priv->bottom_panel = (g_object_unref (self->priv->bottom_panel), NULL))), _tmp2);
#line 103 "window.vala"
	valide_panel_add_item_with_stock_icon (self->priv->bottom_panel, GTK_WIDGET (self->priv->executables), "Executable", GTK_STOCK_EXECUTE);
#line 105 "window.vala"
	gtk_paned_pack2 (GTK_PANED (vpaned), GTK_WIDGET (self->priv->bottom_panel), FALSE, FALSE);
#line 106 "window.vala"
	gtk_paned_set_position (GTK_PANED (vpaned), 50);
	hpaned = g_object_ref_sink (gtk_hpaned_new ());
#line 109 "window.vala"
	gtk_paned_add1 (GTK_PANED (vpaned), GTK_WIDGET (hpaned));
	_tmp3 = NULL;
#line 111 "window.vala"
	self->priv->side_panel = (_tmp3 = g_object_ref_sink (valide_panel_new (GTK_ORIENTATION_VERTICAL)), (self->priv->side_panel == NULL ? NULL : (self->priv->side_panel = (g_object_unref (self->priv->side_panel), NULL))), _tmp3);
#line 112 "window.vala"
	valide_panel_add_item (self->priv->side_panel, GTK_WIDGET (self->priv->projects), "Project", NULL);
#line 113 "window.vala"
	gtk_paned_add1 (GTK_PANED (hpaned), GTK_WIDGET (self->priv->side_panel));
#line 114 "window.vala"
	gtk_paned_add2 (GTK_PANED (hpaned), GTK_WIDGET (self->priv->documents));
#line 116 "window.vala"
	_tmp4 = NULL;
#line 116 "window.vala"
	gtk_box_pack_start (GTK_BOX (main_box), GTK_WIDGET ((_tmp4 = g_object_ref_sink (gtk_statusbar_new ()))), FALSE, TRUE, ((guint) 0));
	(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
	(main_box == NULL ? NULL : (main_box = (g_object_unref (main_box), NULL)));
	(vpaned == NULL ? NULL : (vpaned = (g_object_unref (vpaned), NULL)));
	(hpaned == NULL ? NULL : (hpaned = (g_object_unref (hpaned), NULL)));
}


#line 88 "window.vala"
static void valide_window_populate_window (ValideWindow* self) {
#line 88 "window.vala"
	VALIDE_WINDOW_GET_CLASS (self)->populate_window (self);
}


#line 120 "window.vala"
static void valide_window_on_action_activated (ValideWindow* self, GtkUIManager* sender, GtkAction* action) {
	GError * inner_error;
	GQuark _tmp4;
	char* _tmp3;
	char* _tmp0;
#line 120 "window.vala"
	g_return_if_fail (VALIDE_IS_WINDOW (self));
#line 120 "window.vala"
	g_return_if_fail (GTK_IS_UI_MANAGER (sender));
#line 120 "window.vala"
	g_return_if_fail (GTK_IS_ACTION (action));
	inner_error = NULL;
#line 122 "window.vala"
	_tmp3 = NULL;
	_tmp0 = NULL;
	static GQuark _tmp4_label0 = 0;
	static GQuark _tmp4_label1 = 0;
	static GQuark _tmp4_label2 = 0;
	static GQuark _tmp4_label3 = 0;
	static GQuark _tmp4_label4 = 0;
	static GQuark _tmp4_label5 = 0;
	static GQuark _tmp4_label6 = 0;
	static GQuark _tmp4_label7 = 0;
	static GQuark _tmp4_label8 = 0;
	static GQuark _tmp4_label9 = 0;
	static GQuark _tmp4_label10 = 0;
	static GQuark _tmp4_label11 = 0;
	static GQuark _tmp4_label12 = 0;
	static GQuark _tmp4_label13 = 0;
	static GQuark _tmp4_label14 = 0;
	static GQuark _tmp4_label15 = 0;
	static GQuark _tmp4_label16 = 0;
	static GQuark _tmp4_label17 = 0;
	static GQuark _tmp4_label18 = 0;
	static GQuark _tmp4_label19 = 0;
	static GQuark _tmp4_label20 = 0;
	static GQuark _tmp4_label21 = 0;
	static GQuark _tmp4_label22 = 0;
	_tmp3 = (g_object_get (G_OBJECT (action), "name", &_tmp0, NULL), _tmp0);
	_tmp4 = (NULL == _tmp3 ? 0 : g_quark_from_string (_tmp3));
	if (_tmp4 == (0 != _tmp4_label0 ? _tmp4_label0 : (_tmp4_label0 = g_quark_from_static_string ("file-new"))))
	do {
#line 126 "window.vala"
		valide_document_manager_create (self->priv->documents, NULL);
#line 127 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label1 ? _tmp4_label1 : (_tmp4_label1 = g_quark_from_static_string ("file-open"))))
	do {
#line 129 "window.vala"
		valide_document_manager_open (self->priv->documents);
#line 130 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label2 ? _tmp4_label2 : (_tmp4_label2 = g_quark_from_static_string ("file-save"))))
	do {
#line 132 "window.vala"
		if (valide_document_manager_get_current (self->priv->documents) != NULL) {
#line 134 "window.vala"
			valide_document_save (valide_document_manager_get_current (self->priv->documents));
		} else {
#line 138 "window.vala"
			g_warning (_ ("No document open!"));
		}
#line 140 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label3 ? _tmp4_label3 : (_tmp4_label3 = g_quark_from_static_string ("file-save-as"))))
	do {
#line 142 "window.vala"
		if (valide_document_manager_get_current (self->priv->documents) != NULL) {
#line 144 "window.vala"
			valide_document_save_as (valide_document_manager_get_current (self->priv->documents));
		} else {
#line 148 "window.vala"
			g_warning (_ ("No document open!"));
		}
#line 150 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label4 ? _tmp4_label4 : (_tmp4_label4 = g_quark_from_static_string ("file-close"))))
	do {
#line 152 "window.vala"
		if (valide_document_manager_get_current (self->priv->documents) != NULL) {
#line 154 "window.vala"
			valide_document_close (valide_document_manager_get_current (self->priv->documents));
		} else {
#line 158 "window.vala"
			g_warning (_ ("No document open!"));
		}
#line 160 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label5 ? _tmp4_label5 : (_tmp4_label5 = g_quark_from_static_string ("file-close-all"))))
	do {
#line 162 "window.vala"
		if (valide_document_manager_get_current (self->priv->documents) != NULL) {
#line 164 "window.vala"
			valide_document_manager_close_all (self->priv->documents);
		} else {
#line 168 "window.vala"
			g_warning (_ ("No document open!"));
		}
#line 170 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label6 ? _tmp4_label6 : (_tmp4_label6 = g_quark_from_static_string ("quit"))))
	do {
#line 172 "window.vala"
		if (!valide_window_on_delete_event (self)) {
#line 173 "window.vala"
			gtk_object_destroy (GTK_OBJECT (self));
		}
#line 174 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label7 ? _tmp4_label7 : (_tmp4_label7 = g_quark_from_static_string ("edit-undo"))))
	do {
#line 178 "window.vala"
		if (valide_document_manager_get_current (self->priv->documents) != NULL) {
#line 180 "window.vala"
			valide_document_undo (valide_document_manager_get_current (self->priv->documents));
		} else {
#line 184 "window.vala"
			g_warning (_ ("No document open!"));
		}
#line 186 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label8 ? _tmp4_label8 : (_tmp4_label8 = g_quark_from_static_string ("edit-redo"))))
	do {
#line 188 "window.vala"
		if (valide_document_manager_get_current (self->priv->documents) != NULL) {
#line 190 "window.vala"
			valide_document_redo (valide_document_manager_get_current (self->priv->documents));
		} else {
#line 194 "window.vala"
			g_warning (_ ("No document open!"));
		}
#line 196 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label9 ? _tmp4_label9 : (_tmp4_label9 = g_quark_from_static_string ("edit-copy"))))
	do {
#line 198 "window.vala"
		if (valide_document_manager_get_current (self->priv->documents) != NULL) {
#line 200 "window.vala"
			valide_document_copy (valide_document_manager_get_current (self->priv->documents));
		} else {
#line 204 "window.vala"
			g_warning (_ ("No document open!"));
		}
#line 206 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label10 ? _tmp4_label10 : (_tmp4_label10 = g_quark_from_static_string ("edit-cut"))))
	do {
#line 208 "window.vala"
		if (valide_document_manager_get_current (self->priv->documents) != NULL) {
#line 210 "window.vala"
			valide_document_cut (valide_document_manager_get_current (self->priv->documents));
		} else {
#line 214 "window.vala"
			g_warning (_ ("No document open!"));
		}
#line 216 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label11 ? _tmp4_label11 : (_tmp4_label11 = g_quark_from_static_string ("edit-paste"))))
	do {
#line 218 "window.vala"
		if (valide_document_manager_get_current (self->priv->documents) != NULL) {
#line 220 "window.vala"
			valide_document_paste (valide_document_manager_get_current (self->priv->documents));
		} else {
#line 224 "window.vala"
			g_warning (_ ("No document open!"));
		}
#line 226 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label12 ? _tmp4_label12 : (_tmp4_label12 = g_quark_from_static_string ("view-side-panel"))))
	do {
		GtkToggleAction* _tmp1;
		GtkToggleAction* toggle_action;
#line 230 "window.vala"
		_tmp1 = NULL;
		toggle_action = (_tmp1 = GTK_TOGGLE_ACTION (action), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
#line 231 "window.vala"
		if (gtk_toggle_action_get_active (toggle_action)) {
#line 233 "window.vala"
			gtk_widget_show (GTK_WIDGET (self->priv->side_panel));
		} else {
#line 237 "window.vala"
			gtk_widget_hide (GTK_WIDGET (self->priv->side_panel));
		}
		(toggle_action == NULL ? NULL : (toggle_action = (g_object_unref (toggle_action), NULL)));
#line 239 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label13 ? _tmp4_label13 : (_tmp4_label13 = g_quark_from_static_string ("view-bottom-panel"))))
	do {
		GtkToggleAction* _tmp2;
		GtkToggleAction* toggle_action;
#line 241 "window.vala"
		_tmp2 = NULL;
		toggle_action = (_tmp2 = GTK_TOGGLE_ACTION (action), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
#line 242 "window.vala"
		if (gtk_toggle_action_get_active (toggle_action)) {
#line 244 "window.vala"
			gtk_widget_show (GTK_WIDGET (self->priv->bottom_panel));
		} else {
#line 248 "window.vala"
			gtk_widget_hide (GTK_WIDGET (self->priv->bottom_panel));
		}
		(toggle_action == NULL ? NULL : (toggle_action = (g_object_unref (toggle_action), NULL)));
#line 250 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label14 ? _tmp4_label14 : (_tmp4_label14 = g_quark_from_static_string ("project-new"))))
	do {
#line 254 "window.vala"
		valide_project_manager_create (self->priv->projects, NULL, &inner_error);
		if (inner_error != NULL) {
			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
			g_clear_error (&inner_error);
		}
#line 255 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label15 ? _tmp4_label15 : (_tmp4_label15 = g_quark_from_static_string ("project-open"))))
	do {
#line 257 "window.vala"
		valide_project_manager_open (self->priv->projects);
#line 258 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label16 ? _tmp4_label16 : (_tmp4_label16 = g_quark_from_static_string ("project-add"))))
	do {
#line 260 "window.vala"
		if (valide_project_manager_get_current (self->priv->projects) != NULL) {
#line 262 "window.vala"
			valide_project_add_file (valide_project_manager_get_current (self->priv->projects));
		} else {
#line 266 "window.vala"
			g_warning (_ ("No project open!"));
		}
#line 268 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label17 ? _tmp4_label17 : (_tmp4_label17 = g_quark_from_static_string ("project-remove"))))
	do {
#line 270 "window.vala"
		if (valide_project_manager_get_current (self->priv->projects) != NULL) {
#line 272 "window.vala"
			valide_project_remove_file (valide_project_manager_get_current (self->priv->projects));
		} else {
#line 276 "window.vala"
			g_warning (_ ("No project open!"));
		}
#line 278 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label18 ? _tmp4_label18 : (_tmp4_label18 = g_quark_from_static_string ("project-options"))))
	do {
#line 280 "window.vala"
		if (valide_project_manager_get_current (self->priv->projects) != NULL) {
#line 282 "window.vala"
			valide_project_options (valide_project_manager_get_current (self->priv->projects));
		} else {
#line 286 "window.vala"
			g_warning (_ ("No project open!"));
		}
#line 288 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label19 ? _tmp4_label19 : (_tmp4_label19 = g_quark_from_static_string ("project-compile"))))
	do {
#line 290 "window.vala"
		if (valide_project_manager_get_current (self->priv->projects) != NULL) {
#line 292 "window.vala"
			valide_project_compile (valide_project_manager_get_current (self->priv->projects));
		} else {
#line 296 "window.vala"
			g_warning (_ ("No project open!"));
		}
#line 298 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label20 ? _tmp4_label20 : (_tmp4_label20 = g_quark_from_static_string ("project-execute"))))
	do {
#line 300 "window.vala"
		if (valide_project_manager_get_current (self->priv->projects) != NULL) {
#line 302 "window.vala"
			valide_project_execute (valide_project_manager_get_current (self->priv->projects));
		} else {
#line 306 "window.vala"
			g_warning (_ ("No project open!"));
		}
#line 308 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label21 ? _tmp4_label21 : (_tmp4_label21 = g_quark_from_static_string ("project-close"))))
	do {
#line 310 "window.vala"
		if (valide_project_manager_get_current (self->priv->projects) != NULL) {
#line 312 "window.vala"
			valide_project_close (valide_project_manager_get_current (self->priv->projects));
		} else {
#line 316 "window.vala"
			g_warning (_ ("No project open!"));
		}
#line 318 "window.vala"
		break;
	} while (0); else if (_tmp4 == (0 != _tmp4_label22 ? _tmp4_label22 : (_tmp4_label22 = g_quark_from_static_string ("help-about"))))
	do {
		ValideAboutDialog* dialog;
		dialog = g_object_ref_sink (valide_about_dialog_new ());
#line 323 "window.vala"
		gtk_dialog_run (GTK_DIALOG (dialog));
#line 324 "window.vala"
		gtk_object_destroy (GTK_OBJECT (dialog));
		(dialog == NULL ? NULL : (dialog = (g_object_unref (dialog), NULL)));
#line 325 "window.vala"
		break;
	} while (0);
}


#line 329 "window.vala"
ValideWindow* valide_window_get_instance (void) {
	ValideWindow* _tmp1;
#line 331 "window.vala"
	if (valide_window_instance == NULL) {
		ValideWindow* _tmp0;
		_tmp0 = NULL;
#line 333 "window.vala"
		valide_window_instance = (_tmp0 = g_object_ref_sink (valide_window_new ()), (valide_window_instance == NULL ? NULL : (valide_window_instance = (g_object_unref (valide_window_instance), NULL))), _tmp0);
	}
#line 335 "window.vala"
	_tmp1 = NULL;
#line 335 "window.vala"
	return (_tmp1 = valide_window_instance, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
}


#line 338 "window.vala"
void valide_window_run (ValideWindow* self) {
#line 338 "window.vala"
	g_return_if_fail (VALIDE_IS_WINDOW (self));
#line 340 "window.vala"
	gtk_widget_show_all (GTK_WIDGET (self));
#line 341 "window.vala"
	gtk_widget_hide (GTK_WIDGET (self->priv->side_panel));
#line 342 "window.vala"
	gtk_widget_hide (GTK_WIDGET (self->priv->bottom_panel));
}


#line 63 "window.vala"
static gboolean _valide_window_on_delete_event_gtk_widget_delete_event (GtkWidget* sender, GdkEvent* event, gpointer self) {
	return valide_window_on_delete_event (self);
}


#line 6697 "gtk+-2.0.vapi"
static void _gtk_main_quit_gtk_object_destroy (GtkObject* sender, gpointer self) {
	gtk_main_quit ();
}


static void _g_list_free_g_object_unref (GList* self) {
	g_list_foreach (self, ((GFunc) g_object_unref), NULL);
	g_list_free (self);
}


static GObject * valide_window_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	ValideWindowClass * klass;
	GObjectClass * parent_class;
	ValideWindow * self;
	GError * inner_error;
	klass = VALIDE_WINDOW_CLASS (g_type_class_peek (VALIDE_TYPE_WINDOW));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = VALIDE_WINDOW (obj);
	inner_error = NULL;
	{
		ValideDocumentManager* _tmp0;
		ValideProjectManager* _tmp1;
		ValideExecutableManager* _tmp2;
#line 37 "window.vala"
		gtk_window_maximize (GTK_WINDOW (self));
#line 38 "window.vala"
		g_signal_connect_object (self, "delete-event", ((GCallback) _valide_window_on_delete_event_gtk_widget_delete_event), self, 0);
#line 39 "window.vala"
		g_signal_connect (self, "destroy", ((GCallback) _gtk_main_quit_gtk_object_destroy), NULL);
#line 40 "window.vala"
		gtk_window_set_title (GTK_WINDOW (self), "Val(a)IDE");
		_tmp0 = NULL;
#line 41 "window.vala"
		self->priv->documents = (_tmp0 = valide_document_manager_get_instance (), (self->priv->documents == NULL ? NULL : (self->priv->documents = (g_object_unref (self->priv->documents), NULL))), _tmp0);
		_tmp1 = NULL;
#line 42 "window.vala"
		self->priv->projects = (_tmp1 = valide_project_manager_get_instance (), (self->priv->projects == NULL ? NULL : (self->priv->projects = (g_object_unref (self->priv->projects), NULL))), _tmp1);
		_tmp2 = NULL;
#line 43 "window.vala"
		self->priv->executables = (_tmp2 = valide_executable_manager_get_instance (), (self->priv->executables == NULL ? NULL : (self->priv->executables = (g_object_unref (self->priv->executables), NULL))), _tmp2);
#line 44 "window.vala"
		valide_window_setup_ui_manager (self);
#line 45 "window.vala"
		valide_window_populate_window (self);
		{
			GList* list;
			char* _tmp3;
			char* _tmp4;
			char* _tmp5;
			char* _tmp6;
			list = NULL;
#line 50 "window.vala"
			_tmp3 = NULL;
#line 50 "window.vala"
			list = g_list_append (list, gdk_pixbuf_new_from_file ((_tmp3 = g_build_filename (PACKAGE_PIXMAPS_DIR, "icone-16.xpm", NULL)), &inner_error));
			_tmp3 = (g_free (_tmp3), NULL);
#line 51 "window.vala"
			_tmp4 = NULL;
#line 51 "window.vala"
			list = g_list_append (list, gdk_pixbuf_new_from_file ((_tmp4 = g_build_filename (PACKAGE_PIXMAPS_DIR, "icone-32.xpm", NULL)), &inner_error));
			_tmp4 = (g_free (_tmp4), NULL);
#line 52 "window.vala"
			_tmp5 = NULL;
#line 52 "window.vala"
			list = g_list_append (list, gdk_pixbuf_new_from_file ((_tmp5 = g_build_filename (PACKAGE_PIXMAPS_DIR, "icone-48.xpm", NULL)), &inner_error));
			_tmp5 = (g_free (_tmp5), NULL);
#line 53 "window.vala"
			_tmp6 = NULL;
#line 53 "window.vala"
			list = g_list_append (list, gdk_pixbuf_new_from_file ((_tmp6 = g_build_filename (PACKAGE_PIXMAPS_DIR, "icone-64.xpm", NULL)), &inner_error));
			_tmp6 = (g_free (_tmp6), NULL);
#line 54 "window.vala"
			gtk_window_set_default_icon_list (list);
			(list == NULL ? NULL : (list = (_g_list_free_g_object_unref (list), NULL)));
		}
		goto __finally11;
		__catch11_g_error:
		{
			GError * e;
			e = inner_error;
			inner_error = NULL;
			{
#line 58 "window.vala"
				g_warning (e->message);
			}
		}
		__finally11:
		;
	}
	return obj;
}


static void valide_window_class_init (ValideWindowClass * klass) {
	valide_window_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValideWindowPrivate));
	G_OBJECT_CLASS (klass)->constructor = valide_window_constructor;
	G_OBJECT_CLASS (klass)->dispose = valide_window_dispose;
	VALIDE_WINDOW_CLASS (klass)->populate_window = valide_window_real_populate_window;
}


static void valide_window_init (ValideWindow * self) {
	self->priv = VALIDE_WINDOW_GET_PRIVATE (self);
}


static void valide_window_dispose (GObject * obj) {
	ValideWindow * self;
	self = VALIDE_WINDOW (obj);
	(self->priv->ui_manager == NULL ? NULL : (self->priv->ui_manager = (g_object_unref (self->priv->ui_manager), NULL)));
	(self->priv->documents == NULL ? NULL : (self->priv->documents = (g_object_unref (self->priv->documents), NULL)));
	(self->priv->projects == NULL ? NULL : (self->priv->projects = (g_object_unref (self->priv->projects), NULL)));
	(self->priv->executables == NULL ? NULL : (self->priv->executables = (g_object_unref (self->priv->executables), NULL)));
	(self->priv->side_panel == NULL ? NULL : (self->priv->side_panel = (g_object_unref (self->priv->side_panel), NULL)));
	(self->priv->bottom_panel == NULL ? NULL : (self->priv->bottom_panel = (g_object_unref (self->priv->bottom_panel), NULL)));
	G_OBJECT_CLASS (valide_window_parent_class)->dispose (obj);
}


GType valide_window_get_type (void) {
	static GType valide_window_type_id = 0;
	if (G_UNLIKELY (valide_window_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValideWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valide_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValideWindow), 0, (GInstanceInitFunc) valide_window_init };
		valide_window_type_id = g_type_register_static (GTK_TYPE_WINDOW, "ValideWindow", &g_define_type_info, 0);
	}
	return valide_window_type_id;
}




